#include "nv_push_cl902d.h"

#include <stdio.h>

#include "util/u_math.h"






const char*
P_PARSE_NV902D_MTHD(uint16_t idx)
{
    switch (idx) {


    case NV902D_SET_OBJECT:
        return "NV902D_SET_OBJECT";
    case NV902D_NO_OPERATION:
        return "NV902D_NO_OPERATION";
    case NV902D_SET_NOTIFY_A:
        return "NV902D_SET_NOTIFY_A";
    case NV902D_SET_NOTIFY_B:
        return "NV902D_SET_NOTIFY_B";
    case NV902D_NOTIFY:
        return "NV902D_NOTIFY";
    case NV902D_WAIT_FOR_IDLE:
        return "NV902D_WAIT_FOR_IDLE";
    case NV902D_LOAD_MME_INSTRUCTION_RAM_POINTER:
        return "NV902D_LOAD_MME_INSTRUCTION_RAM_POINTER";
    case NV902D_LOAD_MME_INSTRUCTION_RAM:
        return "NV902D_LOAD_MME_INSTRUCTION_RAM";
    case NV902D_LOAD_MME_START_ADDRESS_RAM_POINTER:
        return "NV902D_LOAD_MME_START_ADDRESS_RAM_POINTER";
    case NV902D_LOAD_MME_START_ADDRESS_RAM:
        return "NV902D_LOAD_MME_START_ADDRESS_RAM";
    case NV902D_SET_MME_SHADOW_RAM_CONTROL:
        return "NV902D_SET_MME_SHADOW_RAM_CONTROL";
    case NV902D_SET_GLOBAL_RENDER_ENABLE_A:
        return "NV902D_SET_GLOBAL_RENDER_ENABLE_A";
    case NV902D_SET_GLOBAL_RENDER_ENABLE_B:
        return "NV902D_SET_GLOBAL_RENDER_ENABLE_B";
    case NV902D_SET_GLOBAL_RENDER_ENABLE_C:
        return "NV902D_SET_GLOBAL_RENDER_ENABLE_C";
    case NV902D_SEND_GO_IDLE:
        return "NV902D_SEND_GO_IDLE";
    case NV902D_PM_TRIGGER:
        return "NV902D_PM_TRIGGER";
    case NV902D_SET_INSTRUMENTATION_METHOD_HEADER:
        return "NV902D_SET_INSTRUMENTATION_METHOD_HEADER";
    case NV902D_SET_INSTRUMENTATION_METHOD_DATA:
        return "NV902D_SET_INSTRUMENTATION_METHOD_DATA";
    case NV902D_SET_MME_SWITCH_STATE:
        return "NV902D_SET_MME_SWITCH_STATE";
    case NV902D_SET_DST_FORMAT:
        return "NV902D_SET_DST_FORMAT";
    case NV902D_SET_DST_MEMORY_LAYOUT:
        return "NV902D_SET_DST_MEMORY_LAYOUT";
    case NV902D_SET_DST_BLOCK_SIZE:
        return "NV902D_SET_DST_BLOCK_SIZE";
    case NV902D_SET_DST_DEPTH:
        return "NV902D_SET_DST_DEPTH";
    case NV902D_SET_DST_LAYER:
        return "NV902D_SET_DST_LAYER";
    case NV902D_SET_DST_PITCH:
        return "NV902D_SET_DST_PITCH";
    case NV902D_SET_DST_WIDTH:
        return "NV902D_SET_DST_WIDTH";
    case NV902D_SET_DST_HEIGHT:
        return "NV902D_SET_DST_HEIGHT";
    case NV902D_SET_DST_OFFSET_UPPER:
        return "NV902D_SET_DST_OFFSET_UPPER";
    case NV902D_SET_DST_OFFSET_LOWER:
        return "NV902D_SET_DST_OFFSET_LOWER";
    case NV902D_FLUSH_AND_INVALIDATE_ROP_MINI_CACHE:
        return "NV902D_FLUSH_AND_INVALIDATE_ROP_MINI_CACHE";
    case NV902D_SET_SPARE_NOOP06:
        return "NV902D_SET_SPARE_NOOP06";
    case NV902D_SET_SRC_FORMAT:
        return "NV902D_SET_SRC_FORMAT";
    case NV902D_SET_SRC_MEMORY_LAYOUT:
        return "NV902D_SET_SRC_MEMORY_LAYOUT";
    case NV902D_SET_SRC_BLOCK_SIZE:
        return "NV902D_SET_SRC_BLOCK_SIZE";
    case NV902D_SET_SRC_DEPTH:
        return "NV902D_SET_SRC_DEPTH";
    case NV902D_TWOD_INVALIDATE_TEXTURE_DATA_CACHE:
        return "NV902D_TWOD_INVALIDATE_TEXTURE_DATA_CACHE";
    case NV902D_SET_SRC_PITCH:
        return "NV902D_SET_SRC_PITCH";
    case NV902D_SET_SRC_WIDTH:
        return "NV902D_SET_SRC_WIDTH";
    case NV902D_SET_SRC_HEIGHT:
        return "NV902D_SET_SRC_HEIGHT";
    case NV902D_SET_SRC_OFFSET_UPPER:
        return "NV902D_SET_SRC_OFFSET_UPPER";
    case NV902D_SET_SRC_OFFSET_LOWER:
        return "NV902D_SET_SRC_OFFSET_LOWER";
    case NV902D_SET_PIXELS_FROM_MEMORY_SECTOR_PROMOTION:
        return "NV902D_SET_PIXELS_FROM_MEMORY_SECTOR_PROMOTION";
    case NV902D_SET_SPARE_NOOP12:
        return "NV902D_SET_SPARE_NOOP12";
    case NV902D_SET_NUM_PROCESSING_CLUSTERS:
        return "NV902D_SET_NUM_PROCESSING_CLUSTERS";
    case NV902D_SET_RENDER_ENABLE_A:
        return "NV902D_SET_RENDER_ENABLE_A";
    case NV902D_SET_RENDER_ENABLE_B:
        return "NV902D_SET_RENDER_ENABLE_B";
    case NV902D_SET_RENDER_ENABLE_C:
        return "NV902D_SET_RENDER_ENABLE_C";
    case NV902D_SET_SPARE_NOOP08:
        return "NV902D_SET_SPARE_NOOP08";
    case NV902D_SET_SPARE_NOOP01:
        return "NV902D_SET_SPARE_NOOP01";
    case NV902D_SET_SPARE_NOOP11:
        return "NV902D_SET_SPARE_NOOP11";
    case NV902D_SET_SPARE_NOOP07:
        return "NV902D_SET_SPARE_NOOP07";
    case NV902D_SET_CLIP_X0:
        return "NV902D_SET_CLIP_X0";
    case NV902D_SET_CLIP_Y0:
        return "NV902D_SET_CLIP_Y0";
    case NV902D_SET_CLIP_WIDTH:
        return "NV902D_SET_CLIP_WIDTH";
    case NV902D_SET_CLIP_HEIGHT:
        return "NV902D_SET_CLIP_HEIGHT";
    case NV902D_SET_CLIP_ENABLE:
        return "NV902D_SET_CLIP_ENABLE";
    case NV902D_SET_COLOR_KEY_FORMAT:
        return "NV902D_SET_COLOR_KEY_FORMAT";
    case NV902D_SET_COLOR_KEY:
        return "NV902D_SET_COLOR_KEY";
    case NV902D_SET_COLOR_KEY_ENABLE:
        return "NV902D_SET_COLOR_KEY_ENABLE";
    case NV902D_SET_ROP:
        return "NV902D_SET_ROP";
    case NV902D_SET_BETA1:
        return "NV902D_SET_BETA1";
    case NV902D_SET_BETA4:
        return "NV902D_SET_BETA4";
    case NV902D_SET_OPERATION:
        return "NV902D_SET_OPERATION";
    case NV902D_SET_PATTERN_OFFSET:
        return "NV902D_SET_PATTERN_OFFSET";
    case NV902D_SET_PATTERN_SELECT:
        return "NV902D_SET_PATTERN_SELECT";
    case NV902D_SET_DST_COLOR_RENDER_TO_ZETA_SURFACE:
        return "NV902D_SET_DST_COLOR_RENDER_TO_ZETA_SURFACE";
    case NV902D_SET_SPARE_NOOP04:
        return "NV902D_SET_SPARE_NOOP04";
    case NV902D_SET_SPARE_NOOP15:
        return "NV902D_SET_SPARE_NOOP15";
    case NV902D_SET_SPARE_NOOP13:
        return "NV902D_SET_SPARE_NOOP13";
    case NV902D_SET_SPARE_NOOP03:
        return "NV902D_SET_SPARE_NOOP03";
    case NV902D_SET_SPARE_NOOP14:
        return "NV902D_SET_SPARE_NOOP14";
    case NV902D_SET_SPARE_NOOP02:
        return "NV902D_SET_SPARE_NOOP02";
    case NV902D_SET_COMPRESSION:
        return "NV902D_SET_COMPRESSION";
    case NV902D_SET_SPARE_NOOP09:
        return "NV902D_SET_SPARE_NOOP09";
    case NV902D_SET_RENDER_ENABLE_OVERRIDE:
        return "NV902D_SET_RENDER_ENABLE_OVERRIDE";
    case NV902D_SET_PIXELS_FROM_MEMORY_DIRECTION:
        return "NV902D_SET_PIXELS_FROM_MEMORY_DIRECTION";
    case NV902D_SET_SPARE_NOOP10:
        return "NV902D_SET_SPARE_NOOP10";
    case NV902D_SET_MONOCHROME_PATTERN_COLOR_FORMAT:
        return "NV902D_SET_MONOCHROME_PATTERN_COLOR_FORMAT";
    case NV902D_SET_MONOCHROME_PATTERN_FORMAT:
        return "NV902D_SET_MONOCHROME_PATTERN_FORMAT";
    case NV902D_SET_MONOCHROME_PATTERN_COLOR0:
        return "NV902D_SET_MONOCHROME_PATTERN_COLOR0";
    case NV902D_SET_MONOCHROME_PATTERN_COLOR1:
        return "NV902D_SET_MONOCHROME_PATTERN_COLOR1";
    case NV902D_SET_MONOCHROME_PATTERN0:
        return "NV902D_SET_MONOCHROME_PATTERN0";
    case NV902D_SET_MONOCHROME_PATTERN1:
        return "NV902D_SET_MONOCHROME_PATTERN1";
                    case NV902D_SET_RENDER_SOLID_PRIM_COLOR0:
        return "NV902D_SET_RENDER_SOLID_PRIM_COLOR0";
    case NV902D_SET_RENDER_SOLID_PRIM_COLOR1:
        return "NV902D_SET_RENDER_SOLID_PRIM_COLOR1";
    case NV902D_SET_RENDER_SOLID_PRIM_COLOR2:
        return "NV902D_SET_RENDER_SOLID_PRIM_COLOR2";
    case NV902D_SET_RENDER_SOLID_PRIM_COLOR3:
        return "NV902D_SET_RENDER_SOLID_PRIM_COLOR3";
    case NV902D_SET_MME_MEM_ADDRESS_A:
        return "NV902D_SET_MME_MEM_ADDRESS_A";
    case NV902D_SET_MME_MEM_ADDRESS_B:
        return "NV902D_SET_MME_MEM_ADDRESS_B";
    case NV902D_SET_MME_DATA_RAM_ADDRESS:
        return "NV902D_SET_MME_DATA_RAM_ADDRESS";
    case NV902D_MME_DMA_READ:
        return "NV902D_MME_DMA_READ";
    case NV902D_MME_DMA_READ_FIFOED:
        return "NV902D_MME_DMA_READ_FIFOED";
    case NV902D_MME_DMA_WRITE:
        return "NV902D_MME_DMA_WRITE";
    case NV902D_MME_DMA_REDUCTION:
        return "NV902D_MME_DMA_REDUCTION";
    case NV902D_MME_DMA_SYSMEMBAR:
        return "NV902D_MME_DMA_SYSMEMBAR";
    case NV902D_MME_DMA_SYNC:
        return "NV902D_MME_DMA_SYNC";
    case NV902D_SET_MME_DATA_FIFO_CONFIG:
        return "NV902D_SET_MME_DATA_FIFO_CONFIG";
    case NV902D_RENDER_SOLID_PRIM_MODE:
        return "NV902D_RENDER_SOLID_PRIM_MODE";
    case NV902D_SET_RENDER_SOLID_PRIM_COLOR_FORMAT:
        return "NV902D_SET_RENDER_SOLID_PRIM_COLOR_FORMAT";
    case NV902D_SET_RENDER_SOLID_PRIM_COLOR:
        return "NV902D_SET_RENDER_SOLID_PRIM_COLOR";
    case NV902D_SET_RENDER_SOLID_LINE_TIE_BREAK_BITS:
        return "NV902D_SET_RENDER_SOLID_LINE_TIE_BREAK_BITS";
    case NV902D_RENDER_SOLID_PRIM_POINT_X_Y:
        return "NV902D_RENDER_SOLID_PRIM_POINT_X_Y";
            case NV902D_SET_PIXELS_FROM_CPU_DATA_TYPE:
        return "NV902D_SET_PIXELS_FROM_CPU_DATA_TYPE";
    case NV902D_SET_PIXELS_FROM_CPU_COLOR_FORMAT:
        return "NV902D_SET_PIXELS_FROM_CPU_COLOR_FORMAT";
    case NV902D_SET_PIXELS_FROM_CPU_INDEX_FORMAT:
        return "NV902D_SET_PIXELS_FROM_CPU_INDEX_FORMAT";
    case NV902D_SET_PIXELS_FROM_CPU_MONO_FORMAT:
        return "NV902D_SET_PIXELS_FROM_CPU_MONO_FORMAT";
    case NV902D_SET_PIXELS_FROM_CPU_WRAP:
        return "NV902D_SET_PIXELS_FROM_CPU_WRAP";
    case NV902D_SET_PIXELS_FROM_CPU_COLOR0:
        return "NV902D_SET_PIXELS_FROM_CPU_COLOR0";
    case NV902D_SET_PIXELS_FROM_CPU_COLOR1:
        return "NV902D_SET_PIXELS_FROM_CPU_COLOR1";
    case NV902D_SET_PIXELS_FROM_CPU_MONO_OPACITY:
        return "NV902D_SET_PIXELS_FROM_CPU_MONO_OPACITY";
    case NV902D_SET_PIXELS_FROM_CPU_SRC_WIDTH:
        return "NV902D_SET_PIXELS_FROM_CPU_SRC_WIDTH";
    case NV902D_SET_PIXELS_FROM_CPU_SRC_HEIGHT:
        return "NV902D_SET_PIXELS_FROM_CPU_SRC_HEIGHT";
    case NV902D_SET_PIXELS_FROM_CPU_DX_DU_FRAC:
        return "NV902D_SET_PIXELS_FROM_CPU_DX_DU_FRAC";
    case NV902D_SET_PIXELS_FROM_CPU_DX_DU_INT:
        return "NV902D_SET_PIXELS_FROM_CPU_DX_DU_INT";
    case NV902D_SET_PIXELS_FROM_CPU_DY_DV_FRAC:
        return "NV902D_SET_PIXELS_FROM_CPU_DY_DV_FRAC";
    case NV902D_SET_PIXELS_FROM_CPU_DY_DV_INT:
        return "NV902D_SET_PIXELS_FROM_CPU_DY_DV_INT";
    case NV902D_SET_PIXELS_FROM_CPU_DST_X0_FRAC:
        return "NV902D_SET_PIXELS_FROM_CPU_DST_X0_FRAC";
    case NV902D_SET_PIXELS_FROM_CPU_DST_X0_INT:
        return "NV902D_SET_PIXELS_FROM_CPU_DST_X0_INT";
    case NV902D_SET_PIXELS_FROM_CPU_DST_Y0_FRAC:
        return "NV902D_SET_PIXELS_FROM_CPU_DST_Y0_FRAC";
    case NV902D_SET_PIXELS_FROM_CPU_DST_Y0_INT:
        return "NV902D_SET_PIXELS_FROM_CPU_DST_Y0_INT";
    case NV902D_PIXELS_FROM_CPU_DATA:
        return "NV902D_PIXELS_FROM_CPU_DATA";
    case NV902D_SET_BIG_ENDIAN_CONTROL:
        return "NV902D_SET_BIG_ENDIAN_CONTROL";
    case NV902D_SET_PIXELS_FROM_MEMORY_BLOCK_SHAPE:
        return "NV902D_SET_PIXELS_FROM_MEMORY_BLOCK_SHAPE";
    case NV902D_SET_PIXELS_FROM_MEMORY_CORRAL_SIZE:
        return "NV902D_SET_PIXELS_FROM_MEMORY_CORRAL_SIZE";
    case NV902D_SET_PIXELS_FROM_MEMORY_SAFE_OVERLAP:
        return "NV902D_SET_PIXELS_FROM_MEMORY_SAFE_OVERLAP";
    case NV902D_SET_PIXELS_FROM_MEMORY_SAMPLE_MODE:
        return "NV902D_SET_PIXELS_FROM_MEMORY_SAMPLE_MODE";
    case NV902D_SET_PIXELS_FROM_MEMORY_DST_X0:
        return "NV902D_SET_PIXELS_FROM_MEMORY_DST_X0";
    case NV902D_SET_PIXELS_FROM_MEMORY_DST_Y0:
        return "NV902D_SET_PIXELS_FROM_MEMORY_DST_Y0";
    case NV902D_SET_PIXELS_FROM_MEMORY_DST_WIDTH:
        return "NV902D_SET_PIXELS_FROM_MEMORY_DST_WIDTH";
    case NV902D_SET_PIXELS_FROM_MEMORY_DST_HEIGHT:
        return "NV902D_SET_PIXELS_FROM_MEMORY_DST_HEIGHT";
    case NV902D_SET_PIXELS_FROM_MEMORY_DU_DX_FRAC:
        return "NV902D_SET_PIXELS_FROM_MEMORY_DU_DX_FRAC";
    case NV902D_SET_PIXELS_FROM_MEMORY_DU_DX_INT:
        return "NV902D_SET_PIXELS_FROM_MEMORY_DU_DX_INT";
    case NV902D_SET_PIXELS_FROM_MEMORY_DV_DY_FRAC:
        return "NV902D_SET_PIXELS_FROM_MEMORY_DV_DY_FRAC";
    case NV902D_SET_PIXELS_FROM_MEMORY_DV_DY_INT:
        return "NV902D_SET_PIXELS_FROM_MEMORY_DV_DY_INT";
    case NV902D_SET_PIXELS_FROM_MEMORY_SRC_X0_FRAC:
        return "NV902D_SET_PIXELS_FROM_MEMORY_SRC_X0_FRAC";
    case NV902D_SET_PIXELS_FROM_MEMORY_SRC_X0_INT:
        return "NV902D_SET_PIXELS_FROM_MEMORY_SRC_X0_INT";
    case NV902D_SET_PIXELS_FROM_MEMORY_SRC_Y0_FRAC:
        return "NV902D_SET_PIXELS_FROM_MEMORY_SRC_Y0_FRAC";
    case NV902D_PIXELS_FROM_MEMORY_SRC_Y0_INT:
        return "NV902D_PIXELS_FROM_MEMORY_SRC_Y0_INT";
    case NV902D_SET_FALCON00:
        return "NV902D_SET_FALCON00";
    case NV902D_SET_FALCON01:
        return "NV902D_SET_FALCON01";
    case NV902D_SET_FALCON02:
        return "NV902D_SET_FALCON02";
    case NV902D_SET_FALCON03:
        return "NV902D_SET_FALCON03";
    case NV902D_SET_FALCON04:
        return "NV902D_SET_FALCON04";
    case NV902D_SET_FALCON05:
        return "NV902D_SET_FALCON05";
    case NV902D_SET_FALCON06:
        return "NV902D_SET_FALCON06";
    case NV902D_SET_FALCON07:
        return "NV902D_SET_FALCON07";
    case NV902D_SET_FALCON08:
        return "NV902D_SET_FALCON08";
    case NV902D_SET_FALCON09:
        return "NV902D_SET_FALCON09";
    case NV902D_SET_FALCON10:
        return "NV902D_SET_FALCON10";
    case NV902D_SET_FALCON11:
        return "NV902D_SET_FALCON11";
    case NV902D_SET_FALCON12:
        return "NV902D_SET_FALCON12";
    case NV902D_SET_FALCON13:
        return "NV902D_SET_FALCON13";
    case NV902D_SET_FALCON14:
        return "NV902D_SET_FALCON14";
    case NV902D_SET_FALCON15:
        return "NV902D_SET_FALCON15";
    case NV902D_SET_FALCON16:
        return "NV902D_SET_FALCON16";
    case NV902D_SET_FALCON17:
        return "NV902D_SET_FALCON17";
    case NV902D_SET_FALCON18:
        return "NV902D_SET_FALCON18";
    case NV902D_SET_FALCON19:
        return "NV902D_SET_FALCON19";
    case NV902D_SET_FALCON20:
        return "NV902D_SET_FALCON20";
    case NV902D_SET_FALCON21:
        return "NV902D_SET_FALCON21";
    case NV902D_SET_FALCON22:
        return "NV902D_SET_FALCON22";
    case NV902D_SET_FALCON23:
        return "NV902D_SET_FALCON23";
    case NV902D_SET_FALCON24:
        return "NV902D_SET_FALCON24";
    case NV902D_SET_FALCON25:
        return "NV902D_SET_FALCON25";
    case NV902D_SET_FALCON26:
        return "NV902D_SET_FALCON26";
    case NV902D_SET_FALCON27:
        return "NV902D_SET_FALCON27";
    case NV902D_SET_FALCON28:
        return "NV902D_SET_FALCON28";
    case NV902D_SET_FALCON29:
        return "NV902D_SET_FALCON29";
    case NV902D_SET_FALCON30:
        return "NV902D_SET_FALCON30";
    case NV902D_SET_FALCON31:
        return "NV902D_SET_FALCON31";
    case NV902D_MME_DMA_WRITE_METHOD_BARRIER:
        return "NV902D_MME_DMA_WRITE_METHOD_BARRIER";
    case NV902D_SET_MME_SHADOW_SCRATCH(0):
        return "NV902D_SET_MME_SHADOW_SCRATCH(0)";
    case NV902D_SET_MME_SHADOW_SCRATCH(1):
        return "NV902D_SET_MME_SHADOW_SCRATCH(1)";
    case NV902D_SET_MME_SHADOW_SCRATCH(2):
        return "NV902D_SET_MME_SHADOW_SCRATCH(2)";
    case NV902D_SET_MME_SHADOW_SCRATCH(3):
        return "NV902D_SET_MME_SHADOW_SCRATCH(3)";
    case NV902D_SET_MME_SHADOW_SCRATCH(4):
        return "NV902D_SET_MME_SHADOW_SCRATCH(4)";
    case NV902D_SET_MME_SHADOW_SCRATCH(5):
        return "NV902D_SET_MME_SHADOW_SCRATCH(5)";
    case NV902D_SET_MME_SHADOW_SCRATCH(6):
        return "NV902D_SET_MME_SHADOW_SCRATCH(6)";
    case NV902D_SET_MME_SHADOW_SCRATCH(7):
        return "NV902D_SET_MME_SHADOW_SCRATCH(7)";
    case NV902D_SET_MME_SHADOW_SCRATCH(8):
        return "NV902D_SET_MME_SHADOW_SCRATCH(8)";
    case NV902D_SET_MME_SHADOW_SCRATCH(9):
        return "NV902D_SET_MME_SHADOW_SCRATCH(9)";
    case NV902D_SET_MME_SHADOW_SCRATCH(10):
        return "NV902D_SET_MME_SHADOW_SCRATCH(10)";
    case NV902D_SET_MME_SHADOW_SCRATCH(11):
        return "NV902D_SET_MME_SHADOW_SCRATCH(11)";
    case NV902D_SET_MME_SHADOW_SCRATCH(12):
        return "NV902D_SET_MME_SHADOW_SCRATCH(12)";
    case NV902D_SET_MME_SHADOW_SCRATCH(13):
        return "NV902D_SET_MME_SHADOW_SCRATCH(13)";
    case NV902D_SET_MME_SHADOW_SCRATCH(14):
        return "NV902D_SET_MME_SHADOW_SCRATCH(14)";
    case NV902D_SET_MME_SHADOW_SCRATCH(15):
        return "NV902D_SET_MME_SHADOW_SCRATCH(15)";
    case NV902D_SET_MME_SHADOW_SCRATCH(16):
        return "NV902D_SET_MME_SHADOW_SCRATCH(16)";
    case NV902D_SET_MME_SHADOW_SCRATCH(17):
        return "NV902D_SET_MME_SHADOW_SCRATCH(17)";
    case NV902D_SET_MME_SHADOW_SCRATCH(18):
        return "NV902D_SET_MME_SHADOW_SCRATCH(18)";
    case NV902D_SET_MME_SHADOW_SCRATCH(19):
        return "NV902D_SET_MME_SHADOW_SCRATCH(19)";
    case NV902D_SET_MME_SHADOW_SCRATCH(20):
        return "NV902D_SET_MME_SHADOW_SCRATCH(20)";
    case NV902D_SET_MME_SHADOW_SCRATCH(21):
        return "NV902D_SET_MME_SHADOW_SCRATCH(21)";
    case NV902D_SET_MME_SHADOW_SCRATCH(22):
        return "NV902D_SET_MME_SHADOW_SCRATCH(22)";
    case NV902D_SET_MME_SHADOW_SCRATCH(23):
        return "NV902D_SET_MME_SHADOW_SCRATCH(23)";
    case NV902D_SET_MME_SHADOW_SCRATCH(24):
        return "NV902D_SET_MME_SHADOW_SCRATCH(24)";
    case NV902D_SET_MME_SHADOW_SCRATCH(25):
        return "NV902D_SET_MME_SHADOW_SCRATCH(25)";
    case NV902D_SET_MME_SHADOW_SCRATCH(26):
        return "NV902D_SET_MME_SHADOW_SCRATCH(26)";
    case NV902D_SET_MME_SHADOW_SCRATCH(27):
        return "NV902D_SET_MME_SHADOW_SCRATCH(27)";
    case NV902D_SET_MME_SHADOW_SCRATCH(28):
        return "NV902D_SET_MME_SHADOW_SCRATCH(28)";
    case NV902D_SET_MME_SHADOW_SCRATCH(29):
        return "NV902D_SET_MME_SHADOW_SCRATCH(29)";
    case NV902D_SET_MME_SHADOW_SCRATCH(30):
        return "NV902D_SET_MME_SHADOW_SCRATCH(30)";
    case NV902D_SET_MME_SHADOW_SCRATCH(31):
        return "NV902D_SET_MME_SHADOW_SCRATCH(31)";
    case NV902D_SET_MME_SHADOW_SCRATCH(32):
        return "NV902D_SET_MME_SHADOW_SCRATCH(32)";
    case NV902D_SET_MME_SHADOW_SCRATCH(33):
        return "NV902D_SET_MME_SHADOW_SCRATCH(33)";
    case NV902D_SET_MME_SHADOW_SCRATCH(34):
        return "NV902D_SET_MME_SHADOW_SCRATCH(34)";
    case NV902D_SET_MME_SHADOW_SCRATCH(35):
        return "NV902D_SET_MME_SHADOW_SCRATCH(35)";
    case NV902D_SET_MME_SHADOW_SCRATCH(36):
        return "NV902D_SET_MME_SHADOW_SCRATCH(36)";
    case NV902D_SET_MME_SHADOW_SCRATCH(37):
        return "NV902D_SET_MME_SHADOW_SCRATCH(37)";
    case NV902D_SET_MME_SHADOW_SCRATCH(38):
        return "NV902D_SET_MME_SHADOW_SCRATCH(38)";
    case NV902D_SET_MME_SHADOW_SCRATCH(39):
        return "NV902D_SET_MME_SHADOW_SCRATCH(39)";
    case NV902D_SET_MME_SHADOW_SCRATCH(40):
        return "NV902D_SET_MME_SHADOW_SCRATCH(40)";
    case NV902D_SET_MME_SHADOW_SCRATCH(41):
        return "NV902D_SET_MME_SHADOW_SCRATCH(41)";
    case NV902D_SET_MME_SHADOW_SCRATCH(42):
        return "NV902D_SET_MME_SHADOW_SCRATCH(42)";
    case NV902D_SET_MME_SHADOW_SCRATCH(43):
        return "NV902D_SET_MME_SHADOW_SCRATCH(43)";
    case NV902D_SET_MME_SHADOW_SCRATCH(44):
        return "NV902D_SET_MME_SHADOW_SCRATCH(44)";
    case NV902D_SET_MME_SHADOW_SCRATCH(45):
        return "NV902D_SET_MME_SHADOW_SCRATCH(45)";
    case NV902D_SET_MME_SHADOW_SCRATCH(46):
        return "NV902D_SET_MME_SHADOW_SCRATCH(46)";
    case NV902D_SET_MME_SHADOW_SCRATCH(47):
        return "NV902D_SET_MME_SHADOW_SCRATCH(47)";
    case NV902D_SET_MME_SHADOW_SCRATCH(48):
        return "NV902D_SET_MME_SHADOW_SCRATCH(48)";
    case NV902D_SET_MME_SHADOW_SCRATCH(49):
        return "NV902D_SET_MME_SHADOW_SCRATCH(49)";
    case NV902D_SET_MME_SHADOW_SCRATCH(50):
        return "NV902D_SET_MME_SHADOW_SCRATCH(50)";
    case NV902D_SET_MME_SHADOW_SCRATCH(51):
        return "NV902D_SET_MME_SHADOW_SCRATCH(51)";
    case NV902D_SET_MME_SHADOW_SCRATCH(52):
        return "NV902D_SET_MME_SHADOW_SCRATCH(52)";
    case NV902D_SET_MME_SHADOW_SCRATCH(53):
        return "NV902D_SET_MME_SHADOW_SCRATCH(53)";
    case NV902D_SET_MME_SHADOW_SCRATCH(54):
        return "NV902D_SET_MME_SHADOW_SCRATCH(54)";
    case NV902D_SET_MME_SHADOW_SCRATCH(55):
        return "NV902D_SET_MME_SHADOW_SCRATCH(55)";
    case NV902D_SET_MME_SHADOW_SCRATCH(56):
        return "NV902D_SET_MME_SHADOW_SCRATCH(56)";
    case NV902D_SET_MME_SHADOW_SCRATCH(57):
        return "NV902D_SET_MME_SHADOW_SCRATCH(57)";
    case NV902D_SET_MME_SHADOW_SCRATCH(58):
        return "NV902D_SET_MME_SHADOW_SCRATCH(58)";
    case NV902D_SET_MME_SHADOW_SCRATCH(59):
        return "NV902D_SET_MME_SHADOW_SCRATCH(59)";
    case NV902D_SET_MME_SHADOW_SCRATCH(60):
        return "NV902D_SET_MME_SHADOW_SCRATCH(60)";
    case NV902D_SET_MME_SHADOW_SCRATCH(61):
        return "NV902D_SET_MME_SHADOW_SCRATCH(61)";
    case NV902D_SET_MME_SHADOW_SCRATCH(62):
        return "NV902D_SET_MME_SHADOW_SCRATCH(62)";
    case NV902D_SET_MME_SHADOW_SCRATCH(63):
        return "NV902D_SET_MME_SHADOW_SCRATCH(63)";
    case NV902D_SET_MME_SHADOW_SCRATCH(64):
        return "NV902D_SET_MME_SHADOW_SCRATCH(64)";
    case NV902D_SET_MME_SHADOW_SCRATCH(65):
        return "NV902D_SET_MME_SHADOW_SCRATCH(65)";
    case NV902D_SET_MME_SHADOW_SCRATCH(66):
        return "NV902D_SET_MME_SHADOW_SCRATCH(66)";
    case NV902D_SET_MME_SHADOW_SCRATCH(67):
        return "NV902D_SET_MME_SHADOW_SCRATCH(67)";
    case NV902D_SET_MME_SHADOW_SCRATCH(68):
        return "NV902D_SET_MME_SHADOW_SCRATCH(68)";
    case NV902D_SET_MME_SHADOW_SCRATCH(69):
        return "NV902D_SET_MME_SHADOW_SCRATCH(69)";
    case NV902D_SET_MME_SHADOW_SCRATCH(70):
        return "NV902D_SET_MME_SHADOW_SCRATCH(70)";
    case NV902D_SET_MME_SHADOW_SCRATCH(71):
        return "NV902D_SET_MME_SHADOW_SCRATCH(71)";
    case NV902D_SET_MME_SHADOW_SCRATCH(72):
        return "NV902D_SET_MME_SHADOW_SCRATCH(72)";
    case NV902D_SET_MME_SHADOW_SCRATCH(73):
        return "NV902D_SET_MME_SHADOW_SCRATCH(73)";
    case NV902D_SET_MME_SHADOW_SCRATCH(74):
        return "NV902D_SET_MME_SHADOW_SCRATCH(74)";
    case NV902D_SET_MME_SHADOW_SCRATCH(75):
        return "NV902D_SET_MME_SHADOW_SCRATCH(75)";
    case NV902D_SET_MME_SHADOW_SCRATCH(76):
        return "NV902D_SET_MME_SHADOW_SCRATCH(76)";
    case NV902D_SET_MME_SHADOW_SCRATCH(77):
        return "NV902D_SET_MME_SHADOW_SCRATCH(77)";
    case NV902D_SET_MME_SHADOW_SCRATCH(78):
        return "NV902D_SET_MME_SHADOW_SCRATCH(78)";
    case NV902D_SET_MME_SHADOW_SCRATCH(79):
        return "NV902D_SET_MME_SHADOW_SCRATCH(79)";
    case NV902D_SET_MME_SHADOW_SCRATCH(80):
        return "NV902D_SET_MME_SHADOW_SCRATCH(80)";
    case NV902D_SET_MME_SHADOW_SCRATCH(81):
        return "NV902D_SET_MME_SHADOW_SCRATCH(81)";
    case NV902D_SET_MME_SHADOW_SCRATCH(82):
        return "NV902D_SET_MME_SHADOW_SCRATCH(82)";
    case NV902D_SET_MME_SHADOW_SCRATCH(83):
        return "NV902D_SET_MME_SHADOW_SCRATCH(83)";
    case NV902D_SET_MME_SHADOW_SCRATCH(84):
        return "NV902D_SET_MME_SHADOW_SCRATCH(84)";
    case NV902D_SET_MME_SHADOW_SCRATCH(85):
        return "NV902D_SET_MME_SHADOW_SCRATCH(85)";
    case NV902D_SET_MME_SHADOW_SCRATCH(86):
        return "NV902D_SET_MME_SHADOW_SCRATCH(86)";
    case NV902D_SET_MME_SHADOW_SCRATCH(87):
        return "NV902D_SET_MME_SHADOW_SCRATCH(87)";
    case NV902D_SET_MME_SHADOW_SCRATCH(88):
        return "NV902D_SET_MME_SHADOW_SCRATCH(88)";
    case NV902D_SET_MME_SHADOW_SCRATCH(89):
        return "NV902D_SET_MME_SHADOW_SCRATCH(89)";
    case NV902D_SET_MME_SHADOW_SCRATCH(90):
        return "NV902D_SET_MME_SHADOW_SCRATCH(90)";
    case NV902D_SET_MME_SHADOW_SCRATCH(91):
        return "NV902D_SET_MME_SHADOW_SCRATCH(91)";
    case NV902D_SET_MME_SHADOW_SCRATCH(92):
        return "NV902D_SET_MME_SHADOW_SCRATCH(92)";
    case NV902D_SET_MME_SHADOW_SCRATCH(93):
        return "NV902D_SET_MME_SHADOW_SCRATCH(93)";
    case NV902D_SET_MME_SHADOW_SCRATCH(94):
        return "NV902D_SET_MME_SHADOW_SCRATCH(94)";
    case NV902D_SET_MME_SHADOW_SCRATCH(95):
        return "NV902D_SET_MME_SHADOW_SCRATCH(95)";
    case NV902D_SET_MME_SHADOW_SCRATCH(96):
        return "NV902D_SET_MME_SHADOW_SCRATCH(96)";
    case NV902D_SET_MME_SHADOW_SCRATCH(97):
        return "NV902D_SET_MME_SHADOW_SCRATCH(97)";
    case NV902D_SET_MME_SHADOW_SCRATCH(98):
        return "NV902D_SET_MME_SHADOW_SCRATCH(98)";
    case NV902D_SET_MME_SHADOW_SCRATCH(99):
        return "NV902D_SET_MME_SHADOW_SCRATCH(99)";
    case NV902D_SET_MME_SHADOW_SCRATCH(100):
        return "NV902D_SET_MME_SHADOW_SCRATCH(100)";
    case NV902D_SET_MME_SHADOW_SCRATCH(101):
        return "NV902D_SET_MME_SHADOW_SCRATCH(101)";
    case NV902D_SET_MME_SHADOW_SCRATCH(102):
        return "NV902D_SET_MME_SHADOW_SCRATCH(102)";
    case NV902D_SET_MME_SHADOW_SCRATCH(103):
        return "NV902D_SET_MME_SHADOW_SCRATCH(103)";
    case NV902D_SET_MME_SHADOW_SCRATCH(104):
        return "NV902D_SET_MME_SHADOW_SCRATCH(104)";
    case NV902D_SET_MME_SHADOW_SCRATCH(105):
        return "NV902D_SET_MME_SHADOW_SCRATCH(105)";
    case NV902D_SET_MME_SHADOW_SCRATCH(106):
        return "NV902D_SET_MME_SHADOW_SCRATCH(106)";
    case NV902D_SET_MME_SHADOW_SCRATCH(107):
        return "NV902D_SET_MME_SHADOW_SCRATCH(107)";
    case NV902D_SET_MME_SHADOW_SCRATCH(108):
        return "NV902D_SET_MME_SHADOW_SCRATCH(108)";
    case NV902D_SET_MME_SHADOW_SCRATCH(109):
        return "NV902D_SET_MME_SHADOW_SCRATCH(109)";
    case NV902D_SET_MME_SHADOW_SCRATCH(110):
        return "NV902D_SET_MME_SHADOW_SCRATCH(110)";
    case NV902D_SET_MME_SHADOW_SCRATCH(111):
        return "NV902D_SET_MME_SHADOW_SCRATCH(111)";
    case NV902D_SET_MME_SHADOW_SCRATCH(112):
        return "NV902D_SET_MME_SHADOW_SCRATCH(112)";
    case NV902D_SET_MME_SHADOW_SCRATCH(113):
        return "NV902D_SET_MME_SHADOW_SCRATCH(113)";
    case NV902D_SET_MME_SHADOW_SCRATCH(114):
        return "NV902D_SET_MME_SHADOW_SCRATCH(114)";
    case NV902D_SET_MME_SHADOW_SCRATCH(115):
        return "NV902D_SET_MME_SHADOW_SCRATCH(115)";
    case NV902D_SET_MME_SHADOW_SCRATCH(116):
        return "NV902D_SET_MME_SHADOW_SCRATCH(116)";
    case NV902D_SET_MME_SHADOW_SCRATCH(117):
        return "NV902D_SET_MME_SHADOW_SCRATCH(117)";
    case NV902D_SET_MME_SHADOW_SCRATCH(118):
        return "NV902D_SET_MME_SHADOW_SCRATCH(118)";
    case NV902D_SET_MME_SHADOW_SCRATCH(119):
        return "NV902D_SET_MME_SHADOW_SCRATCH(119)";
    case NV902D_SET_MME_SHADOW_SCRATCH(120):
        return "NV902D_SET_MME_SHADOW_SCRATCH(120)";
    case NV902D_SET_MME_SHADOW_SCRATCH(121):
        return "NV902D_SET_MME_SHADOW_SCRATCH(121)";
    case NV902D_SET_MME_SHADOW_SCRATCH(122):
        return "NV902D_SET_MME_SHADOW_SCRATCH(122)";
    case NV902D_SET_MME_SHADOW_SCRATCH(123):
        return "NV902D_SET_MME_SHADOW_SCRATCH(123)";
    case NV902D_SET_MME_SHADOW_SCRATCH(124):
        return "NV902D_SET_MME_SHADOW_SCRATCH(124)";
    case NV902D_SET_MME_SHADOW_SCRATCH(125):
        return "NV902D_SET_MME_SHADOW_SCRATCH(125)";
    case NV902D_SET_MME_SHADOW_SCRATCH(126):
        return "NV902D_SET_MME_SHADOW_SCRATCH(126)";
    case NV902D_SET_MME_SHADOW_SCRATCH(127):
        return "NV902D_SET_MME_SHADOW_SCRATCH(127)";
    case NV902D_SET_MME_SHADOW_SCRATCH(128):
        return "NV902D_SET_MME_SHADOW_SCRATCH(128)";
    case NV902D_SET_MME_SHADOW_SCRATCH(129):
        return "NV902D_SET_MME_SHADOW_SCRATCH(129)";
    case NV902D_SET_MME_SHADOW_SCRATCH(130):
        return "NV902D_SET_MME_SHADOW_SCRATCH(130)";
    case NV902D_SET_MME_SHADOW_SCRATCH(131):
        return "NV902D_SET_MME_SHADOW_SCRATCH(131)";
    case NV902D_SET_MME_SHADOW_SCRATCH(132):
        return "NV902D_SET_MME_SHADOW_SCRATCH(132)";
    case NV902D_SET_MME_SHADOW_SCRATCH(133):
        return "NV902D_SET_MME_SHADOW_SCRATCH(133)";
    case NV902D_SET_MME_SHADOW_SCRATCH(134):
        return "NV902D_SET_MME_SHADOW_SCRATCH(134)";
    case NV902D_SET_MME_SHADOW_SCRATCH(135):
        return "NV902D_SET_MME_SHADOW_SCRATCH(135)";
    case NV902D_SET_MME_SHADOW_SCRATCH(136):
        return "NV902D_SET_MME_SHADOW_SCRATCH(136)";
    case NV902D_SET_MME_SHADOW_SCRATCH(137):
        return "NV902D_SET_MME_SHADOW_SCRATCH(137)";
    case NV902D_SET_MME_SHADOW_SCRATCH(138):
        return "NV902D_SET_MME_SHADOW_SCRATCH(138)";
    case NV902D_SET_MME_SHADOW_SCRATCH(139):
        return "NV902D_SET_MME_SHADOW_SCRATCH(139)";
    case NV902D_SET_MME_SHADOW_SCRATCH(140):
        return "NV902D_SET_MME_SHADOW_SCRATCH(140)";
    case NV902D_SET_MME_SHADOW_SCRATCH(141):
        return "NV902D_SET_MME_SHADOW_SCRATCH(141)";
    case NV902D_SET_MME_SHADOW_SCRATCH(142):
        return "NV902D_SET_MME_SHADOW_SCRATCH(142)";
    case NV902D_SET_MME_SHADOW_SCRATCH(143):
        return "NV902D_SET_MME_SHADOW_SCRATCH(143)";
    case NV902D_SET_MME_SHADOW_SCRATCH(144):
        return "NV902D_SET_MME_SHADOW_SCRATCH(144)";
    case NV902D_SET_MME_SHADOW_SCRATCH(145):
        return "NV902D_SET_MME_SHADOW_SCRATCH(145)";
    case NV902D_SET_MME_SHADOW_SCRATCH(146):
        return "NV902D_SET_MME_SHADOW_SCRATCH(146)";
    case NV902D_SET_MME_SHADOW_SCRATCH(147):
        return "NV902D_SET_MME_SHADOW_SCRATCH(147)";
    case NV902D_SET_MME_SHADOW_SCRATCH(148):
        return "NV902D_SET_MME_SHADOW_SCRATCH(148)";
    case NV902D_SET_MME_SHADOW_SCRATCH(149):
        return "NV902D_SET_MME_SHADOW_SCRATCH(149)";
    case NV902D_SET_MME_SHADOW_SCRATCH(150):
        return "NV902D_SET_MME_SHADOW_SCRATCH(150)";
    case NV902D_SET_MME_SHADOW_SCRATCH(151):
        return "NV902D_SET_MME_SHADOW_SCRATCH(151)";
    case NV902D_SET_MME_SHADOW_SCRATCH(152):
        return "NV902D_SET_MME_SHADOW_SCRATCH(152)";
    case NV902D_SET_MME_SHADOW_SCRATCH(153):
        return "NV902D_SET_MME_SHADOW_SCRATCH(153)";
    case NV902D_SET_MME_SHADOW_SCRATCH(154):
        return "NV902D_SET_MME_SHADOW_SCRATCH(154)";
    case NV902D_SET_MME_SHADOW_SCRATCH(155):
        return "NV902D_SET_MME_SHADOW_SCRATCH(155)";
    case NV902D_SET_MME_SHADOW_SCRATCH(156):
        return "NV902D_SET_MME_SHADOW_SCRATCH(156)";
    case NV902D_SET_MME_SHADOW_SCRATCH(157):
        return "NV902D_SET_MME_SHADOW_SCRATCH(157)";
    case NV902D_SET_MME_SHADOW_SCRATCH(158):
        return "NV902D_SET_MME_SHADOW_SCRATCH(158)";
    case NV902D_SET_MME_SHADOW_SCRATCH(159):
        return "NV902D_SET_MME_SHADOW_SCRATCH(159)";
    case NV902D_SET_MME_SHADOW_SCRATCH(160):
        return "NV902D_SET_MME_SHADOW_SCRATCH(160)";
    case NV902D_SET_MME_SHADOW_SCRATCH(161):
        return "NV902D_SET_MME_SHADOW_SCRATCH(161)";
    case NV902D_SET_MME_SHADOW_SCRATCH(162):
        return "NV902D_SET_MME_SHADOW_SCRATCH(162)";
    case NV902D_SET_MME_SHADOW_SCRATCH(163):
        return "NV902D_SET_MME_SHADOW_SCRATCH(163)";
    case NV902D_SET_MME_SHADOW_SCRATCH(164):
        return "NV902D_SET_MME_SHADOW_SCRATCH(164)";
    case NV902D_SET_MME_SHADOW_SCRATCH(165):
        return "NV902D_SET_MME_SHADOW_SCRATCH(165)";
    case NV902D_SET_MME_SHADOW_SCRATCH(166):
        return "NV902D_SET_MME_SHADOW_SCRATCH(166)";
    case NV902D_SET_MME_SHADOW_SCRATCH(167):
        return "NV902D_SET_MME_SHADOW_SCRATCH(167)";
    case NV902D_SET_MME_SHADOW_SCRATCH(168):
        return "NV902D_SET_MME_SHADOW_SCRATCH(168)";
    case NV902D_SET_MME_SHADOW_SCRATCH(169):
        return "NV902D_SET_MME_SHADOW_SCRATCH(169)";
    case NV902D_SET_MME_SHADOW_SCRATCH(170):
        return "NV902D_SET_MME_SHADOW_SCRATCH(170)";
    case NV902D_SET_MME_SHADOW_SCRATCH(171):
        return "NV902D_SET_MME_SHADOW_SCRATCH(171)";
    case NV902D_SET_MME_SHADOW_SCRATCH(172):
        return "NV902D_SET_MME_SHADOW_SCRATCH(172)";
    case NV902D_SET_MME_SHADOW_SCRATCH(173):
        return "NV902D_SET_MME_SHADOW_SCRATCH(173)";
    case NV902D_SET_MME_SHADOW_SCRATCH(174):
        return "NV902D_SET_MME_SHADOW_SCRATCH(174)";
    case NV902D_SET_MME_SHADOW_SCRATCH(175):
        return "NV902D_SET_MME_SHADOW_SCRATCH(175)";
    case NV902D_SET_MME_SHADOW_SCRATCH(176):
        return "NV902D_SET_MME_SHADOW_SCRATCH(176)";
    case NV902D_SET_MME_SHADOW_SCRATCH(177):
        return "NV902D_SET_MME_SHADOW_SCRATCH(177)";
    case NV902D_SET_MME_SHADOW_SCRATCH(178):
        return "NV902D_SET_MME_SHADOW_SCRATCH(178)";
    case NV902D_SET_MME_SHADOW_SCRATCH(179):
        return "NV902D_SET_MME_SHADOW_SCRATCH(179)";
    case NV902D_SET_MME_SHADOW_SCRATCH(180):
        return "NV902D_SET_MME_SHADOW_SCRATCH(180)";
    case NV902D_SET_MME_SHADOW_SCRATCH(181):
        return "NV902D_SET_MME_SHADOW_SCRATCH(181)";
    case NV902D_SET_MME_SHADOW_SCRATCH(182):
        return "NV902D_SET_MME_SHADOW_SCRATCH(182)";
    case NV902D_SET_MME_SHADOW_SCRATCH(183):
        return "NV902D_SET_MME_SHADOW_SCRATCH(183)";
    case NV902D_SET_MME_SHADOW_SCRATCH(184):
        return "NV902D_SET_MME_SHADOW_SCRATCH(184)";
    case NV902D_SET_MME_SHADOW_SCRATCH(185):
        return "NV902D_SET_MME_SHADOW_SCRATCH(185)";
    case NV902D_SET_MME_SHADOW_SCRATCH(186):
        return "NV902D_SET_MME_SHADOW_SCRATCH(186)";
    case NV902D_SET_MME_SHADOW_SCRATCH(187):
        return "NV902D_SET_MME_SHADOW_SCRATCH(187)";
    case NV902D_SET_MME_SHADOW_SCRATCH(188):
        return "NV902D_SET_MME_SHADOW_SCRATCH(188)";
    case NV902D_SET_MME_SHADOW_SCRATCH(189):
        return "NV902D_SET_MME_SHADOW_SCRATCH(189)";
    case NV902D_SET_MME_SHADOW_SCRATCH(190):
        return "NV902D_SET_MME_SHADOW_SCRATCH(190)";
    case NV902D_SET_MME_SHADOW_SCRATCH(191):
        return "NV902D_SET_MME_SHADOW_SCRATCH(191)";
    case NV902D_SET_MME_SHADOW_SCRATCH(192):
        return "NV902D_SET_MME_SHADOW_SCRATCH(192)";
    case NV902D_SET_MME_SHADOW_SCRATCH(193):
        return "NV902D_SET_MME_SHADOW_SCRATCH(193)";
    case NV902D_SET_MME_SHADOW_SCRATCH(194):
        return "NV902D_SET_MME_SHADOW_SCRATCH(194)";
    case NV902D_SET_MME_SHADOW_SCRATCH(195):
        return "NV902D_SET_MME_SHADOW_SCRATCH(195)";
    case NV902D_SET_MME_SHADOW_SCRATCH(196):
        return "NV902D_SET_MME_SHADOW_SCRATCH(196)";
    case NV902D_SET_MME_SHADOW_SCRATCH(197):
        return "NV902D_SET_MME_SHADOW_SCRATCH(197)";
    case NV902D_SET_MME_SHADOW_SCRATCH(198):
        return "NV902D_SET_MME_SHADOW_SCRATCH(198)";
    case NV902D_SET_MME_SHADOW_SCRATCH(199):
        return "NV902D_SET_MME_SHADOW_SCRATCH(199)";
    case NV902D_SET_MME_SHADOW_SCRATCH(200):
        return "NV902D_SET_MME_SHADOW_SCRATCH(200)";
    case NV902D_SET_MME_SHADOW_SCRATCH(201):
        return "NV902D_SET_MME_SHADOW_SCRATCH(201)";
    case NV902D_SET_MME_SHADOW_SCRATCH(202):
        return "NV902D_SET_MME_SHADOW_SCRATCH(202)";
    case NV902D_SET_MME_SHADOW_SCRATCH(203):
        return "NV902D_SET_MME_SHADOW_SCRATCH(203)";
    case NV902D_SET_MME_SHADOW_SCRATCH(204):
        return "NV902D_SET_MME_SHADOW_SCRATCH(204)";
    case NV902D_SET_MME_SHADOW_SCRATCH(205):
        return "NV902D_SET_MME_SHADOW_SCRATCH(205)";
    case NV902D_SET_MME_SHADOW_SCRATCH(206):
        return "NV902D_SET_MME_SHADOW_SCRATCH(206)";
    case NV902D_SET_MME_SHADOW_SCRATCH(207):
        return "NV902D_SET_MME_SHADOW_SCRATCH(207)";
    case NV902D_SET_MME_SHADOW_SCRATCH(208):
        return "NV902D_SET_MME_SHADOW_SCRATCH(208)";
    case NV902D_SET_MME_SHADOW_SCRATCH(209):
        return "NV902D_SET_MME_SHADOW_SCRATCH(209)";
    case NV902D_SET_MME_SHADOW_SCRATCH(210):
        return "NV902D_SET_MME_SHADOW_SCRATCH(210)";
    case NV902D_SET_MME_SHADOW_SCRATCH(211):
        return "NV902D_SET_MME_SHADOW_SCRATCH(211)";
    case NV902D_SET_MME_SHADOW_SCRATCH(212):
        return "NV902D_SET_MME_SHADOW_SCRATCH(212)";
    case NV902D_SET_MME_SHADOW_SCRATCH(213):
        return "NV902D_SET_MME_SHADOW_SCRATCH(213)";
    case NV902D_SET_MME_SHADOW_SCRATCH(214):
        return "NV902D_SET_MME_SHADOW_SCRATCH(214)";
    case NV902D_SET_MME_SHADOW_SCRATCH(215):
        return "NV902D_SET_MME_SHADOW_SCRATCH(215)";
    case NV902D_SET_MME_SHADOW_SCRATCH(216):
        return "NV902D_SET_MME_SHADOW_SCRATCH(216)";
    case NV902D_SET_MME_SHADOW_SCRATCH(217):
        return "NV902D_SET_MME_SHADOW_SCRATCH(217)";
    case NV902D_SET_MME_SHADOW_SCRATCH(218):
        return "NV902D_SET_MME_SHADOW_SCRATCH(218)";
    case NV902D_SET_MME_SHADOW_SCRATCH(219):
        return "NV902D_SET_MME_SHADOW_SCRATCH(219)";
    case NV902D_SET_MME_SHADOW_SCRATCH(220):
        return "NV902D_SET_MME_SHADOW_SCRATCH(220)";
    case NV902D_SET_MME_SHADOW_SCRATCH(221):
        return "NV902D_SET_MME_SHADOW_SCRATCH(221)";
    case NV902D_SET_MME_SHADOW_SCRATCH(222):
        return "NV902D_SET_MME_SHADOW_SCRATCH(222)";
    case NV902D_SET_MME_SHADOW_SCRATCH(223):
        return "NV902D_SET_MME_SHADOW_SCRATCH(223)";
    case NV902D_SET_MME_SHADOW_SCRATCH(224):
        return "NV902D_SET_MME_SHADOW_SCRATCH(224)";
    case NV902D_SET_MME_SHADOW_SCRATCH(225):
        return "NV902D_SET_MME_SHADOW_SCRATCH(225)";
    case NV902D_SET_MME_SHADOW_SCRATCH(226):
        return "NV902D_SET_MME_SHADOW_SCRATCH(226)";
    case NV902D_SET_MME_SHADOW_SCRATCH(227):
        return "NV902D_SET_MME_SHADOW_SCRATCH(227)";
    case NV902D_SET_MME_SHADOW_SCRATCH(228):
        return "NV902D_SET_MME_SHADOW_SCRATCH(228)";
    case NV902D_SET_MME_SHADOW_SCRATCH(229):
        return "NV902D_SET_MME_SHADOW_SCRATCH(229)";
    case NV902D_SET_MME_SHADOW_SCRATCH(230):
        return "NV902D_SET_MME_SHADOW_SCRATCH(230)";
    case NV902D_SET_MME_SHADOW_SCRATCH(231):
        return "NV902D_SET_MME_SHADOW_SCRATCH(231)";
    case NV902D_SET_MME_SHADOW_SCRATCH(232):
        return "NV902D_SET_MME_SHADOW_SCRATCH(232)";
    case NV902D_SET_MME_SHADOW_SCRATCH(233):
        return "NV902D_SET_MME_SHADOW_SCRATCH(233)";
    case NV902D_SET_MME_SHADOW_SCRATCH(234):
        return "NV902D_SET_MME_SHADOW_SCRATCH(234)";
    case NV902D_SET_MME_SHADOW_SCRATCH(235):
        return "NV902D_SET_MME_SHADOW_SCRATCH(235)";
    case NV902D_SET_MME_SHADOW_SCRATCH(236):
        return "NV902D_SET_MME_SHADOW_SCRATCH(236)";
    case NV902D_SET_MME_SHADOW_SCRATCH(237):
        return "NV902D_SET_MME_SHADOW_SCRATCH(237)";
    case NV902D_SET_MME_SHADOW_SCRATCH(238):
        return "NV902D_SET_MME_SHADOW_SCRATCH(238)";
    case NV902D_SET_MME_SHADOW_SCRATCH(239):
        return "NV902D_SET_MME_SHADOW_SCRATCH(239)";
    case NV902D_SET_MME_SHADOW_SCRATCH(240):
        return "NV902D_SET_MME_SHADOW_SCRATCH(240)";
    case NV902D_SET_MME_SHADOW_SCRATCH(241):
        return "NV902D_SET_MME_SHADOW_SCRATCH(241)";
    case NV902D_SET_MME_SHADOW_SCRATCH(242):
        return "NV902D_SET_MME_SHADOW_SCRATCH(242)";
    case NV902D_SET_MME_SHADOW_SCRATCH(243):
        return "NV902D_SET_MME_SHADOW_SCRATCH(243)";
    case NV902D_SET_MME_SHADOW_SCRATCH(244):
        return "NV902D_SET_MME_SHADOW_SCRATCH(244)";
    case NV902D_SET_MME_SHADOW_SCRATCH(245):
        return "NV902D_SET_MME_SHADOW_SCRATCH(245)";
    case NV902D_SET_MME_SHADOW_SCRATCH(246):
        return "NV902D_SET_MME_SHADOW_SCRATCH(246)";
    case NV902D_SET_MME_SHADOW_SCRATCH(247):
        return "NV902D_SET_MME_SHADOW_SCRATCH(247)";
    case NV902D_SET_MME_SHADOW_SCRATCH(248):
        return "NV902D_SET_MME_SHADOW_SCRATCH(248)";
    case NV902D_SET_MME_SHADOW_SCRATCH(249):
        return "NV902D_SET_MME_SHADOW_SCRATCH(249)";
    case NV902D_SET_MME_SHADOW_SCRATCH(250):
        return "NV902D_SET_MME_SHADOW_SCRATCH(250)";
    case NV902D_SET_MME_SHADOW_SCRATCH(251):
        return "NV902D_SET_MME_SHADOW_SCRATCH(251)";
    case NV902D_SET_MME_SHADOW_SCRATCH(252):
        return "NV902D_SET_MME_SHADOW_SCRATCH(252)";
    case NV902D_SET_MME_SHADOW_SCRATCH(253):
        return "NV902D_SET_MME_SHADOW_SCRATCH(253)";
    case NV902D_SET_MME_SHADOW_SCRATCH(254):
        return "NV902D_SET_MME_SHADOW_SCRATCH(254)";
    case NV902D_SET_MME_SHADOW_SCRATCH(255):
        return "NV902D_SET_MME_SHADOW_SCRATCH(255)";
    case NV902D_CALL_MME_MACRO(0):
        return "NV902D_CALL_MME_MACRO(0)";
    case NV902D_CALL_MME_MACRO(1):
        return "NV902D_CALL_MME_MACRO(1)";
    case NV902D_CALL_MME_MACRO(2):
        return "NV902D_CALL_MME_MACRO(2)";
    case NV902D_CALL_MME_MACRO(3):
        return "NV902D_CALL_MME_MACRO(3)";
    case NV902D_CALL_MME_MACRO(4):
        return "NV902D_CALL_MME_MACRO(4)";
    case NV902D_CALL_MME_MACRO(5):
        return "NV902D_CALL_MME_MACRO(5)";
    case NV902D_CALL_MME_MACRO(6):
        return "NV902D_CALL_MME_MACRO(6)";
    case NV902D_CALL_MME_MACRO(7):
        return "NV902D_CALL_MME_MACRO(7)";
    case NV902D_CALL_MME_MACRO(8):
        return "NV902D_CALL_MME_MACRO(8)";
    case NV902D_CALL_MME_MACRO(9):
        return "NV902D_CALL_MME_MACRO(9)";
    case NV902D_CALL_MME_MACRO(10):
        return "NV902D_CALL_MME_MACRO(10)";
    case NV902D_CALL_MME_MACRO(11):
        return "NV902D_CALL_MME_MACRO(11)";
    case NV902D_CALL_MME_MACRO(12):
        return "NV902D_CALL_MME_MACRO(12)";
    case NV902D_CALL_MME_MACRO(13):
        return "NV902D_CALL_MME_MACRO(13)";
    case NV902D_CALL_MME_MACRO(14):
        return "NV902D_CALL_MME_MACRO(14)";
    case NV902D_CALL_MME_MACRO(15):
        return "NV902D_CALL_MME_MACRO(15)";
    case NV902D_CALL_MME_MACRO(16):
        return "NV902D_CALL_MME_MACRO(16)";
    case NV902D_CALL_MME_MACRO(17):
        return "NV902D_CALL_MME_MACRO(17)";
    case NV902D_CALL_MME_MACRO(18):
        return "NV902D_CALL_MME_MACRO(18)";
    case NV902D_CALL_MME_MACRO(19):
        return "NV902D_CALL_MME_MACRO(19)";
    case NV902D_CALL_MME_MACRO(20):
        return "NV902D_CALL_MME_MACRO(20)";
    case NV902D_CALL_MME_MACRO(21):
        return "NV902D_CALL_MME_MACRO(21)";
    case NV902D_CALL_MME_MACRO(22):
        return "NV902D_CALL_MME_MACRO(22)";
    case NV902D_CALL_MME_MACRO(23):
        return "NV902D_CALL_MME_MACRO(23)";
    case NV902D_CALL_MME_MACRO(24):
        return "NV902D_CALL_MME_MACRO(24)";
    case NV902D_CALL_MME_MACRO(25):
        return "NV902D_CALL_MME_MACRO(25)";
    case NV902D_CALL_MME_MACRO(26):
        return "NV902D_CALL_MME_MACRO(26)";
    case NV902D_CALL_MME_MACRO(27):
        return "NV902D_CALL_MME_MACRO(27)";
    case NV902D_CALL_MME_MACRO(28):
        return "NV902D_CALL_MME_MACRO(28)";
    case NV902D_CALL_MME_MACRO(29):
        return "NV902D_CALL_MME_MACRO(29)";
    case NV902D_CALL_MME_MACRO(30):
        return "NV902D_CALL_MME_MACRO(30)";
    case NV902D_CALL_MME_MACRO(31):
        return "NV902D_CALL_MME_MACRO(31)";
    case NV902D_CALL_MME_MACRO(32):
        return "NV902D_CALL_MME_MACRO(32)";
    case NV902D_CALL_MME_MACRO(33):
        return "NV902D_CALL_MME_MACRO(33)";
    case NV902D_CALL_MME_MACRO(34):
        return "NV902D_CALL_MME_MACRO(34)";
    case NV902D_CALL_MME_MACRO(35):
        return "NV902D_CALL_MME_MACRO(35)";
    case NV902D_CALL_MME_MACRO(36):
        return "NV902D_CALL_MME_MACRO(36)";
    case NV902D_CALL_MME_MACRO(37):
        return "NV902D_CALL_MME_MACRO(37)";
    case NV902D_CALL_MME_MACRO(38):
        return "NV902D_CALL_MME_MACRO(38)";
    case NV902D_CALL_MME_MACRO(39):
        return "NV902D_CALL_MME_MACRO(39)";
    case NV902D_CALL_MME_MACRO(40):
        return "NV902D_CALL_MME_MACRO(40)";
    case NV902D_CALL_MME_MACRO(41):
        return "NV902D_CALL_MME_MACRO(41)";
    case NV902D_CALL_MME_MACRO(42):
        return "NV902D_CALL_MME_MACRO(42)";
    case NV902D_CALL_MME_MACRO(43):
        return "NV902D_CALL_MME_MACRO(43)";
    case NV902D_CALL_MME_MACRO(44):
        return "NV902D_CALL_MME_MACRO(44)";
    case NV902D_CALL_MME_MACRO(45):
        return "NV902D_CALL_MME_MACRO(45)";
    case NV902D_CALL_MME_MACRO(46):
        return "NV902D_CALL_MME_MACRO(46)";
    case NV902D_CALL_MME_MACRO(47):
        return "NV902D_CALL_MME_MACRO(47)";
    case NV902D_CALL_MME_MACRO(48):
        return "NV902D_CALL_MME_MACRO(48)";
    case NV902D_CALL_MME_MACRO(49):
        return "NV902D_CALL_MME_MACRO(49)";
    case NV902D_CALL_MME_MACRO(50):
        return "NV902D_CALL_MME_MACRO(50)";
    case NV902D_CALL_MME_MACRO(51):
        return "NV902D_CALL_MME_MACRO(51)";
    case NV902D_CALL_MME_MACRO(52):
        return "NV902D_CALL_MME_MACRO(52)";
    case NV902D_CALL_MME_MACRO(53):
        return "NV902D_CALL_MME_MACRO(53)";
    case NV902D_CALL_MME_MACRO(54):
        return "NV902D_CALL_MME_MACRO(54)";
    case NV902D_CALL_MME_MACRO(55):
        return "NV902D_CALL_MME_MACRO(55)";
    case NV902D_CALL_MME_MACRO(56):
        return "NV902D_CALL_MME_MACRO(56)";
    case NV902D_CALL_MME_MACRO(57):
        return "NV902D_CALL_MME_MACRO(57)";
    case NV902D_CALL_MME_MACRO(58):
        return "NV902D_CALL_MME_MACRO(58)";
    case NV902D_CALL_MME_MACRO(59):
        return "NV902D_CALL_MME_MACRO(59)";
    case NV902D_CALL_MME_MACRO(60):
        return "NV902D_CALL_MME_MACRO(60)";
    case NV902D_CALL_MME_MACRO(61):
        return "NV902D_CALL_MME_MACRO(61)";
    case NV902D_CALL_MME_MACRO(62):
        return "NV902D_CALL_MME_MACRO(62)";
    case NV902D_CALL_MME_MACRO(63):
        return "NV902D_CALL_MME_MACRO(63)";
    case NV902D_CALL_MME_MACRO(64):
        return "NV902D_CALL_MME_MACRO(64)";
    case NV902D_CALL_MME_MACRO(65):
        return "NV902D_CALL_MME_MACRO(65)";
    case NV902D_CALL_MME_MACRO(66):
        return "NV902D_CALL_MME_MACRO(66)";
    case NV902D_CALL_MME_MACRO(67):
        return "NV902D_CALL_MME_MACRO(67)";
    case NV902D_CALL_MME_MACRO(68):
        return "NV902D_CALL_MME_MACRO(68)";
    case NV902D_CALL_MME_MACRO(69):
        return "NV902D_CALL_MME_MACRO(69)";
    case NV902D_CALL_MME_MACRO(70):
        return "NV902D_CALL_MME_MACRO(70)";
    case NV902D_CALL_MME_MACRO(71):
        return "NV902D_CALL_MME_MACRO(71)";
    case NV902D_CALL_MME_MACRO(72):
        return "NV902D_CALL_MME_MACRO(72)";
    case NV902D_CALL_MME_MACRO(73):
        return "NV902D_CALL_MME_MACRO(73)";
    case NV902D_CALL_MME_MACRO(74):
        return "NV902D_CALL_MME_MACRO(74)";
    case NV902D_CALL_MME_MACRO(75):
        return "NV902D_CALL_MME_MACRO(75)";
    case NV902D_CALL_MME_MACRO(76):
        return "NV902D_CALL_MME_MACRO(76)";
    case NV902D_CALL_MME_MACRO(77):
        return "NV902D_CALL_MME_MACRO(77)";
    case NV902D_CALL_MME_MACRO(78):
        return "NV902D_CALL_MME_MACRO(78)";
    case NV902D_CALL_MME_MACRO(79):
        return "NV902D_CALL_MME_MACRO(79)";
    case NV902D_CALL_MME_MACRO(80):
        return "NV902D_CALL_MME_MACRO(80)";
    case NV902D_CALL_MME_MACRO(81):
        return "NV902D_CALL_MME_MACRO(81)";
    case NV902D_CALL_MME_MACRO(82):
        return "NV902D_CALL_MME_MACRO(82)";
    case NV902D_CALL_MME_MACRO(83):
        return "NV902D_CALL_MME_MACRO(83)";
    case NV902D_CALL_MME_MACRO(84):
        return "NV902D_CALL_MME_MACRO(84)";
    case NV902D_CALL_MME_MACRO(85):
        return "NV902D_CALL_MME_MACRO(85)";
    case NV902D_CALL_MME_MACRO(86):
        return "NV902D_CALL_MME_MACRO(86)";
    case NV902D_CALL_MME_MACRO(87):
        return "NV902D_CALL_MME_MACRO(87)";
    case NV902D_CALL_MME_MACRO(88):
        return "NV902D_CALL_MME_MACRO(88)";
    case NV902D_CALL_MME_MACRO(89):
        return "NV902D_CALL_MME_MACRO(89)";
    case NV902D_CALL_MME_MACRO(90):
        return "NV902D_CALL_MME_MACRO(90)";
    case NV902D_CALL_MME_MACRO(91):
        return "NV902D_CALL_MME_MACRO(91)";
    case NV902D_CALL_MME_MACRO(92):
        return "NV902D_CALL_MME_MACRO(92)";
    case NV902D_CALL_MME_MACRO(93):
        return "NV902D_CALL_MME_MACRO(93)";
    case NV902D_CALL_MME_MACRO(94):
        return "NV902D_CALL_MME_MACRO(94)";
    case NV902D_CALL_MME_MACRO(95):
        return "NV902D_CALL_MME_MACRO(95)";
    case NV902D_CALL_MME_MACRO(96):
        return "NV902D_CALL_MME_MACRO(96)";
    case NV902D_CALL_MME_MACRO(97):
        return "NV902D_CALL_MME_MACRO(97)";
    case NV902D_CALL_MME_MACRO(98):
        return "NV902D_CALL_MME_MACRO(98)";
    case NV902D_CALL_MME_MACRO(99):
        return "NV902D_CALL_MME_MACRO(99)";
    case NV902D_CALL_MME_MACRO(100):
        return "NV902D_CALL_MME_MACRO(100)";
    case NV902D_CALL_MME_MACRO(101):
        return "NV902D_CALL_MME_MACRO(101)";
    case NV902D_CALL_MME_MACRO(102):
        return "NV902D_CALL_MME_MACRO(102)";
    case NV902D_CALL_MME_MACRO(103):
        return "NV902D_CALL_MME_MACRO(103)";
    case NV902D_CALL_MME_MACRO(104):
        return "NV902D_CALL_MME_MACRO(104)";
    case NV902D_CALL_MME_MACRO(105):
        return "NV902D_CALL_MME_MACRO(105)";
    case NV902D_CALL_MME_MACRO(106):
        return "NV902D_CALL_MME_MACRO(106)";
    case NV902D_CALL_MME_MACRO(107):
        return "NV902D_CALL_MME_MACRO(107)";
    case NV902D_CALL_MME_MACRO(108):
        return "NV902D_CALL_MME_MACRO(108)";
    case NV902D_CALL_MME_MACRO(109):
        return "NV902D_CALL_MME_MACRO(109)";
    case NV902D_CALL_MME_MACRO(110):
        return "NV902D_CALL_MME_MACRO(110)";
    case NV902D_CALL_MME_MACRO(111):
        return "NV902D_CALL_MME_MACRO(111)";
    case NV902D_CALL_MME_MACRO(112):
        return "NV902D_CALL_MME_MACRO(112)";
    case NV902D_CALL_MME_MACRO(113):
        return "NV902D_CALL_MME_MACRO(113)";
    case NV902D_CALL_MME_MACRO(114):
        return "NV902D_CALL_MME_MACRO(114)";
    case NV902D_CALL_MME_MACRO(115):
        return "NV902D_CALL_MME_MACRO(115)";
    case NV902D_CALL_MME_MACRO(116):
        return "NV902D_CALL_MME_MACRO(116)";
    case NV902D_CALL_MME_MACRO(117):
        return "NV902D_CALL_MME_MACRO(117)";
    case NV902D_CALL_MME_MACRO(118):
        return "NV902D_CALL_MME_MACRO(118)";
    case NV902D_CALL_MME_MACRO(119):
        return "NV902D_CALL_MME_MACRO(119)";
    case NV902D_CALL_MME_MACRO(120):
        return "NV902D_CALL_MME_MACRO(120)";
    case NV902D_CALL_MME_MACRO(121):
        return "NV902D_CALL_MME_MACRO(121)";
    case NV902D_CALL_MME_MACRO(122):
        return "NV902D_CALL_MME_MACRO(122)";
    case NV902D_CALL_MME_MACRO(123):
        return "NV902D_CALL_MME_MACRO(123)";
    case NV902D_CALL_MME_MACRO(124):
        return "NV902D_CALL_MME_MACRO(124)";
    case NV902D_CALL_MME_MACRO(125):
        return "NV902D_CALL_MME_MACRO(125)";
    case NV902D_CALL_MME_MACRO(126):
        return "NV902D_CALL_MME_MACRO(126)";
    case NV902D_CALL_MME_MACRO(127):
        return "NV902D_CALL_MME_MACRO(127)";
    case NV902D_CALL_MME_MACRO(128):
        return "NV902D_CALL_MME_MACRO(128)";
    case NV902D_CALL_MME_MACRO(129):
        return "NV902D_CALL_MME_MACRO(129)";
    case NV902D_CALL_MME_MACRO(130):
        return "NV902D_CALL_MME_MACRO(130)";
    case NV902D_CALL_MME_MACRO(131):
        return "NV902D_CALL_MME_MACRO(131)";
    case NV902D_CALL_MME_MACRO(132):
        return "NV902D_CALL_MME_MACRO(132)";
    case NV902D_CALL_MME_MACRO(133):
        return "NV902D_CALL_MME_MACRO(133)";
    case NV902D_CALL_MME_MACRO(134):
        return "NV902D_CALL_MME_MACRO(134)";
    case NV902D_CALL_MME_MACRO(135):
        return "NV902D_CALL_MME_MACRO(135)";
    case NV902D_CALL_MME_MACRO(136):
        return "NV902D_CALL_MME_MACRO(136)";
    case NV902D_CALL_MME_MACRO(137):
        return "NV902D_CALL_MME_MACRO(137)";
    case NV902D_CALL_MME_MACRO(138):
        return "NV902D_CALL_MME_MACRO(138)";
    case NV902D_CALL_MME_MACRO(139):
        return "NV902D_CALL_MME_MACRO(139)";
    case NV902D_CALL_MME_MACRO(140):
        return "NV902D_CALL_MME_MACRO(140)";
    case NV902D_CALL_MME_MACRO(141):
        return "NV902D_CALL_MME_MACRO(141)";
    case NV902D_CALL_MME_MACRO(142):
        return "NV902D_CALL_MME_MACRO(142)";
    case NV902D_CALL_MME_MACRO(143):
        return "NV902D_CALL_MME_MACRO(143)";
    case NV902D_CALL_MME_MACRO(144):
        return "NV902D_CALL_MME_MACRO(144)";
    case NV902D_CALL_MME_MACRO(145):
        return "NV902D_CALL_MME_MACRO(145)";
    case NV902D_CALL_MME_MACRO(146):
        return "NV902D_CALL_MME_MACRO(146)";
    case NV902D_CALL_MME_MACRO(147):
        return "NV902D_CALL_MME_MACRO(147)";
    case NV902D_CALL_MME_MACRO(148):
        return "NV902D_CALL_MME_MACRO(148)";
    case NV902D_CALL_MME_MACRO(149):
        return "NV902D_CALL_MME_MACRO(149)";
    case NV902D_CALL_MME_MACRO(150):
        return "NV902D_CALL_MME_MACRO(150)";
    case NV902D_CALL_MME_MACRO(151):
        return "NV902D_CALL_MME_MACRO(151)";
    case NV902D_CALL_MME_MACRO(152):
        return "NV902D_CALL_MME_MACRO(152)";
    case NV902D_CALL_MME_MACRO(153):
        return "NV902D_CALL_MME_MACRO(153)";
    case NV902D_CALL_MME_MACRO(154):
        return "NV902D_CALL_MME_MACRO(154)";
    case NV902D_CALL_MME_MACRO(155):
        return "NV902D_CALL_MME_MACRO(155)";
    case NV902D_CALL_MME_MACRO(156):
        return "NV902D_CALL_MME_MACRO(156)";
    case NV902D_CALL_MME_MACRO(157):
        return "NV902D_CALL_MME_MACRO(157)";
    case NV902D_CALL_MME_MACRO(158):
        return "NV902D_CALL_MME_MACRO(158)";
    case NV902D_CALL_MME_MACRO(159):
        return "NV902D_CALL_MME_MACRO(159)";
    case NV902D_CALL_MME_MACRO(160):
        return "NV902D_CALL_MME_MACRO(160)";
    case NV902D_CALL_MME_MACRO(161):
        return "NV902D_CALL_MME_MACRO(161)";
    case NV902D_CALL_MME_MACRO(162):
        return "NV902D_CALL_MME_MACRO(162)";
    case NV902D_CALL_MME_MACRO(163):
        return "NV902D_CALL_MME_MACRO(163)";
    case NV902D_CALL_MME_MACRO(164):
        return "NV902D_CALL_MME_MACRO(164)";
    case NV902D_CALL_MME_MACRO(165):
        return "NV902D_CALL_MME_MACRO(165)";
    case NV902D_CALL_MME_MACRO(166):
        return "NV902D_CALL_MME_MACRO(166)";
    case NV902D_CALL_MME_MACRO(167):
        return "NV902D_CALL_MME_MACRO(167)";
    case NV902D_CALL_MME_MACRO(168):
        return "NV902D_CALL_MME_MACRO(168)";
    case NV902D_CALL_MME_MACRO(169):
        return "NV902D_CALL_MME_MACRO(169)";
    case NV902D_CALL_MME_MACRO(170):
        return "NV902D_CALL_MME_MACRO(170)";
    case NV902D_CALL_MME_MACRO(171):
        return "NV902D_CALL_MME_MACRO(171)";
    case NV902D_CALL_MME_MACRO(172):
        return "NV902D_CALL_MME_MACRO(172)";
    case NV902D_CALL_MME_MACRO(173):
        return "NV902D_CALL_MME_MACRO(173)";
    case NV902D_CALL_MME_MACRO(174):
        return "NV902D_CALL_MME_MACRO(174)";
    case NV902D_CALL_MME_MACRO(175):
        return "NV902D_CALL_MME_MACRO(175)";
    case NV902D_CALL_MME_MACRO(176):
        return "NV902D_CALL_MME_MACRO(176)";
    case NV902D_CALL_MME_MACRO(177):
        return "NV902D_CALL_MME_MACRO(177)";
    case NV902D_CALL_MME_MACRO(178):
        return "NV902D_CALL_MME_MACRO(178)";
    case NV902D_CALL_MME_MACRO(179):
        return "NV902D_CALL_MME_MACRO(179)";
    case NV902D_CALL_MME_MACRO(180):
        return "NV902D_CALL_MME_MACRO(180)";
    case NV902D_CALL_MME_MACRO(181):
        return "NV902D_CALL_MME_MACRO(181)";
    case NV902D_CALL_MME_MACRO(182):
        return "NV902D_CALL_MME_MACRO(182)";
    case NV902D_CALL_MME_MACRO(183):
        return "NV902D_CALL_MME_MACRO(183)";
    case NV902D_CALL_MME_MACRO(184):
        return "NV902D_CALL_MME_MACRO(184)";
    case NV902D_CALL_MME_MACRO(185):
        return "NV902D_CALL_MME_MACRO(185)";
    case NV902D_CALL_MME_MACRO(186):
        return "NV902D_CALL_MME_MACRO(186)";
    case NV902D_CALL_MME_MACRO(187):
        return "NV902D_CALL_MME_MACRO(187)";
    case NV902D_CALL_MME_MACRO(188):
        return "NV902D_CALL_MME_MACRO(188)";
    case NV902D_CALL_MME_MACRO(189):
        return "NV902D_CALL_MME_MACRO(189)";
    case NV902D_CALL_MME_MACRO(190):
        return "NV902D_CALL_MME_MACRO(190)";
    case NV902D_CALL_MME_MACRO(191):
        return "NV902D_CALL_MME_MACRO(191)";
    case NV902D_CALL_MME_MACRO(192):
        return "NV902D_CALL_MME_MACRO(192)";
    case NV902D_CALL_MME_MACRO(193):
        return "NV902D_CALL_MME_MACRO(193)";
    case NV902D_CALL_MME_MACRO(194):
        return "NV902D_CALL_MME_MACRO(194)";
    case NV902D_CALL_MME_MACRO(195):
        return "NV902D_CALL_MME_MACRO(195)";
    case NV902D_CALL_MME_MACRO(196):
        return "NV902D_CALL_MME_MACRO(196)";
    case NV902D_CALL_MME_MACRO(197):
        return "NV902D_CALL_MME_MACRO(197)";
    case NV902D_CALL_MME_MACRO(198):
        return "NV902D_CALL_MME_MACRO(198)";
    case NV902D_CALL_MME_MACRO(199):
        return "NV902D_CALL_MME_MACRO(199)";
    case NV902D_CALL_MME_MACRO(200):
        return "NV902D_CALL_MME_MACRO(200)";
    case NV902D_CALL_MME_MACRO(201):
        return "NV902D_CALL_MME_MACRO(201)";
    case NV902D_CALL_MME_MACRO(202):
        return "NV902D_CALL_MME_MACRO(202)";
    case NV902D_CALL_MME_MACRO(203):
        return "NV902D_CALL_MME_MACRO(203)";
    case NV902D_CALL_MME_MACRO(204):
        return "NV902D_CALL_MME_MACRO(204)";
    case NV902D_CALL_MME_MACRO(205):
        return "NV902D_CALL_MME_MACRO(205)";
    case NV902D_CALL_MME_MACRO(206):
        return "NV902D_CALL_MME_MACRO(206)";
    case NV902D_CALL_MME_MACRO(207):
        return "NV902D_CALL_MME_MACRO(207)";
    case NV902D_CALL_MME_MACRO(208):
        return "NV902D_CALL_MME_MACRO(208)";
    case NV902D_CALL_MME_MACRO(209):
        return "NV902D_CALL_MME_MACRO(209)";
    case NV902D_CALL_MME_MACRO(210):
        return "NV902D_CALL_MME_MACRO(210)";
    case NV902D_CALL_MME_MACRO(211):
        return "NV902D_CALL_MME_MACRO(211)";
    case NV902D_CALL_MME_MACRO(212):
        return "NV902D_CALL_MME_MACRO(212)";
    case NV902D_CALL_MME_MACRO(213):
        return "NV902D_CALL_MME_MACRO(213)";
    case NV902D_CALL_MME_MACRO(214):
        return "NV902D_CALL_MME_MACRO(214)";
    case NV902D_CALL_MME_MACRO(215):
        return "NV902D_CALL_MME_MACRO(215)";
    case NV902D_CALL_MME_MACRO(216):
        return "NV902D_CALL_MME_MACRO(216)";
    case NV902D_CALL_MME_MACRO(217):
        return "NV902D_CALL_MME_MACRO(217)";
    case NV902D_CALL_MME_MACRO(218):
        return "NV902D_CALL_MME_MACRO(218)";
    case NV902D_CALL_MME_MACRO(219):
        return "NV902D_CALL_MME_MACRO(219)";
    case NV902D_CALL_MME_MACRO(220):
        return "NV902D_CALL_MME_MACRO(220)";
    case NV902D_CALL_MME_MACRO(221):
        return "NV902D_CALL_MME_MACRO(221)";
    case NV902D_CALL_MME_MACRO(222):
        return "NV902D_CALL_MME_MACRO(222)";
    case NV902D_CALL_MME_MACRO(223):
        return "NV902D_CALL_MME_MACRO(223)";
    case NV902D_CALL_MME_MACRO(224):
        return "NV902D_CALL_MME_MACRO(224)";
    case NV902D_CALL_MME_MACRO(225):
        return "NV902D_CALL_MME_MACRO(225)";
    case NV902D_CALL_MME_MACRO(226):
        return "NV902D_CALL_MME_MACRO(226)";
    case NV902D_CALL_MME_MACRO(227):
        return "NV902D_CALL_MME_MACRO(227)";
    case NV902D_CALL_MME_MACRO(228):
        return "NV902D_CALL_MME_MACRO(228)";
    case NV902D_CALL_MME_MACRO(229):
        return "NV902D_CALL_MME_MACRO(229)";
    case NV902D_CALL_MME_MACRO(230):
        return "NV902D_CALL_MME_MACRO(230)";
    case NV902D_CALL_MME_MACRO(231):
        return "NV902D_CALL_MME_MACRO(231)";
    case NV902D_CALL_MME_MACRO(232):
        return "NV902D_CALL_MME_MACRO(232)";
    case NV902D_CALL_MME_MACRO(233):
        return "NV902D_CALL_MME_MACRO(233)";
    case NV902D_CALL_MME_MACRO(234):
        return "NV902D_CALL_MME_MACRO(234)";
    case NV902D_CALL_MME_MACRO(235):
        return "NV902D_CALL_MME_MACRO(235)";
    case NV902D_CALL_MME_MACRO(236):
        return "NV902D_CALL_MME_MACRO(236)";
    case NV902D_CALL_MME_MACRO(237):
        return "NV902D_CALL_MME_MACRO(237)";
    case NV902D_CALL_MME_MACRO(238):
        return "NV902D_CALL_MME_MACRO(238)";
    case NV902D_CALL_MME_MACRO(239):
        return "NV902D_CALL_MME_MACRO(239)";
    case NV902D_CALL_MME_MACRO(240):
        return "NV902D_CALL_MME_MACRO(240)";
    case NV902D_CALL_MME_MACRO(241):
        return "NV902D_CALL_MME_MACRO(241)";
    case NV902D_CALL_MME_MACRO(242):
        return "NV902D_CALL_MME_MACRO(242)";
    case NV902D_CALL_MME_MACRO(243):
        return "NV902D_CALL_MME_MACRO(243)";
    case NV902D_CALL_MME_MACRO(244):
        return "NV902D_CALL_MME_MACRO(244)";
    case NV902D_CALL_MME_MACRO(245):
        return "NV902D_CALL_MME_MACRO(245)";
    case NV902D_CALL_MME_MACRO(246):
        return "NV902D_CALL_MME_MACRO(246)";
    case NV902D_CALL_MME_MACRO(247):
        return "NV902D_CALL_MME_MACRO(247)";
    case NV902D_CALL_MME_MACRO(248):
        return "NV902D_CALL_MME_MACRO(248)";
    case NV902D_CALL_MME_MACRO(249):
        return "NV902D_CALL_MME_MACRO(249)";
    case NV902D_CALL_MME_MACRO(250):
        return "NV902D_CALL_MME_MACRO(250)";
    case NV902D_CALL_MME_MACRO(251):
        return "NV902D_CALL_MME_MACRO(251)";
    case NV902D_CALL_MME_MACRO(252):
        return "NV902D_CALL_MME_MACRO(252)";
    case NV902D_CALL_MME_MACRO(253):
        return "NV902D_CALL_MME_MACRO(253)";
    case NV902D_CALL_MME_MACRO(254):
        return "NV902D_CALL_MME_MACRO(254)";
    case NV902D_CALL_MME_MACRO(255):
        return "NV902D_CALL_MME_MACRO(255)";
    case NV902D_CALL_MME_DATA(0):
        return "NV902D_CALL_MME_DATA(0)";
    case NV902D_CALL_MME_DATA(1):
        return "NV902D_CALL_MME_DATA(1)";
    case NV902D_CALL_MME_DATA(2):
        return "NV902D_CALL_MME_DATA(2)";
    case NV902D_CALL_MME_DATA(3):
        return "NV902D_CALL_MME_DATA(3)";
    case NV902D_CALL_MME_DATA(4):
        return "NV902D_CALL_MME_DATA(4)";
    case NV902D_CALL_MME_DATA(5):
        return "NV902D_CALL_MME_DATA(5)";
    case NV902D_CALL_MME_DATA(6):
        return "NV902D_CALL_MME_DATA(6)";
    case NV902D_CALL_MME_DATA(7):
        return "NV902D_CALL_MME_DATA(7)";
    case NV902D_CALL_MME_DATA(8):
        return "NV902D_CALL_MME_DATA(8)";
    case NV902D_CALL_MME_DATA(9):
        return "NV902D_CALL_MME_DATA(9)";
    case NV902D_CALL_MME_DATA(10):
        return "NV902D_CALL_MME_DATA(10)";
    case NV902D_CALL_MME_DATA(11):
        return "NV902D_CALL_MME_DATA(11)";
    case NV902D_CALL_MME_DATA(12):
        return "NV902D_CALL_MME_DATA(12)";
    case NV902D_CALL_MME_DATA(13):
        return "NV902D_CALL_MME_DATA(13)";
    case NV902D_CALL_MME_DATA(14):
        return "NV902D_CALL_MME_DATA(14)";
    case NV902D_CALL_MME_DATA(15):
        return "NV902D_CALL_MME_DATA(15)";
    case NV902D_CALL_MME_DATA(16):
        return "NV902D_CALL_MME_DATA(16)";
    case NV902D_CALL_MME_DATA(17):
        return "NV902D_CALL_MME_DATA(17)";
    case NV902D_CALL_MME_DATA(18):
        return "NV902D_CALL_MME_DATA(18)";
    case NV902D_CALL_MME_DATA(19):
        return "NV902D_CALL_MME_DATA(19)";
    case NV902D_CALL_MME_DATA(20):
        return "NV902D_CALL_MME_DATA(20)";
    case NV902D_CALL_MME_DATA(21):
        return "NV902D_CALL_MME_DATA(21)";
    case NV902D_CALL_MME_DATA(22):
        return "NV902D_CALL_MME_DATA(22)";
    case NV902D_CALL_MME_DATA(23):
        return "NV902D_CALL_MME_DATA(23)";
    case NV902D_CALL_MME_DATA(24):
        return "NV902D_CALL_MME_DATA(24)";
    case NV902D_CALL_MME_DATA(25):
        return "NV902D_CALL_MME_DATA(25)";
    case NV902D_CALL_MME_DATA(26):
        return "NV902D_CALL_MME_DATA(26)";
    case NV902D_CALL_MME_DATA(27):
        return "NV902D_CALL_MME_DATA(27)";
    case NV902D_CALL_MME_DATA(28):
        return "NV902D_CALL_MME_DATA(28)";
    case NV902D_CALL_MME_DATA(29):
        return "NV902D_CALL_MME_DATA(29)";
    case NV902D_CALL_MME_DATA(30):
        return "NV902D_CALL_MME_DATA(30)";
    case NV902D_CALL_MME_DATA(31):
        return "NV902D_CALL_MME_DATA(31)";
    case NV902D_CALL_MME_DATA(32):
        return "NV902D_CALL_MME_DATA(32)";
    case NV902D_CALL_MME_DATA(33):
        return "NV902D_CALL_MME_DATA(33)";
    case NV902D_CALL_MME_DATA(34):
        return "NV902D_CALL_MME_DATA(34)";
    case NV902D_CALL_MME_DATA(35):
        return "NV902D_CALL_MME_DATA(35)";
    case NV902D_CALL_MME_DATA(36):
        return "NV902D_CALL_MME_DATA(36)";
    case NV902D_CALL_MME_DATA(37):
        return "NV902D_CALL_MME_DATA(37)";
    case NV902D_CALL_MME_DATA(38):
        return "NV902D_CALL_MME_DATA(38)";
    case NV902D_CALL_MME_DATA(39):
        return "NV902D_CALL_MME_DATA(39)";
    case NV902D_CALL_MME_DATA(40):
        return "NV902D_CALL_MME_DATA(40)";
    case NV902D_CALL_MME_DATA(41):
        return "NV902D_CALL_MME_DATA(41)";
    case NV902D_CALL_MME_DATA(42):
        return "NV902D_CALL_MME_DATA(42)";
    case NV902D_CALL_MME_DATA(43):
        return "NV902D_CALL_MME_DATA(43)";
    case NV902D_CALL_MME_DATA(44):
        return "NV902D_CALL_MME_DATA(44)";
    case NV902D_CALL_MME_DATA(45):
        return "NV902D_CALL_MME_DATA(45)";
    case NV902D_CALL_MME_DATA(46):
        return "NV902D_CALL_MME_DATA(46)";
    case NV902D_CALL_MME_DATA(47):
        return "NV902D_CALL_MME_DATA(47)";
    case NV902D_CALL_MME_DATA(48):
        return "NV902D_CALL_MME_DATA(48)";
    case NV902D_CALL_MME_DATA(49):
        return "NV902D_CALL_MME_DATA(49)";
    case NV902D_CALL_MME_DATA(50):
        return "NV902D_CALL_MME_DATA(50)";
    case NV902D_CALL_MME_DATA(51):
        return "NV902D_CALL_MME_DATA(51)";
    case NV902D_CALL_MME_DATA(52):
        return "NV902D_CALL_MME_DATA(52)";
    case NV902D_CALL_MME_DATA(53):
        return "NV902D_CALL_MME_DATA(53)";
    case NV902D_CALL_MME_DATA(54):
        return "NV902D_CALL_MME_DATA(54)";
    case NV902D_CALL_MME_DATA(55):
        return "NV902D_CALL_MME_DATA(55)";
    case NV902D_CALL_MME_DATA(56):
        return "NV902D_CALL_MME_DATA(56)";
    case NV902D_CALL_MME_DATA(57):
        return "NV902D_CALL_MME_DATA(57)";
    case NV902D_CALL_MME_DATA(58):
        return "NV902D_CALL_MME_DATA(58)";
    case NV902D_CALL_MME_DATA(59):
        return "NV902D_CALL_MME_DATA(59)";
    case NV902D_CALL_MME_DATA(60):
        return "NV902D_CALL_MME_DATA(60)";
    case NV902D_CALL_MME_DATA(61):
        return "NV902D_CALL_MME_DATA(61)";
    case NV902D_CALL_MME_DATA(62):
        return "NV902D_CALL_MME_DATA(62)";
    case NV902D_CALL_MME_DATA(63):
        return "NV902D_CALL_MME_DATA(63)";
    case NV902D_CALL_MME_DATA(64):
        return "NV902D_CALL_MME_DATA(64)";
    case NV902D_CALL_MME_DATA(65):
        return "NV902D_CALL_MME_DATA(65)";
    case NV902D_CALL_MME_DATA(66):
        return "NV902D_CALL_MME_DATA(66)";
    case NV902D_CALL_MME_DATA(67):
        return "NV902D_CALL_MME_DATA(67)";
    case NV902D_CALL_MME_DATA(68):
        return "NV902D_CALL_MME_DATA(68)";
    case NV902D_CALL_MME_DATA(69):
        return "NV902D_CALL_MME_DATA(69)";
    case NV902D_CALL_MME_DATA(70):
        return "NV902D_CALL_MME_DATA(70)";
    case NV902D_CALL_MME_DATA(71):
        return "NV902D_CALL_MME_DATA(71)";
    case NV902D_CALL_MME_DATA(72):
        return "NV902D_CALL_MME_DATA(72)";
    case NV902D_CALL_MME_DATA(73):
        return "NV902D_CALL_MME_DATA(73)";
    case NV902D_CALL_MME_DATA(74):
        return "NV902D_CALL_MME_DATA(74)";
    case NV902D_CALL_MME_DATA(75):
        return "NV902D_CALL_MME_DATA(75)";
    case NV902D_CALL_MME_DATA(76):
        return "NV902D_CALL_MME_DATA(76)";
    case NV902D_CALL_MME_DATA(77):
        return "NV902D_CALL_MME_DATA(77)";
    case NV902D_CALL_MME_DATA(78):
        return "NV902D_CALL_MME_DATA(78)";
    case NV902D_CALL_MME_DATA(79):
        return "NV902D_CALL_MME_DATA(79)";
    case NV902D_CALL_MME_DATA(80):
        return "NV902D_CALL_MME_DATA(80)";
    case NV902D_CALL_MME_DATA(81):
        return "NV902D_CALL_MME_DATA(81)";
    case NV902D_CALL_MME_DATA(82):
        return "NV902D_CALL_MME_DATA(82)";
    case NV902D_CALL_MME_DATA(83):
        return "NV902D_CALL_MME_DATA(83)";
    case NV902D_CALL_MME_DATA(84):
        return "NV902D_CALL_MME_DATA(84)";
    case NV902D_CALL_MME_DATA(85):
        return "NV902D_CALL_MME_DATA(85)";
    case NV902D_CALL_MME_DATA(86):
        return "NV902D_CALL_MME_DATA(86)";
    case NV902D_CALL_MME_DATA(87):
        return "NV902D_CALL_MME_DATA(87)";
    case NV902D_CALL_MME_DATA(88):
        return "NV902D_CALL_MME_DATA(88)";
    case NV902D_CALL_MME_DATA(89):
        return "NV902D_CALL_MME_DATA(89)";
    case NV902D_CALL_MME_DATA(90):
        return "NV902D_CALL_MME_DATA(90)";
    case NV902D_CALL_MME_DATA(91):
        return "NV902D_CALL_MME_DATA(91)";
    case NV902D_CALL_MME_DATA(92):
        return "NV902D_CALL_MME_DATA(92)";
    case NV902D_CALL_MME_DATA(93):
        return "NV902D_CALL_MME_DATA(93)";
    case NV902D_CALL_MME_DATA(94):
        return "NV902D_CALL_MME_DATA(94)";
    case NV902D_CALL_MME_DATA(95):
        return "NV902D_CALL_MME_DATA(95)";
    case NV902D_CALL_MME_DATA(96):
        return "NV902D_CALL_MME_DATA(96)";
    case NV902D_CALL_MME_DATA(97):
        return "NV902D_CALL_MME_DATA(97)";
    case NV902D_CALL_MME_DATA(98):
        return "NV902D_CALL_MME_DATA(98)";
    case NV902D_CALL_MME_DATA(99):
        return "NV902D_CALL_MME_DATA(99)";
    case NV902D_CALL_MME_DATA(100):
        return "NV902D_CALL_MME_DATA(100)";
    case NV902D_CALL_MME_DATA(101):
        return "NV902D_CALL_MME_DATA(101)";
    case NV902D_CALL_MME_DATA(102):
        return "NV902D_CALL_MME_DATA(102)";
    case NV902D_CALL_MME_DATA(103):
        return "NV902D_CALL_MME_DATA(103)";
    case NV902D_CALL_MME_DATA(104):
        return "NV902D_CALL_MME_DATA(104)";
    case NV902D_CALL_MME_DATA(105):
        return "NV902D_CALL_MME_DATA(105)";
    case NV902D_CALL_MME_DATA(106):
        return "NV902D_CALL_MME_DATA(106)";
    case NV902D_CALL_MME_DATA(107):
        return "NV902D_CALL_MME_DATA(107)";
    case NV902D_CALL_MME_DATA(108):
        return "NV902D_CALL_MME_DATA(108)";
    case NV902D_CALL_MME_DATA(109):
        return "NV902D_CALL_MME_DATA(109)";
    case NV902D_CALL_MME_DATA(110):
        return "NV902D_CALL_MME_DATA(110)";
    case NV902D_CALL_MME_DATA(111):
        return "NV902D_CALL_MME_DATA(111)";
    case NV902D_CALL_MME_DATA(112):
        return "NV902D_CALL_MME_DATA(112)";
    case NV902D_CALL_MME_DATA(113):
        return "NV902D_CALL_MME_DATA(113)";
    case NV902D_CALL_MME_DATA(114):
        return "NV902D_CALL_MME_DATA(114)";
    case NV902D_CALL_MME_DATA(115):
        return "NV902D_CALL_MME_DATA(115)";
    case NV902D_CALL_MME_DATA(116):
        return "NV902D_CALL_MME_DATA(116)";
    case NV902D_CALL_MME_DATA(117):
        return "NV902D_CALL_MME_DATA(117)";
    case NV902D_CALL_MME_DATA(118):
        return "NV902D_CALL_MME_DATA(118)";
    case NV902D_CALL_MME_DATA(119):
        return "NV902D_CALL_MME_DATA(119)";
    case NV902D_CALL_MME_DATA(120):
        return "NV902D_CALL_MME_DATA(120)";
    case NV902D_CALL_MME_DATA(121):
        return "NV902D_CALL_MME_DATA(121)";
    case NV902D_CALL_MME_DATA(122):
        return "NV902D_CALL_MME_DATA(122)";
    case NV902D_CALL_MME_DATA(123):
        return "NV902D_CALL_MME_DATA(123)";
    case NV902D_CALL_MME_DATA(124):
        return "NV902D_CALL_MME_DATA(124)";
    case NV902D_CALL_MME_DATA(125):
        return "NV902D_CALL_MME_DATA(125)";
    case NV902D_CALL_MME_DATA(126):
        return "NV902D_CALL_MME_DATA(126)";
    case NV902D_CALL_MME_DATA(127):
        return "NV902D_CALL_MME_DATA(127)";
    case NV902D_CALL_MME_DATA(128):
        return "NV902D_CALL_MME_DATA(128)";
    case NV902D_CALL_MME_DATA(129):
        return "NV902D_CALL_MME_DATA(129)";
    case NV902D_CALL_MME_DATA(130):
        return "NV902D_CALL_MME_DATA(130)";
    case NV902D_CALL_MME_DATA(131):
        return "NV902D_CALL_MME_DATA(131)";
    case NV902D_CALL_MME_DATA(132):
        return "NV902D_CALL_MME_DATA(132)";
    case NV902D_CALL_MME_DATA(133):
        return "NV902D_CALL_MME_DATA(133)";
    case NV902D_CALL_MME_DATA(134):
        return "NV902D_CALL_MME_DATA(134)";
    case NV902D_CALL_MME_DATA(135):
        return "NV902D_CALL_MME_DATA(135)";
    case NV902D_CALL_MME_DATA(136):
        return "NV902D_CALL_MME_DATA(136)";
    case NV902D_CALL_MME_DATA(137):
        return "NV902D_CALL_MME_DATA(137)";
    case NV902D_CALL_MME_DATA(138):
        return "NV902D_CALL_MME_DATA(138)";
    case NV902D_CALL_MME_DATA(139):
        return "NV902D_CALL_MME_DATA(139)";
    case NV902D_CALL_MME_DATA(140):
        return "NV902D_CALL_MME_DATA(140)";
    case NV902D_CALL_MME_DATA(141):
        return "NV902D_CALL_MME_DATA(141)";
    case NV902D_CALL_MME_DATA(142):
        return "NV902D_CALL_MME_DATA(142)";
    case NV902D_CALL_MME_DATA(143):
        return "NV902D_CALL_MME_DATA(143)";
    case NV902D_CALL_MME_DATA(144):
        return "NV902D_CALL_MME_DATA(144)";
    case NV902D_CALL_MME_DATA(145):
        return "NV902D_CALL_MME_DATA(145)";
    case NV902D_CALL_MME_DATA(146):
        return "NV902D_CALL_MME_DATA(146)";
    case NV902D_CALL_MME_DATA(147):
        return "NV902D_CALL_MME_DATA(147)";
    case NV902D_CALL_MME_DATA(148):
        return "NV902D_CALL_MME_DATA(148)";
    case NV902D_CALL_MME_DATA(149):
        return "NV902D_CALL_MME_DATA(149)";
    case NV902D_CALL_MME_DATA(150):
        return "NV902D_CALL_MME_DATA(150)";
    case NV902D_CALL_MME_DATA(151):
        return "NV902D_CALL_MME_DATA(151)";
    case NV902D_CALL_MME_DATA(152):
        return "NV902D_CALL_MME_DATA(152)";
    case NV902D_CALL_MME_DATA(153):
        return "NV902D_CALL_MME_DATA(153)";
    case NV902D_CALL_MME_DATA(154):
        return "NV902D_CALL_MME_DATA(154)";
    case NV902D_CALL_MME_DATA(155):
        return "NV902D_CALL_MME_DATA(155)";
    case NV902D_CALL_MME_DATA(156):
        return "NV902D_CALL_MME_DATA(156)";
    case NV902D_CALL_MME_DATA(157):
        return "NV902D_CALL_MME_DATA(157)";
    case NV902D_CALL_MME_DATA(158):
        return "NV902D_CALL_MME_DATA(158)";
    case NV902D_CALL_MME_DATA(159):
        return "NV902D_CALL_MME_DATA(159)";
    case NV902D_CALL_MME_DATA(160):
        return "NV902D_CALL_MME_DATA(160)";
    case NV902D_CALL_MME_DATA(161):
        return "NV902D_CALL_MME_DATA(161)";
    case NV902D_CALL_MME_DATA(162):
        return "NV902D_CALL_MME_DATA(162)";
    case NV902D_CALL_MME_DATA(163):
        return "NV902D_CALL_MME_DATA(163)";
    case NV902D_CALL_MME_DATA(164):
        return "NV902D_CALL_MME_DATA(164)";
    case NV902D_CALL_MME_DATA(165):
        return "NV902D_CALL_MME_DATA(165)";
    case NV902D_CALL_MME_DATA(166):
        return "NV902D_CALL_MME_DATA(166)";
    case NV902D_CALL_MME_DATA(167):
        return "NV902D_CALL_MME_DATA(167)";
    case NV902D_CALL_MME_DATA(168):
        return "NV902D_CALL_MME_DATA(168)";
    case NV902D_CALL_MME_DATA(169):
        return "NV902D_CALL_MME_DATA(169)";
    case NV902D_CALL_MME_DATA(170):
        return "NV902D_CALL_MME_DATA(170)";
    case NV902D_CALL_MME_DATA(171):
        return "NV902D_CALL_MME_DATA(171)";
    case NV902D_CALL_MME_DATA(172):
        return "NV902D_CALL_MME_DATA(172)";
    case NV902D_CALL_MME_DATA(173):
        return "NV902D_CALL_MME_DATA(173)";
    case NV902D_CALL_MME_DATA(174):
        return "NV902D_CALL_MME_DATA(174)";
    case NV902D_CALL_MME_DATA(175):
        return "NV902D_CALL_MME_DATA(175)";
    case NV902D_CALL_MME_DATA(176):
        return "NV902D_CALL_MME_DATA(176)";
    case NV902D_CALL_MME_DATA(177):
        return "NV902D_CALL_MME_DATA(177)";
    case NV902D_CALL_MME_DATA(178):
        return "NV902D_CALL_MME_DATA(178)";
    case NV902D_CALL_MME_DATA(179):
        return "NV902D_CALL_MME_DATA(179)";
    case NV902D_CALL_MME_DATA(180):
        return "NV902D_CALL_MME_DATA(180)";
    case NV902D_CALL_MME_DATA(181):
        return "NV902D_CALL_MME_DATA(181)";
    case NV902D_CALL_MME_DATA(182):
        return "NV902D_CALL_MME_DATA(182)";
    case NV902D_CALL_MME_DATA(183):
        return "NV902D_CALL_MME_DATA(183)";
    case NV902D_CALL_MME_DATA(184):
        return "NV902D_CALL_MME_DATA(184)";
    case NV902D_CALL_MME_DATA(185):
        return "NV902D_CALL_MME_DATA(185)";
    case NV902D_CALL_MME_DATA(186):
        return "NV902D_CALL_MME_DATA(186)";
    case NV902D_CALL_MME_DATA(187):
        return "NV902D_CALL_MME_DATA(187)";
    case NV902D_CALL_MME_DATA(188):
        return "NV902D_CALL_MME_DATA(188)";
    case NV902D_CALL_MME_DATA(189):
        return "NV902D_CALL_MME_DATA(189)";
    case NV902D_CALL_MME_DATA(190):
        return "NV902D_CALL_MME_DATA(190)";
    case NV902D_CALL_MME_DATA(191):
        return "NV902D_CALL_MME_DATA(191)";
    case NV902D_CALL_MME_DATA(192):
        return "NV902D_CALL_MME_DATA(192)";
    case NV902D_CALL_MME_DATA(193):
        return "NV902D_CALL_MME_DATA(193)";
    case NV902D_CALL_MME_DATA(194):
        return "NV902D_CALL_MME_DATA(194)";
    case NV902D_CALL_MME_DATA(195):
        return "NV902D_CALL_MME_DATA(195)";
    case NV902D_CALL_MME_DATA(196):
        return "NV902D_CALL_MME_DATA(196)";
    case NV902D_CALL_MME_DATA(197):
        return "NV902D_CALL_MME_DATA(197)";
    case NV902D_CALL_MME_DATA(198):
        return "NV902D_CALL_MME_DATA(198)";
    case NV902D_CALL_MME_DATA(199):
        return "NV902D_CALL_MME_DATA(199)";
    case NV902D_CALL_MME_DATA(200):
        return "NV902D_CALL_MME_DATA(200)";
    case NV902D_CALL_MME_DATA(201):
        return "NV902D_CALL_MME_DATA(201)";
    case NV902D_CALL_MME_DATA(202):
        return "NV902D_CALL_MME_DATA(202)";
    case NV902D_CALL_MME_DATA(203):
        return "NV902D_CALL_MME_DATA(203)";
    case NV902D_CALL_MME_DATA(204):
        return "NV902D_CALL_MME_DATA(204)";
    case NV902D_CALL_MME_DATA(205):
        return "NV902D_CALL_MME_DATA(205)";
    case NV902D_CALL_MME_DATA(206):
        return "NV902D_CALL_MME_DATA(206)";
    case NV902D_CALL_MME_DATA(207):
        return "NV902D_CALL_MME_DATA(207)";
    case NV902D_CALL_MME_DATA(208):
        return "NV902D_CALL_MME_DATA(208)";
    case NV902D_CALL_MME_DATA(209):
        return "NV902D_CALL_MME_DATA(209)";
    case NV902D_CALL_MME_DATA(210):
        return "NV902D_CALL_MME_DATA(210)";
    case NV902D_CALL_MME_DATA(211):
        return "NV902D_CALL_MME_DATA(211)";
    case NV902D_CALL_MME_DATA(212):
        return "NV902D_CALL_MME_DATA(212)";
    case NV902D_CALL_MME_DATA(213):
        return "NV902D_CALL_MME_DATA(213)";
    case NV902D_CALL_MME_DATA(214):
        return "NV902D_CALL_MME_DATA(214)";
    case NV902D_CALL_MME_DATA(215):
        return "NV902D_CALL_MME_DATA(215)";
    case NV902D_CALL_MME_DATA(216):
        return "NV902D_CALL_MME_DATA(216)";
    case NV902D_CALL_MME_DATA(217):
        return "NV902D_CALL_MME_DATA(217)";
    case NV902D_CALL_MME_DATA(218):
        return "NV902D_CALL_MME_DATA(218)";
    case NV902D_CALL_MME_DATA(219):
        return "NV902D_CALL_MME_DATA(219)";
    case NV902D_CALL_MME_DATA(220):
        return "NV902D_CALL_MME_DATA(220)";
    case NV902D_CALL_MME_DATA(221):
        return "NV902D_CALL_MME_DATA(221)";
    case NV902D_CALL_MME_DATA(222):
        return "NV902D_CALL_MME_DATA(222)";
    case NV902D_CALL_MME_DATA(223):
        return "NV902D_CALL_MME_DATA(223)";
    case NV902D_CALL_MME_DATA(224):
        return "NV902D_CALL_MME_DATA(224)";
    case NV902D_CALL_MME_DATA(225):
        return "NV902D_CALL_MME_DATA(225)";
    case NV902D_CALL_MME_DATA(226):
        return "NV902D_CALL_MME_DATA(226)";
    case NV902D_CALL_MME_DATA(227):
        return "NV902D_CALL_MME_DATA(227)";
    case NV902D_CALL_MME_DATA(228):
        return "NV902D_CALL_MME_DATA(228)";
    case NV902D_CALL_MME_DATA(229):
        return "NV902D_CALL_MME_DATA(229)";
    case NV902D_CALL_MME_DATA(230):
        return "NV902D_CALL_MME_DATA(230)";
    case NV902D_CALL_MME_DATA(231):
        return "NV902D_CALL_MME_DATA(231)";
    case NV902D_CALL_MME_DATA(232):
        return "NV902D_CALL_MME_DATA(232)";
    case NV902D_CALL_MME_DATA(233):
        return "NV902D_CALL_MME_DATA(233)";
    case NV902D_CALL_MME_DATA(234):
        return "NV902D_CALL_MME_DATA(234)";
    case NV902D_CALL_MME_DATA(235):
        return "NV902D_CALL_MME_DATA(235)";
    case NV902D_CALL_MME_DATA(236):
        return "NV902D_CALL_MME_DATA(236)";
    case NV902D_CALL_MME_DATA(237):
        return "NV902D_CALL_MME_DATA(237)";
    case NV902D_CALL_MME_DATA(238):
        return "NV902D_CALL_MME_DATA(238)";
    case NV902D_CALL_MME_DATA(239):
        return "NV902D_CALL_MME_DATA(239)";
    case NV902D_CALL_MME_DATA(240):
        return "NV902D_CALL_MME_DATA(240)";
    case NV902D_CALL_MME_DATA(241):
        return "NV902D_CALL_MME_DATA(241)";
    case NV902D_CALL_MME_DATA(242):
        return "NV902D_CALL_MME_DATA(242)";
    case NV902D_CALL_MME_DATA(243):
        return "NV902D_CALL_MME_DATA(243)";
    case NV902D_CALL_MME_DATA(244):
        return "NV902D_CALL_MME_DATA(244)";
    case NV902D_CALL_MME_DATA(245):
        return "NV902D_CALL_MME_DATA(245)";
    case NV902D_CALL_MME_DATA(246):
        return "NV902D_CALL_MME_DATA(246)";
    case NV902D_CALL_MME_DATA(247):
        return "NV902D_CALL_MME_DATA(247)";
    case NV902D_CALL_MME_DATA(248):
        return "NV902D_CALL_MME_DATA(248)";
    case NV902D_CALL_MME_DATA(249):
        return "NV902D_CALL_MME_DATA(249)";
    case NV902D_CALL_MME_DATA(250):
        return "NV902D_CALL_MME_DATA(250)";
    case NV902D_CALL_MME_DATA(251):
        return "NV902D_CALL_MME_DATA(251)";
    case NV902D_CALL_MME_DATA(252):
        return "NV902D_CALL_MME_DATA(252)";
    case NV902D_CALL_MME_DATA(253):
        return "NV902D_CALL_MME_DATA(253)";
    case NV902D_CALL_MME_DATA(254):
        return "NV902D_CALL_MME_DATA(254)";
    case NV902D_CALL_MME_DATA(255):
        return "NV902D_CALL_MME_DATA(255)";

    default:
        return "unknown method";
    }
}

void
P_DUMP_NV902D_MTHD_DATA(FILE *fp, uint16_t idx, uint32_t data,
                         const char *prefix)
{
    UNUSED uint32_t parsed;
    switch (idx) {


  
    case NV902D_SET_OBJECT:

    
        parsed = (data >> 0) & ((1u << 16) - 1);
        fprintf(fp, "%s.CLASS_ID = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 16) & ((1u << 5) - 1);
        fprintf(fp, "%s.ENGINE_ID = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_NO_OPERATION:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_NOTIFY_A:

    
        parsed = (data >> 0) & ((1u << 25) - 1);
        fprintf(fp, "%s.ADDRESS_UPPER = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_NOTIFY_B:

    
        parsed = data;
        fprintf(fp, "%s.ADDRESS_LOWER = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_NOTIFY:

    
        parsed = data;
        fprintf(fp, "%s.TYPE = ", prefix);
        switch (parsed) {
        case NV902D_NOTIFY_TYPE_WRITE_ONLY:
            fprintf(fp, "WRITE_ONLY\n");
            break;
        case NV902D_NOTIFY_TYPE_WRITE_THEN_AWAKEN:
            fprintf(fp, "WRITE_THEN_AWAKEN\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_WAIT_FOR_IDLE:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_LOAD_MME_INSTRUCTION_RAM_POINTER:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_LOAD_MME_INSTRUCTION_RAM:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_LOAD_MME_START_ADDRESS_RAM_POINTER:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_LOAD_MME_START_ADDRESS_RAM:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_MME_SHADOW_RAM_CONTROL:

    
        parsed = (data >> 0) & ((1u << 2) - 1);
        fprintf(fp, "%s.MODE = ", prefix);
        switch (parsed) {
        case NV902D_SET_MME_SHADOW_RAM_CONTROL_MODE_METHOD_TRACK:
            fprintf(fp, "METHOD_TRACK\n");
            break;
        case NV902D_SET_MME_SHADOW_RAM_CONTROL_MODE_METHOD_TRACK_WITH_FILTER:
            fprintf(fp, "METHOD_TRACK_WITH_FILTER\n");
            break;
        case NV902D_SET_MME_SHADOW_RAM_CONTROL_MODE_METHOD_PASSTHROUGH:
            fprintf(fp, "METHOD_PASSTHROUGH\n");
            break;
        case NV902D_SET_MME_SHADOW_RAM_CONTROL_MODE_METHOD_REPLAY:
            fprintf(fp, "METHOD_REPLAY\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_GLOBAL_RENDER_ENABLE_A:

    
        parsed = (data >> 0) & ((1u << 8) - 1);
        fprintf(fp, "%s.OFFSET_UPPER = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_GLOBAL_RENDER_ENABLE_B:

    
        parsed = data;
        fprintf(fp, "%s.OFFSET_LOWER = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_GLOBAL_RENDER_ENABLE_C:

    
        parsed = (data >> 0) & ((1u << 3) - 1);
        fprintf(fp, "%s.MODE = ", prefix);
        switch (parsed) {
        case NV902D_SET_GLOBAL_RENDER_ENABLE_C_MODE_FALSE:
            fprintf(fp, "FALSE\n");
            break;
        case NV902D_SET_GLOBAL_RENDER_ENABLE_C_MODE_TRUE:
            fprintf(fp, "TRUE\n");
            break;
        case NV902D_SET_GLOBAL_RENDER_ENABLE_C_MODE_CONDITIONAL:
            fprintf(fp, "CONDITIONAL\n");
            break;
        case NV902D_SET_GLOBAL_RENDER_ENABLE_C_MODE_RENDER_IF_EQUAL:
            fprintf(fp, "RENDER_IF_EQUAL\n");
            break;
        case NV902D_SET_GLOBAL_RENDER_ENABLE_C_MODE_RENDER_IF_NOT_EQUAL:
            fprintf(fp, "RENDER_IF_NOT_EQUAL\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SEND_GO_IDLE:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_PM_TRIGGER:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_INSTRUMENTATION_METHOD_HEADER:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_INSTRUMENTATION_METHOD_DATA:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_MME_SWITCH_STATE:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.VALID = ", prefix);
        switch (parsed) {
        case NV902D_SET_MME_SWITCH_STATE_VALID_FALSE:
            fprintf(fp, "FALSE\n");
            break;
        case NV902D_SET_MME_SWITCH_STATE_VALID_TRUE:
            fprintf(fp, "TRUE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 4) & ((1u << 8) - 1);
        fprintf(fp, "%s.SAVE_MACRO = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 12) & ((1u << 8) - 1);
        fprintf(fp, "%s.RESTORE_MACRO = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_DST_FORMAT:

    
        parsed = (data >> 0) & ((1u << 8) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_SET_DST_FORMAT_V_A8R8G8B8:
            fprintf(fp, "A8R8G8B8\n");
            break;
        case NV902D_SET_DST_FORMAT_V_A8RL8GL8BL8:
            fprintf(fp, "A8RL8GL8BL8\n");
            break;
        case NV902D_SET_DST_FORMAT_V_A2R10G10B10:
            fprintf(fp, "A2R10G10B10\n");
            break;
        case NV902D_SET_DST_FORMAT_V_A8B8G8R8:
            fprintf(fp, "A8B8G8R8\n");
            break;
        case NV902D_SET_DST_FORMAT_V_A8BL8GL8RL8:
            fprintf(fp, "A8BL8GL8RL8\n");
            break;
        case NV902D_SET_DST_FORMAT_V_A2B10G10R10:
            fprintf(fp, "A2B10G10R10\n");
            break;
        case NV902D_SET_DST_FORMAT_V_X8R8G8B8:
            fprintf(fp, "X8R8G8B8\n");
            break;
        case NV902D_SET_DST_FORMAT_V_X8RL8GL8BL8:
            fprintf(fp, "X8RL8GL8BL8\n");
            break;
        case NV902D_SET_DST_FORMAT_V_X8B8G8R8:
            fprintf(fp, "X8B8G8R8\n");
            break;
        case NV902D_SET_DST_FORMAT_V_X8BL8GL8RL8:
            fprintf(fp, "X8BL8GL8RL8\n");
            break;
        case NV902D_SET_DST_FORMAT_V_R5G6B5:
            fprintf(fp, "R5G6B5\n");
            break;
        case NV902D_SET_DST_FORMAT_V_A1R5G5B5:
            fprintf(fp, "A1R5G5B5\n");
            break;
        case NV902D_SET_DST_FORMAT_V_X1R5G5B5:
            fprintf(fp, "X1R5G5B5\n");
            break;
        case NV902D_SET_DST_FORMAT_V_Y8:
            fprintf(fp, "Y8\n");
            break;
        case NV902D_SET_DST_FORMAT_V_Y16:
            fprintf(fp, "Y16\n");
            break;
        case NV902D_SET_DST_FORMAT_V_Y32:
            fprintf(fp, "Y32\n");
            break;
        case NV902D_SET_DST_FORMAT_V_Z1R5G5B5:
            fprintf(fp, "Z1R5G5B5\n");
            break;
        case NV902D_SET_DST_FORMAT_V_O1R5G5B5:
            fprintf(fp, "O1R5G5B5\n");
            break;
        case NV902D_SET_DST_FORMAT_V_Z8R8G8B8:
            fprintf(fp, "Z8R8G8B8\n");
            break;
        case NV902D_SET_DST_FORMAT_V_O8R8G8B8:
            fprintf(fp, "O8R8G8B8\n");
            break;
        case NV902D_SET_DST_FORMAT_V_Y1_8X8:
            fprintf(fp, "Y1_8X8\n");
            break;
        case NV902D_SET_DST_FORMAT_V_RF16:
            fprintf(fp, "RF16\n");
            break;
        case NV902D_SET_DST_FORMAT_V_RF32:
            fprintf(fp, "RF32\n");
            break;
        case NV902D_SET_DST_FORMAT_V_RF32_GF32:
            fprintf(fp, "RF32_GF32\n");
            break;
        case NV902D_SET_DST_FORMAT_V_RF16_GF16_BF16_AF16:
            fprintf(fp, "RF16_GF16_BF16_AF16\n");
            break;
        case NV902D_SET_DST_FORMAT_V_RF16_GF16_BF16_X16:
            fprintf(fp, "RF16_GF16_BF16_X16\n");
            break;
        case NV902D_SET_DST_FORMAT_V_RF32_GF32_BF32_AF32:
            fprintf(fp, "RF32_GF32_BF32_AF32\n");
            break;
        case NV902D_SET_DST_FORMAT_V_RF32_GF32_BF32_X32:
            fprintf(fp, "RF32_GF32_BF32_X32\n");
            break;
        case NV902D_SET_DST_FORMAT_V_R16_G16_B16_A16:
            fprintf(fp, "R16_G16_B16_A16\n");
            break;
        case NV902D_SET_DST_FORMAT_V_RN16_GN16_BN16_AN16:
            fprintf(fp, "RN16_GN16_BN16_AN16\n");
            break;
        case NV902D_SET_DST_FORMAT_V_BF10GF11RF11:
            fprintf(fp, "BF10GF11RF11\n");
            break;
        case NV902D_SET_DST_FORMAT_V_AN8BN8GN8RN8:
            fprintf(fp, "AN8BN8GN8RN8\n");
            break;
        case NV902D_SET_DST_FORMAT_V_RF16_GF16:
            fprintf(fp, "RF16_GF16\n");
            break;
        case NV902D_SET_DST_FORMAT_V_R16_G16:
            fprintf(fp, "R16_G16\n");
            break;
        case NV902D_SET_DST_FORMAT_V_RN16_GN16:
            fprintf(fp, "RN16_GN16\n");
            break;
        case NV902D_SET_DST_FORMAT_V_G8R8:
            fprintf(fp, "G8R8\n");
            break;
        case NV902D_SET_DST_FORMAT_V_GN8RN8:
            fprintf(fp, "GN8RN8\n");
            break;
        case NV902D_SET_DST_FORMAT_V_RN16:
            fprintf(fp, "RN16\n");
            break;
        case NV902D_SET_DST_FORMAT_V_RN8:
            fprintf(fp, "RN8\n");
            break;
        case NV902D_SET_DST_FORMAT_V_A8:
            fprintf(fp, "A8\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_DST_MEMORY_LAYOUT:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_SET_DST_MEMORY_LAYOUT_V_BLOCKLINEAR:
            fprintf(fp, "BLOCKLINEAR\n");
            break;
        case NV902D_SET_DST_MEMORY_LAYOUT_V_PITCH:
            fprintf(fp, "PITCH\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_DST_BLOCK_SIZE:

    
        parsed = (data >> 4) & ((1u << 3) - 1);
        fprintf(fp, "%s.HEIGHT = ", prefix);
        switch (parsed) {
        case NV902D_SET_DST_BLOCK_SIZE_HEIGHT_ONE_GOB:
            fprintf(fp, "ONE_GOB\n");
            break;
        case NV902D_SET_DST_BLOCK_SIZE_HEIGHT_TWO_GOBS:
            fprintf(fp, "TWO_GOBS\n");
            break;
        case NV902D_SET_DST_BLOCK_SIZE_HEIGHT_FOUR_GOBS:
            fprintf(fp, "FOUR_GOBS\n");
            break;
        case NV902D_SET_DST_BLOCK_SIZE_HEIGHT_EIGHT_GOBS:
            fprintf(fp, "EIGHT_GOBS\n");
            break;
        case NV902D_SET_DST_BLOCK_SIZE_HEIGHT_SIXTEEN_GOBS:
            fprintf(fp, "SIXTEEN_GOBS\n");
            break;
        case NV902D_SET_DST_BLOCK_SIZE_HEIGHT_THIRTYTWO_GOBS:
            fprintf(fp, "THIRTYTWO_GOBS\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 8) & ((1u << 3) - 1);
        fprintf(fp, "%s.DEPTH = ", prefix);
        switch (parsed) {
        case NV902D_SET_DST_BLOCK_SIZE_DEPTH_ONE_GOB:
            fprintf(fp, "ONE_GOB\n");
            break;
        case NV902D_SET_DST_BLOCK_SIZE_DEPTH_TWO_GOBS:
            fprintf(fp, "TWO_GOBS\n");
            break;
        case NV902D_SET_DST_BLOCK_SIZE_DEPTH_FOUR_GOBS:
            fprintf(fp, "FOUR_GOBS\n");
            break;
        case NV902D_SET_DST_BLOCK_SIZE_DEPTH_EIGHT_GOBS:
            fprintf(fp, "EIGHT_GOBS\n");
            break;
        case NV902D_SET_DST_BLOCK_SIZE_DEPTH_SIXTEEN_GOBS:
            fprintf(fp, "SIXTEEN_GOBS\n");
            break;
        case NV902D_SET_DST_BLOCK_SIZE_DEPTH_THIRTYTWO_GOBS:
            fprintf(fp, "THIRTYTWO_GOBS\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_DST_DEPTH:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_DST_LAYER:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_DST_PITCH:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_DST_WIDTH:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_DST_HEIGHT:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_DST_OFFSET_UPPER:

    
        parsed = (data >> 0) & ((1u << 8) - 1);
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_DST_OFFSET_LOWER:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_FLUSH_AND_INVALIDATE_ROP_MINI_CACHE:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_SPARE_NOOP06:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_SRC_FORMAT:

    
        parsed = (data >> 0) & ((1u << 8) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_SET_SRC_FORMAT_V_A8R8G8B8:
            fprintf(fp, "A8R8G8B8\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_A8RL8GL8BL8:
            fprintf(fp, "A8RL8GL8BL8\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_A2R10G10B10:
            fprintf(fp, "A2R10G10B10\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_A8B8G8R8:
            fprintf(fp, "A8B8G8R8\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_A8BL8GL8RL8:
            fprintf(fp, "A8BL8GL8RL8\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_A2B10G10R10:
            fprintf(fp, "A2B10G10R10\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_X8R8G8B8:
            fprintf(fp, "X8R8G8B8\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_X8RL8GL8BL8:
            fprintf(fp, "X8RL8GL8BL8\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_X8B8G8R8:
            fprintf(fp, "X8B8G8R8\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_X8BL8GL8RL8:
            fprintf(fp, "X8BL8GL8RL8\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_R5G6B5:
            fprintf(fp, "R5G6B5\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_A1R5G5B5:
            fprintf(fp, "A1R5G5B5\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_X1R5G5B5:
            fprintf(fp, "X1R5G5B5\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_Y8:
            fprintf(fp, "Y8\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_AY8:
            fprintf(fp, "AY8\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_Y16:
            fprintf(fp, "Y16\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_Y32:
            fprintf(fp, "Y32\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_Z1R5G5B5:
            fprintf(fp, "Z1R5G5B5\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_O1R5G5B5:
            fprintf(fp, "O1R5G5B5\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_Z8R8G8B8:
            fprintf(fp, "Z8R8G8B8\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_O8R8G8B8:
            fprintf(fp, "O8R8G8B8\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_Y1_8X8:
            fprintf(fp, "Y1_8X8\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_RF16:
            fprintf(fp, "RF16\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_RF32:
            fprintf(fp, "RF32\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_RF32_GF32:
            fprintf(fp, "RF32_GF32\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_RF16_GF16_BF16_AF16:
            fprintf(fp, "RF16_GF16_BF16_AF16\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_RF16_GF16_BF16_X16:
            fprintf(fp, "RF16_GF16_BF16_X16\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_RF32_GF32_BF32_AF32:
            fprintf(fp, "RF32_GF32_BF32_AF32\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_RF32_GF32_BF32_X32:
            fprintf(fp, "RF32_GF32_BF32_X32\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_R16_G16_B16_A16:
            fprintf(fp, "R16_G16_B16_A16\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_RN16_GN16_BN16_AN16:
            fprintf(fp, "RN16_GN16_BN16_AN16\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_BF10GF11RF11:
            fprintf(fp, "BF10GF11RF11\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_AN8BN8GN8RN8:
            fprintf(fp, "AN8BN8GN8RN8\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_RF16_GF16:
            fprintf(fp, "RF16_GF16\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_R16_G16:
            fprintf(fp, "R16_G16\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_RN16_GN16:
            fprintf(fp, "RN16_GN16\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_G8R8:
            fprintf(fp, "G8R8\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_GN8RN8:
            fprintf(fp, "GN8RN8\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_RN16:
            fprintf(fp, "RN16\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_RN8:
            fprintf(fp, "RN8\n");
            break;
        case NV902D_SET_SRC_FORMAT_V_A8:
            fprintf(fp, "A8\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_SRC_MEMORY_LAYOUT:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_SET_SRC_MEMORY_LAYOUT_V_BLOCKLINEAR:
            fprintf(fp, "BLOCKLINEAR\n");
            break;
        case NV902D_SET_SRC_MEMORY_LAYOUT_V_PITCH:
            fprintf(fp, "PITCH\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_SRC_BLOCK_SIZE:

    
        parsed = (data >> 4) & ((1u << 3) - 1);
        fprintf(fp, "%s.HEIGHT = ", prefix);
        switch (parsed) {
        case NV902D_SET_SRC_BLOCK_SIZE_HEIGHT_ONE_GOB:
            fprintf(fp, "ONE_GOB\n");
            break;
        case NV902D_SET_SRC_BLOCK_SIZE_HEIGHT_TWO_GOBS:
            fprintf(fp, "TWO_GOBS\n");
            break;
        case NV902D_SET_SRC_BLOCK_SIZE_HEIGHT_FOUR_GOBS:
            fprintf(fp, "FOUR_GOBS\n");
            break;
        case NV902D_SET_SRC_BLOCK_SIZE_HEIGHT_EIGHT_GOBS:
            fprintf(fp, "EIGHT_GOBS\n");
            break;
        case NV902D_SET_SRC_BLOCK_SIZE_HEIGHT_SIXTEEN_GOBS:
            fprintf(fp, "SIXTEEN_GOBS\n");
            break;
        case NV902D_SET_SRC_BLOCK_SIZE_HEIGHT_THIRTYTWO_GOBS:
            fprintf(fp, "THIRTYTWO_GOBS\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 8) & ((1u << 3) - 1);
        fprintf(fp, "%s.DEPTH = ", prefix);
        switch (parsed) {
        case NV902D_SET_SRC_BLOCK_SIZE_DEPTH_ONE_GOB:
            fprintf(fp, "ONE_GOB\n");
            break;
        case NV902D_SET_SRC_BLOCK_SIZE_DEPTH_TWO_GOBS:
            fprintf(fp, "TWO_GOBS\n");
            break;
        case NV902D_SET_SRC_BLOCK_SIZE_DEPTH_FOUR_GOBS:
            fprintf(fp, "FOUR_GOBS\n");
            break;
        case NV902D_SET_SRC_BLOCK_SIZE_DEPTH_EIGHT_GOBS:
            fprintf(fp, "EIGHT_GOBS\n");
            break;
        case NV902D_SET_SRC_BLOCK_SIZE_DEPTH_SIXTEEN_GOBS:
            fprintf(fp, "SIXTEEN_GOBS\n");
            break;
        case NV902D_SET_SRC_BLOCK_SIZE_DEPTH_THIRTYTWO_GOBS:
            fprintf(fp, "THIRTYTWO_GOBS\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_SRC_DEPTH:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_TWOD_INVALIDATE_TEXTURE_DATA_CACHE:

    
        parsed = (data >> 0) & ((1u << 2) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_TWOD_INVALIDATE_TEXTURE_DATA_CACHE_V_L1_ONLY:
            fprintf(fp, "L1_ONLY\n");
            break;
        case NV902D_TWOD_INVALIDATE_TEXTURE_DATA_CACHE_V_L2_ONLY:
            fprintf(fp, "L2_ONLY\n");
            break;
        case NV902D_TWOD_INVALIDATE_TEXTURE_DATA_CACHE_V_L1_AND_L2:
            fprintf(fp, "L1_AND_L2\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_SRC_PITCH:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_SRC_WIDTH:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_SRC_HEIGHT:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_SRC_OFFSET_UPPER:

    
        parsed = (data >> 0) & ((1u << 8) - 1);
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_SRC_OFFSET_LOWER:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PIXELS_FROM_MEMORY_SECTOR_PROMOTION:

    
        parsed = (data >> 0) & ((1u << 2) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_SET_PIXELS_FROM_MEMORY_SECTOR_PROMOTION_V_NO_PROMOTION:
            fprintf(fp, "NO_PROMOTION\n");
            break;
        case NV902D_SET_PIXELS_FROM_MEMORY_SECTOR_PROMOTION_V_PROMOTE_TO_2_V:
            fprintf(fp, "PROMOTE_TO_2_V\n");
            break;
        case NV902D_SET_PIXELS_FROM_MEMORY_SECTOR_PROMOTION_V_PROMOTE_TO_2_H:
            fprintf(fp, "PROMOTE_TO_2_H\n");
            break;
        case NV902D_SET_PIXELS_FROM_MEMORY_SECTOR_PROMOTION_V_PROMOTE_TO_4:
            fprintf(fp, "PROMOTE_TO_4\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_SPARE_NOOP12:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_NUM_PROCESSING_CLUSTERS:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_SET_NUM_PROCESSING_CLUSTERS_V_ALL:
            fprintf(fp, "ALL\n");
            break;
        case NV902D_SET_NUM_PROCESSING_CLUSTERS_V_ONE:
            fprintf(fp, "ONE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_RENDER_ENABLE_A:

    
        parsed = (data >> 0) & ((1u << 8) - 1);
        fprintf(fp, "%s.OFFSET_UPPER = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_RENDER_ENABLE_B:

    
        parsed = data;
        fprintf(fp, "%s.OFFSET_LOWER = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_RENDER_ENABLE_C:

    
        parsed = (data >> 0) & ((1u << 3) - 1);
        fprintf(fp, "%s.MODE = ", prefix);
        switch (parsed) {
        case NV902D_SET_RENDER_ENABLE_C_MODE_FALSE:
            fprintf(fp, "FALSE\n");
            break;
        case NV902D_SET_RENDER_ENABLE_C_MODE_TRUE:
            fprintf(fp, "TRUE\n");
            break;
        case NV902D_SET_RENDER_ENABLE_C_MODE_CONDITIONAL:
            fprintf(fp, "CONDITIONAL\n");
            break;
        case NV902D_SET_RENDER_ENABLE_C_MODE_RENDER_IF_EQUAL:
            fprintf(fp, "RENDER_IF_EQUAL\n");
            break;
        case NV902D_SET_RENDER_ENABLE_C_MODE_RENDER_IF_NOT_EQUAL:
            fprintf(fp, "RENDER_IF_NOT_EQUAL\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_SPARE_NOOP08:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_SPARE_NOOP01:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_SPARE_NOOP11:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_SPARE_NOOP07:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_CLIP_X0:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_CLIP_Y0:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_CLIP_WIDTH:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_CLIP_HEIGHT:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_CLIP_ENABLE:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_SET_CLIP_ENABLE_V_FALSE:
            fprintf(fp, "FALSE\n");
            break;
        case NV902D_SET_CLIP_ENABLE_V_TRUE:
            fprintf(fp, "TRUE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_COLOR_KEY_FORMAT:

    
        parsed = (data >> 0) & ((1u << 3) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_SET_COLOR_KEY_FORMAT_V_A16R5G6B5:
            fprintf(fp, "A16R5G6B5\n");
            break;
        case NV902D_SET_COLOR_KEY_FORMAT_V_A1R5G5B5:
            fprintf(fp, "A1R5G5B5\n");
            break;
        case NV902D_SET_COLOR_KEY_FORMAT_V_A8R8G8B8:
            fprintf(fp, "A8R8G8B8\n");
            break;
        case NV902D_SET_COLOR_KEY_FORMAT_V_A2R10G10B10:
            fprintf(fp, "A2R10G10B10\n");
            break;
        case NV902D_SET_COLOR_KEY_FORMAT_V_Y8:
            fprintf(fp, "Y8\n");
            break;
        case NV902D_SET_COLOR_KEY_FORMAT_V_Y16:
            fprintf(fp, "Y16\n");
            break;
        case NV902D_SET_COLOR_KEY_FORMAT_V_Y32:
            fprintf(fp, "Y32\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_COLOR_KEY:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_COLOR_KEY_ENABLE:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_SET_COLOR_KEY_ENABLE_V_FALSE:
            fprintf(fp, "FALSE\n");
            break;
        case NV902D_SET_COLOR_KEY_ENABLE_V_TRUE:
            fprintf(fp, "TRUE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_ROP:

    
        parsed = (data >> 0) & ((1u << 8) - 1);
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_BETA1:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_BETA4:

    
        parsed = (data >> 0) & ((1u << 8) - 1);
        fprintf(fp, "%s.B = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 8) & ((1u << 8) - 1);
        fprintf(fp, "%s.G = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 16) & ((1u << 8) - 1);
        fprintf(fp, "%s.R = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 24) & ((1u << 8) - 1);
        fprintf(fp, "%s.A = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_OPERATION:

    
        parsed = (data >> 0) & ((1u << 3) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_SET_OPERATION_V_SRCCOPY_AND:
            fprintf(fp, "SRCCOPY_AND\n");
            break;
        case NV902D_SET_OPERATION_V_ROP_AND:
            fprintf(fp, "ROP_AND\n");
            break;
        case NV902D_SET_OPERATION_V_BLEND_AND:
            fprintf(fp, "BLEND_AND\n");
            break;
        case NV902D_SET_OPERATION_V_SRCCOPY:
            fprintf(fp, "SRCCOPY\n");
            break;
        case NV902D_SET_OPERATION_V_ROP:
            fprintf(fp, "ROP\n");
            break;
        case NV902D_SET_OPERATION_V_SRCCOPY_PREMULT:
            fprintf(fp, "SRCCOPY_PREMULT\n");
            break;
        case NV902D_SET_OPERATION_V_BLEND_PREMULT:
            fprintf(fp, "BLEND_PREMULT\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_PATTERN_OFFSET:

    
        parsed = (data >> 0) & ((1u << 6) - 1);
        fprintf(fp, "%s.X = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 8) & ((1u << 6) - 1);
        fprintf(fp, "%s.Y = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PATTERN_SELECT:

    
        parsed = (data >> 0) & ((1u << 2) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_SET_PATTERN_SELECT_V_MONOCHROME_8x8:
            fprintf(fp, "MONOCHROME_8x8\n");
            break;
        case NV902D_SET_PATTERN_SELECT_V_MONOCHROME_64x1:
            fprintf(fp, "MONOCHROME_64x1\n");
            break;
        case NV902D_SET_PATTERN_SELECT_V_MONOCHROME_1x64:
            fprintf(fp, "MONOCHROME_1x64\n");
            break;
        case NV902D_SET_PATTERN_SELECT_V_COLOR:
            fprintf(fp, "COLOR\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_DST_COLOR_RENDER_TO_ZETA_SURFACE:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_SET_DST_COLOR_RENDER_TO_ZETA_SURFACE_V_FALSE:
            fprintf(fp, "FALSE\n");
            break;
        case NV902D_SET_DST_COLOR_RENDER_TO_ZETA_SURFACE_V_TRUE:
            fprintf(fp, "TRUE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_SPARE_NOOP04:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_SPARE_NOOP15:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_SPARE_NOOP13:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_SPARE_NOOP03:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_SPARE_NOOP14:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_SPARE_NOOP02:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_COMPRESSION:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.ENABLE = ", prefix);
        switch (parsed) {
        case NV902D_SET_COMPRESSION_ENABLE_FALSE:
            fprintf(fp, "FALSE\n");
            break;
        case NV902D_SET_COMPRESSION_ENABLE_TRUE:
            fprintf(fp, "TRUE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_SPARE_NOOP09:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_RENDER_ENABLE_OVERRIDE:

    
        parsed = (data >> 0) & ((1u << 2) - 1);
        fprintf(fp, "%s.MODE = ", prefix);
        switch (parsed) {
        case NV902D_SET_RENDER_ENABLE_OVERRIDE_MODE_USE_RENDER_ENABLE:
            fprintf(fp, "USE_RENDER_ENABLE\n");
            break;
        case NV902D_SET_RENDER_ENABLE_OVERRIDE_MODE_ALWAYS_RENDER:
            fprintf(fp, "ALWAYS_RENDER\n");
            break;
        case NV902D_SET_RENDER_ENABLE_OVERRIDE_MODE_NEVER_RENDER:
            fprintf(fp, "NEVER_RENDER\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_PIXELS_FROM_MEMORY_DIRECTION:

    
        parsed = (data >> 0) & ((1u << 2) - 1);
        fprintf(fp, "%s.HORIZONTAL = ", prefix);
        switch (parsed) {
        case NV902D_SET_PIXELS_FROM_MEMORY_DIRECTION_HORIZONTAL_HW_DECIDES:
            fprintf(fp, "HW_DECIDES\n");
            break;
        case NV902D_SET_PIXELS_FROM_MEMORY_DIRECTION_HORIZONTAL_LEFT_TO_RIGHT:
            fprintf(fp, "LEFT_TO_RIGHT\n");
            break;
        case NV902D_SET_PIXELS_FROM_MEMORY_DIRECTION_HORIZONTAL_RIGHT_TO_LEFT:
            fprintf(fp, "RIGHT_TO_LEFT\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 4) & ((1u << 2) - 1);
        fprintf(fp, "%s.VERTICAL = ", prefix);
        switch (parsed) {
        case NV902D_SET_PIXELS_FROM_MEMORY_DIRECTION_VERTICAL_HW_DECIDES:
            fprintf(fp, "HW_DECIDES\n");
            break;
        case NV902D_SET_PIXELS_FROM_MEMORY_DIRECTION_VERTICAL_TOP_TO_BOTTOM:
            fprintf(fp, "TOP_TO_BOTTOM\n");
            break;
        case NV902D_SET_PIXELS_FROM_MEMORY_DIRECTION_VERTICAL_BOTTOM_TO_TOP:
            fprintf(fp, "BOTTOM_TO_TOP\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_SPARE_NOOP10:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_MONOCHROME_PATTERN_COLOR_FORMAT:

    
        parsed = (data >> 0) & ((1u << 3) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_SET_MONOCHROME_PATTERN_COLOR_FORMAT_V_A8X8R5G6B5:
            fprintf(fp, "A8X8R5G6B5\n");
            break;
        case NV902D_SET_MONOCHROME_PATTERN_COLOR_FORMAT_V_A1R5G5B5:
            fprintf(fp, "A1R5G5B5\n");
            break;
        case NV902D_SET_MONOCHROME_PATTERN_COLOR_FORMAT_V_A8R8G8B8:
            fprintf(fp, "A8R8G8B8\n");
            break;
        case NV902D_SET_MONOCHROME_PATTERN_COLOR_FORMAT_V_A8Y8:
            fprintf(fp, "A8Y8\n");
            break;
        case NV902D_SET_MONOCHROME_PATTERN_COLOR_FORMAT_V_A8X8Y16:
            fprintf(fp, "A8X8Y16\n");
            break;
        case NV902D_SET_MONOCHROME_PATTERN_COLOR_FORMAT_V_Y32:
            fprintf(fp, "Y32\n");
            break;
        case NV902D_SET_MONOCHROME_PATTERN_COLOR_FORMAT_V_BYTE_EXPAND:
            fprintf(fp, "BYTE_EXPAND\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_MONOCHROME_PATTERN_FORMAT:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_SET_MONOCHROME_PATTERN_FORMAT_V_CGA6_M1:
            fprintf(fp, "CGA6_M1\n");
            break;
        case NV902D_SET_MONOCHROME_PATTERN_FORMAT_V_LE_M1:
            fprintf(fp, "LE_M1\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_MONOCHROME_PATTERN_COLOR0:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_MONOCHROME_PATTERN_COLOR1:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_MONOCHROME_PATTERN0:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_MONOCHROME_PATTERN1:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
                  
    case NV902D_SET_RENDER_SOLID_PRIM_COLOR0:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_RENDER_SOLID_PRIM_COLOR1:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_RENDER_SOLID_PRIM_COLOR2:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_RENDER_SOLID_PRIM_COLOR3:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_MME_MEM_ADDRESS_A:

    
        parsed = (data >> 0) & ((1u << 25) - 1);
        fprintf(fp, "%s.UPPER = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_MME_MEM_ADDRESS_B:

    
        parsed = data;
        fprintf(fp, "%s.LOWER = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_MME_DATA_RAM_ADDRESS:

    
        parsed = data;
        fprintf(fp, "%s.WORD = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_MME_DMA_READ:

    
        parsed = data;
        fprintf(fp, "%s.LENGTH = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_MME_DMA_READ_FIFOED:

    
        parsed = data;
        fprintf(fp, "%s.LENGTH = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_MME_DMA_WRITE:

    
        parsed = data;
        fprintf(fp, "%s.LENGTH = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_MME_DMA_REDUCTION:

    
        parsed = (data >> 0) & ((1u << 3) - 1);
        fprintf(fp, "%s.REDUCTION_OP = ", prefix);
        switch (parsed) {
        case NV902D_MME_DMA_REDUCTION_REDUCTION_OP_RED_ADD:
            fprintf(fp, "RED_ADD\n");
            break;
        case NV902D_MME_DMA_REDUCTION_REDUCTION_OP_RED_MIN:
            fprintf(fp, "RED_MIN\n");
            break;
        case NV902D_MME_DMA_REDUCTION_REDUCTION_OP_RED_MAX:
            fprintf(fp, "RED_MAX\n");
            break;
        case NV902D_MME_DMA_REDUCTION_REDUCTION_OP_RED_INC:
            fprintf(fp, "RED_INC\n");
            break;
        case NV902D_MME_DMA_REDUCTION_REDUCTION_OP_RED_DEC:
            fprintf(fp, "RED_DEC\n");
            break;
        case NV902D_MME_DMA_REDUCTION_REDUCTION_OP_RED_AND:
            fprintf(fp, "RED_AND\n");
            break;
        case NV902D_MME_DMA_REDUCTION_REDUCTION_OP_RED_OR:
            fprintf(fp, "RED_OR\n");
            break;
        case NV902D_MME_DMA_REDUCTION_REDUCTION_OP_RED_XOR:
            fprintf(fp, "RED_XOR\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 4) & ((1u << 2) - 1);
        fprintf(fp, "%s.REDUCTION_FORMAT = ", prefix);
        switch (parsed) {
        case NV902D_MME_DMA_REDUCTION_REDUCTION_FORMAT_UNSIGNED:
            fprintf(fp, "UNSIGNED\n");
            break;
        case NV902D_MME_DMA_REDUCTION_REDUCTION_FORMAT_SIGNED:
            fprintf(fp, "SIGNED\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 8) & ((1u << 1) - 1);
        fprintf(fp, "%s.REDUCTION_SIZE = ", prefix);
        switch (parsed) {
        case NV902D_MME_DMA_REDUCTION_REDUCTION_SIZE_FOUR_BYTES:
            fprintf(fp, "FOUR_BYTES\n");
            break;
        case NV902D_MME_DMA_REDUCTION_REDUCTION_SIZE_EIGHT_BYTES:
            fprintf(fp, "EIGHT_BYTES\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_MME_DMA_SYSMEMBAR:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_MME_DMA_SYNC:

    
        parsed = data;
        fprintf(fp, "%s.VALUE = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_MME_DATA_FIFO_CONFIG:

    
        parsed = (data >> 0) & ((1u << 3) - 1);
        fprintf(fp, "%s.FIFO_SIZE = ", prefix);
        switch (parsed) {
        case NV902D_SET_MME_DATA_FIFO_CONFIG_FIFO_SIZE_SIZE_0KB:
            fprintf(fp, "SIZE_0KB\n");
            break;
        case NV902D_SET_MME_DATA_FIFO_CONFIG_FIFO_SIZE_SIZE_4KB:
            fprintf(fp, "SIZE_4KB\n");
            break;
        case NV902D_SET_MME_DATA_FIFO_CONFIG_FIFO_SIZE_SIZE_8KB:
            fprintf(fp, "SIZE_8KB\n");
            break;
        case NV902D_SET_MME_DATA_FIFO_CONFIG_FIFO_SIZE_SIZE_12KB:
            fprintf(fp, "SIZE_12KB\n");
            break;
        case NV902D_SET_MME_DATA_FIFO_CONFIG_FIFO_SIZE_SIZE_16KB:
            fprintf(fp, "SIZE_16KB\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_RENDER_SOLID_PRIM_MODE:

    
        parsed = (data >> 0) & ((1u << 3) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_RENDER_SOLID_PRIM_MODE_V_POINTS:
            fprintf(fp, "POINTS\n");
            break;
        case NV902D_RENDER_SOLID_PRIM_MODE_V_LINES:
            fprintf(fp, "LINES\n");
            break;
        case NV902D_RENDER_SOLID_PRIM_MODE_V_POLYLINE:
            fprintf(fp, "POLYLINE\n");
            break;
        case NV902D_RENDER_SOLID_PRIM_MODE_V_TRIANGLES:
            fprintf(fp, "TRIANGLES\n");
            break;
        case NV902D_RENDER_SOLID_PRIM_MODE_V_RECTS:
            fprintf(fp, "RECTS\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_RENDER_SOLID_PRIM_COLOR_FORMAT:

    
        parsed = (data >> 0) & ((1u << 8) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_SET_RENDER_SOLID_PRIM_COLOR_FORMAT_V_RF32_GF32_BF32_AF32:
            fprintf(fp, "RF32_GF32_BF32_AF32\n");
            break;
        case NV902D_SET_RENDER_SOLID_PRIM_COLOR_FORMAT_V_RF16_GF16_BF16_AF16:
            fprintf(fp, "RF16_GF16_BF16_AF16\n");
            break;
        case NV902D_SET_RENDER_SOLID_PRIM_COLOR_FORMAT_V_RF32_GF32:
            fprintf(fp, "RF32_GF32\n");
            break;
        case NV902D_SET_RENDER_SOLID_PRIM_COLOR_FORMAT_V_A8R8G8B8:
            fprintf(fp, "A8R8G8B8\n");
            break;
        case NV902D_SET_RENDER_SOLID_PRIM_COLOR_FORMAT_V_A2R10G10B10:
            fprintf(fp, "A2R10G10B10\n");
            break;
        case NV902D_SET_RENDER_SOLID_PRIM_COLOR_FORMAT_V_A8B8G8R8:
            fprintf(fp, "A8B8G8R8\n");
            break;
        case NV902D_SET_RENDER_SOLID_PRIM_COLOR_FORMAT_V_A2B10G10R10:
            fprintf(fp, "A2B10G10R10\n");
            break;
        case NV902D_SET_RENDER_SOLID_PRIM_COLOR_FORMAT_V_X8R8G8B8:
            fprintf(fp, "X8R8G8B8\n");
            break;
        case NV902D_SET_RENDER_SOLID_PRIM_COLOR_FORMAT_V_X8B8G8R8:
            fprintf(fp, "X8B8G8R8\n");
            break;
        case NV902D_SET_RENDER_SOLID_PRIM_COLOR_FORMAT_V_R5G6B5:
            fprintf(fp, "R5G6B5\n");
            break;
        case NV902D_SET_RENDER_SOLID_PRIM_COLOR_FORMAT_V_A1R5G5B5:
            fprintf(fp, "A1R5G5B5\n");
            break;
        case NV902D_SET_RENDER_SOLID_PRIM_COLOR_FORMAT_V_X1R5G5B5:
            fprintf(fp, "X1R5G5B5\n");
            break;
        case NV902D_SET_RENDER_SOLID_PRIM_COLOR_FORMAT_V_Y8:
            fprintf(fp, "Y8\n");
            break;
        case NV902D_SET_RENDER_SOLID_PRIM_COLOR_FORMAT_V_Y16:
            fprintf(fp, "Y16\n");
            break;
        case NV902D_SET_RENDER_SOLID_PRIM_COLOR_FORMAT_V_Y32:
            fprintf(fp, "Y32\n");
            break;
        case NV902D_SET_RENDER_SOLID_PRIM_COLOR_FORMAT_V_Z1R5G5B5:
            fprintf(fp, "Z1R5G5B5\n");
            break;
        case NV902D_SET_RENDER_SOLID_PRIM_COLOR_FORMAT_V_O1R5G5B5:
            fprintf(fp, "O1R5G5B5\n");
            break;
        case NV902D_SET_RENDER_SOLID_PRIM_COLOR_FORMAT_V_Z8R8G8B8:
            fprintf(fp, "Z8R8G8B8\n");
            break;
        case NV902D_SET_RENDER_SOLID_PRIM_COLOR_FORMAT_V_O8R8G8B8:
            fprintf(fp, "O8R8G8B8\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_RENDER_SOLID_PRIM_COLOR:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_RENDER_SOLID_LINE_TIE_BREAK_BITS:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.XMAJ__XINC__YINC = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 4) & ((1u << 1) - 1);
        fprintf(fp, "%s.XMAJ__XDEC__YINC = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 8) & ((1u << 1) - 1);
        fprintf(fp, "%s.YMAJ__XINC__YINC = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 12) & ((1u << 1) - 1);
        fprintf(fp, "%s.YMAJ__XDEC__YINC = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_RENDER_SOLID_PRIM_POINT_X_Y:

    
        parsed = (data >> 0) & ((1u << 16) - 1);
        fprintf(fp, "%s.X = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 16) & ((1u << 16) - 1);
        fprintf(fp, "%s.Y = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
          
    case NV902D_SET_PIXELS_FROM_CPU_DATA_TYPE:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_SET_PIXELS_FROM_CPU_DATA_TYPE_V_COLOR:
            fprintf(fp, "COLOR\n");
            break;
        case NV902D_SET_PIXELS_FROM_CPU_DATA_TYPE_V_INDEX:
            fprintf(fp, "INDEX\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_PIXELS_FROM_CPU_COLOR_FORMAT:

    
        parsed = (data >> 0) & ((1u << 8) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_SET_PIXELS_FROM_CPU_COLOR_FORMAT_V_A8R8G8B8:
            fprintf(fp, "A8R8G8B8\n");
            break;
        case NV902D_SET_PIXELS_FROM_CPU_COLOR_FORMAT_V_A2R10G10B10:
            fprintf(fp, "A2R10G10B10\n");
            break;
        case NV902D_SET_PIXELS_FROM_CPU_COLOR_FORMAT_V_A8B8G8R8:
            fprintf(fp, "A8B8G8R8\n");
            break;
        case NV902D_SET_PIXELS_FROM_CPU_COLOR_FORMAT_V_A2B10G10R10:
            fprintf(fp, "A2B10G10R10\n");
            break;
        case NV902D_SET_PIXELS_FROM_CPU_COLOR_FORMAT_V_X8R8G8B8:
            fprintf(fp, "X8R8G8B8\n");
            break;
        case NV902D_SET_PIXELS_FROM_CPU_COLOR_FORMAT_V_X8B8G8R8:
            fprintf(fp, "X8B8G8R8\n");
            break;
        case NV902D_SET_PIXELS_FROM_CPU_COLOR_FORMAT_V_R5G6B5:
            fprintf(fp, "R5G6B5\n");
            break;
        case NV902D_SET_PIXELS_FROM_CPU_COLOR_FORMAT_V_A1R5G5B5:
            fprintf(fp, "A1R5G5B5\n");
            break;
        case NV902D_SET_PIXELS_FROM_CPU_COLOR_FORMAT_V_X1R5G5B5:
            fprintf(fp, "X1R5G5B5\n");
            break;
        case NV902D_SET_PIXELS_FROM_CPU_COLOR_FORMAT_V_Y8:
            fprintf(fp, "Y8\n");
            break;
        case NV902D_SET_PIXELS_FROM_CPU_COLOR_FORMAT_V_Y16:
            fprintf(fp, "Y16\n");
            break;
        case NV902D_SET_PIXELS_FROM_CPU_COLOR_FORMAT_V_Y32:
            fprintf(fp, "Y32\n");
            break;
        case NV902D_SET_PIXELS_FROM_CPU_COLOR_FORMAT_V_Z1R5G5B5:
            fprintf(fp, "Z1R5G5B5\n");
            break;
        case NV902D_SET_PIXELS_FROM_CPU_COLOR_FORMAT_V_O1R5G5B5:
            fprintf(fp, "O1R5G5B5\n");
            break;
        case NV902D_SET_PIXELS_FROM_CPU_COLOR_FORMAT_V_Z8R8G8B8:
            fprintf(fp, "Z8R8G8B8\n");
            break;
        case NV902D_SET_PIXELS_FROM_CPU_COLOR_FORMAT_V_O8R8G8B8:
            fprintf(fp, "O8R8G8B8\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_PIXELS_FROM_CPU_INDEX_FORMAT:

    
        parsed = (data >> 0) & ((1u << 2) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_SET_PIXELS_FROM_CPU_INDEX_FORMAT_V_I1:
            fprintf(fp, "I1\n");
            break;
        case NV902D_SET_PIXELS_FROM_CPU_INDEX_FORMAT_V_I4:
            fprintf(fp, "I4\n");
            break;
        case NV902D_SET_PIXELS_FROM_CPU_INDEX_FORMAT_V_I8:
            fprintf(fp, "I8\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_PIXELS_FROM_CPU_MONO_FORMAT:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_SET_PIXELS_FROM_CPU_MONO_FORMAT_V_CGA6_M1:
            fprintf(fp, "CGA6_M1\n");
            break;
        case NV902D_SET_PIXELS_FROM_CPU_MONO_FORMAT_V_LE_M1:
            fprintf(fp, "LE_M1\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_PIXELS_FROM_CPU_WRAP:

    
        parsed = (data >> 0) & ((1u << 2) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_SET_PIXELS_FROM_CPU_WRAP_V_WRAP_PIXEL:
            fprintf(fp, "WRAP_PIXEL\n");
            break;
        case NV902D_SET_PIXELS_FROM_CPU_WRAP_V_WRAP_BYTE:
            fprintf(fp, "WRAP_BYTE\n");
            break;
        case NV902D_SET_PIXELS_FROM_CPU_WRAP_V_WRAP_DWORD:
            fprintf(fp, "WRAP_DWORD\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_PIXELS_FROM_CPU_COLOR0:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PIXELS_FROM_CPU_COLOR1:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PIXELS_FROM_CPU_MONO_OPACITY:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_SET_PIXELS_FROM_CPU_MONO_OPACITY_V_TRANSPARENT:
            fprintf(fp, "TRANSPARENT\n");
            break;
        case NV902D_SET_PIXELS_FROM_CPU_MONO_OPACITY_V_OPAQUE:
            fprintf(fp, "OPAQUE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_PIXELS_FROM_CPU_SRC_WIDTH:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PIXELS_FROM_CPU_SRC_HEIGHT:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PIXELS_FROM_CPU_DX_DU_FRAC:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PIXELS_FROM_CPU_DX_DU_INT:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PIXELS_FROM_CPU_DY_DV_FRAC:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PIXELS_FROM_CPU_DY_DV_INT:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PIXELS_FROM_CPU_DST_X0_FRAC:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PIXELS_FROM_CPU_DST_X0_INT:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PIXELS_FROM_CPU_DST_Y0_FRAC:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PIXELS_FROM_CPU_DST_Y0_INT:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_PIXELS_FROM_CPU_DATA:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_BIG_ENDIAN_CONTROL:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.X32_SWAP_1 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 1) & ((1u << 1) - 1);
        fprintf(fp, "%s.X32_SWAP_4 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 2) & ((1u << 1) - 1);
        fprintf(fp, "%s.X32_SWAP_8 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 3) & ((1u << 1) - 1);
        fprintf(fp, "%s.X32_SWAP_16 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 4) & ((1u << 1) - 1);
        fprintf(fp, "%s.X16_SWAP_1 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 5) & ((1u << 1) - 1);
        fprintf(fp, "%s.X16_SWAP_4 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 6) & ((1u << 1) - 1);
        fprintf(fp, "%s.X16_SWAP_8 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 7) & ((1u << 1) - 1);
        fprintf(fp, "%s.X16_SWAP_16 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 8) & ((1u << 1) - 1);
        fprintf(fp, "%s.X8_SWAP_1 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 9) & ((1u << 1) - 1);
        fprintf(fp, "%s.X8_SWAP_4 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 10) & ((1u << 1) - 1);
        fprintf(fp, "%s.X8_SWAP_8 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 11) & ((1u << 1) - 1);
        fprintf(fp, "%s.X8_SWAP_16 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 12) & ((1u << 1) - 1);
        fprintf(fp, "%s.I1_X8_CGA6_SWAP_1 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 13) & ((1u << 1) - 1);
        fprintf(fp, "%s.I1_X8_CGA6_SWAP_4 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 14) & ((1u << 1) - 1);
        fprintf(fp, "%s.I1_X8_CGA6_SWAP_8 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 15) & ((1u << 1) - 1);
        fprintf(fp, "%s.I1_X8_CGA6_SWAP_16 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 16) & ((1u << 1) - 1);
        fprintf(fp, "%s.I1_X8_LE_SWAP_1 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 17) & ((1u << 1) - 1);
        fprintf(fp, "%s.I1_X8_LE_SWAP_4 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 18) & ((1u << 1) - 1);
        fprintf(fp, "%s.I1_X8_LE_SWAP_8 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 19) & ((1u << 1) - 1);
        fprintf(fp, "%s.I1_X8_LE_SWAP_16 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 20) & ((1u << 1) - 1);
        fprintf(fp, "%s.I4_SWAP_1 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 21) & ((1u << 1) - 1);
        fprintf(fp, "%s.I4_SWAP_4 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 22) & ((1u << 1) - 1);
        fprintf(fp, "%s.I4_SWAP_8 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 23) & ((1u << 1) - 1);
        fprintf(fp, "%s.I4_SWAP_16 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 24) & ((1u << 1) - 1);
        fprintf(fp, "%s.I8_SWAP_1 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 25) & ((1u << 1) - 1);
        fprintf(fp, "%s.I8_SWAP_4 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 26) & ((1u << 1) - 1);
        fprintf(fp, "%s.I8_SWAP_8 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 27) & ((1u << 1) - 1);
        fprintf(fp, "%s.I8_SWAP_16 = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
    
        parsed = (data >> 28) & ((1u << 1) - 1);
        fprintf(fp, "%s.OVERRIDE = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PIXELS_FROM_MEMORY_BLOCK_SHAPE:

    
        parsed = (data >> 0) & ((1u << 3) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_SET_PIXELS_FROM_MEMORY_BLOCK_SHAPE_V_AUTO:
            fprintf(fp, "AUTO\n");
            break;
        case NV902D_SET_PIXELS_FROM_MEMORY_BLOCK_SHAPE_V_SHAPE_8X8:
            fprintf(fp, "SHAPE_8X8\n");
            break;
        case NV902D_SET_PIXELS_FROM_MEMORY_BLOCK_SHAPE_V_SHAPE_16X4:
            fprintf(fp, "SHAPE_16X4\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_PIXELS_FROM_MEMORY_CORRAL_SIZE:

    
        parsed = (data >> 0) & ((1u << 10) - 1);
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PIXELS_FROM_MEMORY_SAFE_OVERLAP:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.V = ", prefix);
        switch (parsed) {
        case NV902D_SET_PIXELS_FROM_MEMORY_SAFE_OVERLAP_V_FALSE:
            fprintf(fp, "FALSE\n");
            break;
        case NV902D_SET_PIXELS_FROM_MEMORY_SAFE_OVERLAP_V_TRUE:
            fprintf(fp, "TRUE\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_PIXELS_FROM_MEMORY_SAMPLE_MODE:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.ORIGIN = ", prefix);
        switch (parsed) {
        case NV902D_SET_PIXELS_FROM_MEMORY_SAMPLE_MODE_ORIGIN_CENTER:
            fprintf(fp, "CENTER\n");
            break;
        case NV902D_SET_PIXELS_FROM_MEMORY_SAMPLE_MODE_ORIGIN_CORNER:
            fprintf(fp, "CORNER\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
    
        parsed = (data >> 4) & ((1u << 1) - 1);
        fprintf(fp, "%s.FILTER = ", prefix);
        switch (parsed) {
        case NV902D_SET_PIXELS_FROM_MEMORY_SAMPLE_MODE_FILTER_POINT:
            fprintf(fp, "POINT\n");
            break;
        case NV902D_SET_PIXELS_FROM_MEMORY_SAMPLE_MODE_FILTER_BILINEAR:
            fprintf(fp, "BILINEAR\n");
            break;
        default:
            fprintf(fp, "0x%x\n", parsed);
            break;
        }
        break;
  
    case NV902D_SET_PIXELS_FROM_MEMORY_DST_X0:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PIXELS_FROM_MEMORY_DST_Y0:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PIXELS_FROM_MEMORY_DST_WIDTH:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PIXELS_FROM_MEMORY_DST_HEIGHT:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PIXELS_FROM_MEMORY_DU_DX_FRAC:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PIXELS_FROM_MEMORY_DU_DX_INT:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PIXELS_FROM_MEMORY_DV_DY_FRAC:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PIXELS_FROM_MEMORY_DV_DY_INT:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PIXELS_FROM_MEMORY_SRC_X0_FRAC:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PIXELS_FROM_MEMORY_SRC_X0_INT:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_PIXELS_FROM_MEMORY_SRC_Y0_FRAC:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_PIXELS_FROM_MEMORY_SRC_Y0_INT:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON00:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON01:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON02:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON03:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON04:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON05:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON06:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON07:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON08:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON09:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON10:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON11:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON12:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON13:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON14:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON15:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON16:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON17:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON18:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON19:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON20:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON21:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON22:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON23:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON24:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON25:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON26:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON27:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON28:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON29:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON30:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_FALCON31:

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_MME_DMA_WRITE_METHOD_BARRIER:

    
        parsed = (data >> 0) & ((1u << 1) - 1);
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_SET_MME_SHADOW_SCRATCH(0):
    case NV902D_SET_MME_SHADOW_SCRATCH(1):
    case NV902D_SET_MME_SHADOW_SCRATCH(2):
    case NV902D_SET_MME_SHADOW_SCRATCH(3):
    case NV902D_SET_MME_SHADOW_SCRATCH(4):
    case NV902D_SET_MME_SHADOW_SCRATCH(5):
    case NV902D_SET_MME_SHADOW_SCRATCH(6):
    case NV902D_SET_MME_SHADOW_SCRATCH(7):
    case NV902D_SET_MME_SHADOW_SCRATCH(8):
    case NV902D_SET_MME_SHADOW_SCRATCH(9):
    case NV902D_SET_MME_SHADOW_SCRATCH(10):
    case NV902D_SET_MME_SHADOW_SCRATCH(11):
    case NV902D_SET_MME_SHADOW_SCRATCH(12):
    case NV902D_SET_MME_SHADOW_SCRATCH(13):
    case NV902D_SET_MME_SHADOW_SCRATCH(14):
    case NV902D_SET_MME_SHADOW_SCRATCH(15):
    case NV902D_SET_MME_SHADOW_SCRATCH(16):
    case NV902D_SET_MME_SHADOW_SCRATCH(17):
    case NV902D_SET_MME_SHADOW_SCRATCH(18):
    case NV902D_SET_MME_SHADOW_SCRATCH(19):
    case NV902D_SET_MME_SHADOW_SCRATCH(20):
    case NV902D_SET_MME_SHADOW_SCRATCH(21):
    case NV902D_SET_MME_SHADOW_SCRATCH(22):
    case NV902D_SET_MME_SHADOW_SCRATCH(23):
    case NV902D_SET_MME_SHADOW_SCRATCH(24):
    case NV902D_SET_MME_SHADOW_SCRATCH(25):
    case NV902D_SET_MME_SHADOW_SCRATCH(26):
    case NV902D_SET_MME_SHADOW_SCRATCH(27):
    case NV902D_SET_MME_SHADOW_SCRATCH(28):
    case NV902D_SET_MME_SHADOW_SCRATCH(29):
    case NV902D_SET_MME_SHADOW_SCRATCH(30):
    case NV902D_SET_MME_SHADOW_SCRATCH(31):
    case NV902D_SET_MME_SHADOW_SCRATCH(32):
    case NV902D_SET_MME_SHADOW_SCRATCH(33):
    case NV902D_SET_MME_SHADOW_SCRATCH(34):
    case NV902D_SET_MME_SHADOW_SCRATCH(35):
    case NV902D_SET_MME_SHADOW_SCRATCH(36):
    case NV902D_SET_MME_SHADOW_SCRATCH(37):
    case NV902D_SET_MME_SHADOW_SCRATCH(38):
    case NV902D_SET_MME_SHADOW_SCRATCH(39):
    case NV902D_SET_MME_SHADOW_SCRATCH(40):
    case NV902D_SET_MME_SHADOW_SCRATCH(41):
    case NV902D_SET_MME_SHADOW_SCRATCH(42):
    case NV902D_SET_MME_SHADOW_SCRATCH(43):
    case NV902D_SET_MME_SHADOW_SCRATCH(44):
    case NV902D_SET_MME_SHADOW_SCRATCH(45):
    case NV902D_SET_MME_SHADOW_SCRATCH(46):
    case NV902D_SET_MME_SHADOW_SCRATCH(47):
    case NV902D_SET_MME_SHADOW_SCRATCH(48):
    case NV902D_SET_MME_SHADOW_SCRATCH(49):
    case NV902D_SET_MME_SHADOW_SCRATCH(50):
    case NV902D_SET_MME_SHADOW_SCRATCH(51):
    case NV902D_SET_MME_SHADOW_SCRATCH(52):
    case NV902D_SET_MME_SHADOW_SCRATCH(53):
    case NV902D_SET_MME_SHADOW_SCRATCH(54):
    case NV902D_SET_MME_SHADOW_SCRATCH(55):
    case NV902D_SET_MME_SHADOW_SCRATCH(56):
    case NV902D_SET_MME_SHADOW_SCRATCH(57):
    case NV902D_SET_MME_SHADOW_SCRATCH(58):
    case NV902D_SET_MME_SHADOW_SCRATCH(59):
    case NV902D_SET_MME_SHADOW_SCRATCH(60):
    case NV902D_SET_MME_SHADOW_SCRATCH(61):
    case NV902D_SET_MME_SHADOW_SCRATCH(62):
    case NV902D_SET_MME_SHADOW_SCRATCH(63):
    case NV902D_SET_MME_SHADOW_SCRATCH(64):
    case NV902D_SET_MME_SHADOW_SCRATCH(65):
    case NV902D_SET_MME_SHADOW_SCRATCH(66):
    case NV902D_SET_MME_SHADOW_SCRATCH(67):
    case NV902D_SET_MME_SHADOW_SCRATCH(68):
    case NV902D_SET_MME_SHADOW_SCRATCH(69):
    case NV902D_SET_MME_SHADOW_SCRATCH(70):
    case NV902D_SET_MME_SHADOW_SCRATCH(71):
    case NV902D_SET_MME_SHADOW_SCRATCH(72):
    case NV902D_SET_MME_SHADOW_SCRATCH(73):
    case NV902D_SET_MME_SHADOW_SCRATCH(74):
    case NV902D_SET_MME_SHADOW_SCRATCH(75):
    case NV902D_SET_MME_SHADOW_SCRATCH(76):
    case NV902D_SET_MME_SHADOW_SCRATCH(77):
    case NV902D_SET_MME_SHADOW_SCRATCH(78):
    case NV902D_SET_MME_SHADOW_SCRATCH(79):
    case NV902D_SET_MME_SHADOW_SCRATCH(80):
    case NV902D_SET_MME_SHADOW_SCRATCH(81):
    case NV902D_SET_MME_SHADOW_SCRATCH(82):
    case NV902D_SET_MME_SHADOW_SCRATCH(83):
    case NV902D_SET_MME_SHADOW_SCRATCH(84):
    case NV902D_SET_MME_SHADOW_SCRATCH(85):
    case NV902D_SET_MME_SHADOW_SCRATCH(86):
    case NV902D_SET_MME_SHADOW_SCRATCH(87):
    case NV902D_SET_MME_SHADOW_SCRATCH(88):
    case NV902D_SET_MME_SHADOW_SCRATCH(89):
    case NV902D_SET_MME_SHADOW_SCRATCH(90):
    case NV902D_SET_MME_SHADOW_SCRATCH(91):
    case NV902D_SET_MME_SHADOW_SCRATCH(92):
    case NV902D_SET_MME_SHADOW_SCRATCH(93):
    case NV902D_SET_MME_SHADOW_SCRATCH(94):
    case NV902D_SET_MME_SHADOW_SCRATCH(95):
    case NV902D_SET_MME_SHADOW_SCRATCH(96):
    case NV902D_SET_MME_SHADOW_SCRATCH(97):
    case NV902D_SET_MME_SHADOW_SCRATCH(98):
    case NV902D_SET_MME_SHADOW_SCRATCH(99):
    case NV902D_SET_MME_SHADOW_SCRATCH(100):
    case NV902D_SET_MME_SHADOW_SCRATCH(101):
    case NV902D_SET_MME_SHADOW_SCRATCH(102):
    case NV902D_SET_MME_SHADOW_SCRATCH(103):
    case NV902D_SET_MME_SHADOW_SCRATCH(104):
    case NV902D_SET_MME_SHADOW_SCRATCH(105):
    case NV902D_SET_MME_SHADOW_SCRATCH(106):
    case NV902D_SET_MME_SHADOW_SCRATCH(107):
    case NV902D_SET_MME_SHADOW_SCRATCH(108):
    case NV902D_SET_MME_SHADOW_SCRATCH(109):
    case NV902D_SET_MME_SHADOW_SCRATCH(110):
    case NV902D_SET_MME_SHADOW_SCRATCH(111):
    case NV902D_SET_MME_SHADOW_SCRATCH(112):
    case NV902D_SET_MME_SHADOW_SCRATCH(113):
    case NV902D_SET_MME_SHADOW_SCRATCH(114):
    case NV902D_SET_MME_SHADOW_SCRATCH(115):
    case NV902D_SET_MME_SHADOW_SCRATCH(116):
    case NV902D_SET_MME_SHADOW_SCRATCH(117):
    case NV902D_SET_MME_SHADOW_SCRATCH(118):
    case NV902D_SET_MME_SHADOW_SCRATCH(119):
    case NV902D_SET_MME_SHADOW_SCRATCH(120):
    case NV902D_SET_MME_SHADOW_SCRATCH(121):
    case NV902D_SET_MME_SHADOW_SCRATCH(122):
    case NV902D_SET_MME_SHADOW_SCRATCH(123):
    case NV902D_SET_MME_SHADOW_SCRATCH(124):
    case NV902D_SET_MME_SHADOW_SCRATCH(125):
    case NV902D_SET_MME_SHADOW_SCRATCH(126):
    case NV902D_SET_MME_SHADOW_SCRATCH(127):
    case NV902D_SET_MME_SHADOW_SCRATCH(128):
    case NV902D_SET_MME_SHADOW_SCRATCH(129):
    case NV902D_SET_MME_SHADOW_SCRATCH(130):
    case NV902D_SET_MME_SHADOW_SCRATCH(131):
    case NV902D_SET_MME_SHADOW_SCRATCH(132):
    case NV902D_SET_MME_SHADOW_SCRATCH(133):
    case NV902D_SET_MME_SHADOW_SCRATCH(134):
    case NV902D_SET_MME_SHADOW_SCRATCH(135):
    case NV902D_SET_MME_SHADOW_SCRATCH(136):
    case NV902D_SET_MME_SHADOW_SCRATCH(137):
    case NV902D_SET_MME_SHADOW_SCRATCH(138):
    case NV902D_SET_MME_SHADOW_SCRATCH(139):
    case NV902D_SET_MME_SHADOW_SCRATCH(140):
    case NV902D_SET_MME_SHADOW_SCRATCH(141):
    case NV902D_SET_MME_SHADOW_SCRATCH(142):
    case NV902D_SET_MME_SHADOW_SCRATCH(143):
    case NV902D_SET_MME_SHADOW_SCRATCH(144):
    case NV902D_SET_MME_SHADOW_SCRATCH(145):
    case NV902D_SET_MME_SHADOW_SCRATCH(146):
    case NV902D_SET_MME_SHADOW_SCRATCH(147):
    case NV902D_SET_MME_SHADOW_SCRATCH(148):
    case NV902D_SET_MME_SHADOW_SCRATCH(149):
    case NV902D_SET_MME_SHADOW_SCRATCH(150):
    case NV902D_SET_MME_SHADOW_SCRATCH(151):
    case NV902D_SET_MME_SHADOW_SCRATCH(152):
    case NV902D_SET_MME_SHADOW_SCRATCH(153):
    case NV902D_SET_MME_SHADOW_SCRATCH(154):
    case NV902D_SET_MME_SHADOW_SCRATCH(155):
    case NV902D_SET_MME_SHADOW_SCRATCH(156):
    case NV902D_SET_MME_SHADOW_SCRATCH(157):
    case NV902D_SET_MME_SHADOW_SCRATCH(158):
    case NV902D_SET_MME_SHADOW_SCRATCH(159):
    case NV902D_SET_MME_SHADOW_SCRATCH(160):
    case NV902D_SET_MME_SHADOW_SCRATCH(161):
    case NV902D_SET_MME_SHADOW_SCRATCH(162):
    case NV902D_SET_MME_SHADOW_SCRATCH(163):
    case NV902D_SET_MME_SHADOW_SCRATCH(164):
    case NV902D_SET_MME_SHADOW_SCRATCH(165):
    case NV902D_SET_MME_SHADOW_SCRATCH(166):
    case NV902D_SET_MME_SHADOW_SCRATCH(167):
    case NV902D_SET_MME_SHADOW_SCRATCH(168):
    case NV902D_SET_MME_SHADOW_SCRATCH(169):
    case NV902D_SET_MME_SHADOW_SCRATCH(170):
    case NV902D_SET_MME_SHADOW_SCRATCH(171):
    case NV902D_SET_MME_SHADOW_SCRATCH(172):
    case NV902D_SET_MME_SHADOW_SCRATCH(173):
    case NV902D_SET_MME_SHADOW_SCRATCH(174):
    case NV902D_SET_MME_SHADOW_SCRATCH(175):
    case NV902D_SET_MME_SHADOW_SCRATCH(176):
    case NV902D_SET_MME_SHADOW_SCRATCH(177):
    case NV902D_SET_MME_SHADOW_SCRATCH(178):
    case NV902D_SET_MME_SHADOW_SCRATCH(179):
    case NV902D_SET_MME_SHADOW_SCRATCH(180):
    case NV902D_SET_MME_SHADOW_SCRATCH(181):
    case NV902D_SET_MME_SHADOW_SCRATCH(182):
    case NV902D_SET_MME_SHADOW_SCRATCH(183):
    case NV902D_SET_MME_SHADOW_SCRATCH(184):
    case NV902D_SET_MME_SHADOW_SCRATCH(185):
    case NV902D_SET_MME_SHADOW_SCRATCH(186):
    case NV902D_SET_MME_SHADOW_SCRATCH(187):
    case NV902D_SET_MME_SHADOW_SCRATCH(188):
    case NV902D_SET_MME_SHADOW_SCRATCH(189):
    case NV902D_SET_MME_SHADOW_SCRATCH(190):
    case NV902D_SET_MME_SHADOW_SCRATCH(191):
    case NV902D_SET_MME_SHADOW_SCRATCH(192):
    case NV902D_SET_MME_SHADOW_SCRATCH(193):
    case NV902D_SET_MME_SHADOW_SCRATCH(194):
    case NV902D_SET_MME_SHADOW_SCRATCH(195):
    case NV902D_SET_MME_SHADOW_SCRATCH(196):
    case NV902D_SET_MME_SHADOW_SCRATCH(197):
    case NV902D_SET_MME_SHADOW_SCRATCH(198):
    case NV902D_SET_MME_SHADOW_SCRATCH(199):
    case NV902D_SET_MME_SHADOW_SCRATCH(200):
    case NV902D_SET_MME_SHADOW_SCRATCH(201):
    case NV902D_SET_MME_SHADOW_SCRATCH(202):
    case NV902D_SET_MME_SHADOW_SCRATCH(203):
    case NV902D_SET_MME_SHADOW_SCRATCH(204):
    case NV902D_SET_MME_SHADOW_SCRATCH(205):
    case NV902D_SET_MME_SHADOW_SCRATCH(206):
    case NV902D_SET_MME_SHADOW_SCRATCH(207):
    case NV902D_SET_MME_SHADOW_SCRATCH(208):
    case NV902D_SET_MME_SHADOW_SCRATCH(209):
    case NV902D_SET_MME_SHADOW_SCRATCH(210):
    case NV902D_SET_MME_SHADOW_SCRATCH(211):
    case NV902D_SET_MME_SHADOW_SCRATCH(212):
    case NV902D_SET_MME_SHADOW_SCRATCH(213):
    case NV902D_SET_MME_SHADOW_SCRATCH(214):
    case NV902D_SET_MME_SHADOW_SCRATCH(215):
    case NV902D_SET_MME_SHADOW_SCRATCH(216):
    case NV902D_SET_MME_SHADOW_SCRATCH(217):
    case NV902D_SET_MME_SHADOW_SCRATCH(218):
    case NV902D_SET_MME_SHADOW_SCRATCH(219):
    case NV902D_SET_MME_SHADOW_SCRATCH(220):
    case NV902D_SET_MME_SHADOW_SCRATCH(221):
    case NV902D_SET_MME_SHADOW_SCRATCH(222):
    case NV902D_SET_MME_SHADOW_SCRATCH(223):
    case NV902D_SET_MME_SHADOW_SCRATCH(224):
    case NV902D_SET_MME_SHADOW_SCRATCH(225):
    case NV902D_SET_MME_SHADOW_SCRATCH(226):
    case NV902D_SET_MME_SHADOW_SCRATCH(227):
    case NV902D_SET_MME_SHADOW_SCRATCH(228):
    case NV902D_SET_MME_SHADOW_SCRATCH(229):
    case NV902D_SET_MME_SHADOW_SCRATCH(230):
    case NV902D_SET_MME_SHADOW_SCRATCH(231):
    case NV902D_SET_MME_SHADOW_SCRATCH(232):
    case NV902D_SET_MME_SHADOW_SCRATCH(233):
    case NV902D_SET_MME_SHADOW_SCRATCH(234):
    case NV902D_SET_MME_SHADOW_SCRATCH(235):
    case NV902D_SET_MME_SHADOW_SCRATCH(236):
    case NV902D_SET_MME_SHADOW_SCRATCH(237):
    case NV902D_SET_MME_SHADOW_SCRATCH(238):
    case NV902D_SET_MME_SHADOW_SCRATCH(239):
    case NV902D_SET_MME_SHADOW_SCRATCH(240):
    case NV902D_SET_MME_SHADOW_SCRATCH(241):
    case NV902D_SET_MME_SHADOW_SCRATCH(242):
    case NV902D_SET_MME_SHADOW_SCRATCH(243):
    case NV902D_SET_MME_SHADOW_SCRATCH(244):
    case NV902D_SET_MME_SHADOW_SCRATCH(245):
    case NV902D_SET_MME_SHADOW_SCRATCH(246):
    case NV902D_SET_MME_SHADOW_SCRATCH(247):
    case NV902D_SET_MME_SHADOW_SCRATCH(248):
    case NV902D_SET_MME_SHADOW_SCRATCH(249):
    case NV902D_SET_MME_SHADOW_SCRATCH(250):
    case NV902D_SET_MME_SHADOW_SCRATCH(251):
    case NV902D_SET_MME_SHADOW_SCRATCH(252):
    case NV902D_SET_MME_SHADOW_SCRATCH(253):
    case NV902D_SET_MME_SHADOW_SCRATCH(254):
    case NV902D_SET_MME_SHADOW_SCRATCH(255):

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_CALL_MME_MACRO(0):
    case NV902D_CALL_MME_MACRO(1):
    case NV902D_CALL_MME_MACRO(2):
    case NV902D_CALL_MME_MACRO(3):
    case NV902D_CALL_MME_MACRO(4):
    case NV902D_CALL_MME_MACRO(5):
    case NV902D_CALL_MME_MACRO(6):
    case NV902D_CALL_MME_MACRO(7):
    case NV902D_CALL_MME_MACRO(8):
    case NV902D_CALL_MME_MACRO(9):
    case NV902D_CALL_MME_MACRO(10):
    case NV902D_CALL_MME_MACRO(11):
    case NV902D_CALL_MME_MACRO(12):
    case NV902D_CALL_MME_MACRO(13):
    case NV902D_CALL_MME_MACRO(14):
    case NV902D_CALL_MME_MACRO(15):
    case NV902D_CALL_MME_MACRO(16):
    case NV902D_CALL_MME_MACRO(17):
    case NV902D_CALL_MME_MACRO(18):
    case NV902D_CALL_MME_MACRO(19):
    case NV902D_CALL_MME_MACRO(20):
    case NV902D_CALL_MME_MACRO(21):
    case NV902D_CALL_MME_MACRO(22):
    case NV902D_CALL_MME_MACRO(23):
    case NV902D_CALL_MME_MACRO(24):
    case NV902D_CALL_MME_MACRO(25):
    case NV902D_CALL_MME_MACRO(26):
    case NV902D_CALL_MME_MACRO(27):
    case NV902D_CALL_MME_MACRO(28):
    case NV902D_CALL_MME_MACRO(29):
    case NV902D_CALL_MME_MACRO(30):
    case NV902D_CALL_MME_MACRO(31):
    case NV902D_CALL_MME_MACRO(32):
    case NV902D_CALL_MME_MACRO(33):
    case NV902D_CALL_MME_MACRO(34):
    case NV902D_CALL_MME_MACRO(35):
    case NV902D_CALL_MME_MACRO(36):
    case NV902D_CALL_MME_MACRO(37):
    case NV902D_CALL_MME_MACRO(38):
    case NV902D_CALL_MME_MACRO(39):
    case NV902D_CALL_MME_MACRO(40):
    case NV902D_CALL_MME_MACRO(41):
    case NV902D_CALL_MME_MACRO(42):
    case NV902D_CALL_MME_MACRO(43):
    case NV902D_CALL_MME_MACRO(44):
    case NV902D_CALL_MME_MACRO(45):
    case NV902D_CALL_MME_MACRO(46):
    case NV902D_CALL_MME_MACRO(47):
    case NV902D_CALL_MME_MACRO(48):
    case NV902D_CALL_MME_MACRO(49):
    case NV902D_CALL_MME_MACRO(50):
    case NV902D_CALL_MME_MACRO(51):
    case NV902D_CALL_MME_MACRO(52):
    case NV902D_CALL_MME_MACRO(53):
    case NV902D_CALL_MME_MACRO(54):
    case NV902D_CALL_MME_MACRO(55):
    case NV902D_CALL_MME_MACRO(56):
    case NV902D_CALL_MME_MACRO(57):
    case NV902D_CALL_MME_MACRO(58):
    case NV902D_CALL_MME_MACRO(59):
    case NV902D_CALL_MME_MACRO(60):
    case NV902D_CALL_MME_MACRO(61):
    case NV902D_CALL_MME_MACRO(62):
    case NV902D_CALL_MME_MACRO(63):
    case NV902D_CALL_MME_MACRO(64):
    case NV902D_CALL_MME_MACRO(65):
    case NV902D_CALL_MME_MACRO(66):
    case NV902D_CALL_MME_MACRO(67):
    case NV902D_CALL_MME_MACRO(68):
    case NV902D_CALL_MME_MACRO(69):
    case NV902D_CALL_MME_MACRO(70):
    case NV902D_CALL_MME_MACRO(71):
    case NV902D_CALL_MME_MACRO(72):
    case NV902D_CALL_MME_MACRO(73):
    case NV902D_CALL_MME_MACRO(74):
    case NV902D_CALL_MME_MACRO(75):
    case NV902D_CALL_MME_MACRO(76):
    case NV902D_CALL_MME_MACRO(77):
    case NV902D_CALL_MME_MACRO(78):
    case NV902D_CALL_MME_MACRO(79):
    case NV902D_CALL_MME_MACRO(80):
    case NV902D_CALL_MME_MACRO(81):
    case NV902D_CALL_MME_MACRO(82):
    case NV902D_CALL_MME_MACRO(83):
    case NV902D_CALL_MME_MACRO(84):
    case NV902D_CALL_MME_MACRO(85):
    case NV902D_CALL_MME_MACRO(86):
    case NV902D_CALL_MME_MACRO(87):
    case NV902D_CALL_MME_MACRO(88):
    case NV902D_CALL_MME_MACRO(89):
    case NV902D_CALL_MME_MACRO(90):
    case NV902D_CALL_MME_MACRO(91):
    case NV902D_CALL_MME_MACRO(92):
    case NV902D_CALL_MME_MACRO(93):
    case NV902D_CALL_MME_MACRO(94):
    case NV902D_CALL_MME_MACRO(95):
    case NV902D_CALL_MME_MACRO(96):
    case NV902D_CALL_MME_MACRO(97):
    case NV902D_CALL_MME_MACRO(98):
    case NV902D_CALL_MME_MACRO(99):
    case NV902D_CALL_MME_MACRO(100):
    case NV902D_CALL_MME_MACRO(101):
    case NV902D_CALL_MME_MACRO(102):
    case NV902D_CALL_MME_MACRO(103):
    case NV902D_CALL_MME_MACRO(104):
    case NV902D_CALL_MME_MACRO(105):
    case NV902D_CALL_MME_MACRO(106):
    case NV902D_CALL_MME_MACRO(107):
    case NV902D_CALL_MME_MACRO(108):
    case NV902D_CALL_MME_MACRO(109):
    case NV902D_CALL_MME_MACRO(110):
    case NV902D_CALL_MME_MACRO(111):
    case NV902D_CALL_MME_MACRO(112):
    case NV902D_CALL_MME_MACRO(113):
    case NV902D_CALL_MME_MACRO(114):
    case NV902D_CALL_MME_MACRO(115):
    case NV902D_CALL_MME_MACRO(116):
    case NV902D_CALL_MME_MACRO(117):
    case NV902D_CALL_MME_MACRO(118):
    case NV902D_CALL_MME_MACRO(119):
    case NV902D_CALL_MME_MACRO(120):
    case NV902D_CALL_MME_MACRO(121):
    case NV902D_CALL_MME_MACRO(122):
    case NV902D_CALL_MME_MACRO(123):
    case NV902D_CALL_MME_MACRO(124):
    case NV902D_CALL_MME_MACRO(125):
    case NV902D_CALL_MME_MACRO(126):
    case NV902D_CALL_MME_MACRO(127):
    case NV902D_CALL_MME_MACRO(128):
    case NV902D_CALL_MME_MACRO(129):
    case NV902D_CALL_MME_MACRO(130):
    case NV902D_CALL_MME_MACRO(131):
    case NV902D_CALL_MME_MACRO(132):
    case NV902D_CALL_MME_MACRO(133):
    case NV902D_CALL_MME_MACRO(134):
    case NV902D_CALL_MME_MACRO(135):
    case NV902D_CALL_MME_MACRO(136):
    case NV902D_CALL_MME_MACRO(137):
    case NV902D_CALL_MME_MACRO(138):
    case NV902D_CALL_MME_MACRO(139):
    case NV902D_CALL_MME_MACRO(140):
    case NV902D_CALL_MME_MACRO(141):
    case NV902D_CALL_MME_MACRO(142):
    case NV902D_CALL_MME_MACRO(143):
    case NV902D_CALL_MME_MACRO(144):
    case NV902D_CALL_MME_MACRO(145):
    case NV902D_CALL_MME_MACRO(146):
    case NV902D_CALL_MME_MACRO(147):
    case NV902D_CALL_MME_MACRO(148):
    case NV902D_CALL_MME_MACRO(149):
    case NV902D_CALL_MME_MACRO(150):
    case NV902D_CALL_MME_MACRO(151):
    case NV902D_CALL_MME_MACRO(152):
    case NV902D_CALL_MME_MACRO(153):
    case NV902D_CALL_MME_MACRO(154):
    case NV902D_CALL_MME_MACRO(155):
    case NV902D_CALL_MME_MACRO(156):
    case NV902D_CALL_MME_MACRO(157):
    case NV902D_CALL_MME_MACRO(158):
    case NV902D_CALL_MME_MACRO(159):
    case NV902D_CALL_MME_MACRO(160):
    case NV902D_CALL_MME_MACRO(161):
    case NV902D_CALL_MME_MACRO(162):
    case NV902D_CALL_MME_MACRO(163):
    case NV902D_CALL_MME_MACRO(164):
    case NV902D_CALL_MME_MACRO(165):
    case NV902D_CALL_MME_MACRO(166):
    case NV902D_CALL_MME_MACRO(167):
    case NV902D_CALL_MME_MACRO(168):
    case NV902D_CALL_MME_MACRO(169):
    case NV902D_CALL_MME_MACRO(170):
    case NV902D_CALL_MME_MACRO(171):
    case NV902D_CALL_MME_MACRO(172):
    case NV902D_CALL_MME_MACRO(173):
    case NV902D_CALL_MME_MACRO(174):
    case NV902D_CALL_MME_MACRO(175):
    case NV902D_CALL_MME_MACRO(176):
    case NV902D_CALL_MME_MACRO(177):
    case NV902D_CALL_MME_MACRO(178):
    case NV902D_CALL_MME_MACRO(179):
    case NV902D_CALL_MME_MACRO(180):
    case NV902D_CALL_MME_MACRO(181):
    case NV902D_CALL_MME_MACRO(182):
    case NV902D_CALL_MME_MACRO(183):
    case NV902D_CALL_MME_MACRO(184):
    case NV902D_CALL_MME_MACRO(185):
    case NV902D_CALL_MME_MACRO(186):
    case NV902D_CALL_MME_MACRO(187):
    case NV902D_CALL_MME_MACRO(188):
    case NV902D_CALL_MME_MACRO(189):
    case NV902D_CALL_MME_MACRO(190):
    case NV902D_CALL_MME_MACRO(191):
    case NV902D_CALL_MME_MACRO(192):
    case NV902D_CALL_MME_MACRO(193):
    case NV902D_CALL_MME_MACRO(194):
    case NV902D_CALL_MME_MACRO(195):
    case NV902D_CALL_MME_MACRO(196):
    case NV902D_CALL_MME_MACRO(197):
    case NV902D_CALL_MME_MACRO(198):
    case NV902D_CALL_MME_MACRO(199):
    case NV902D_CALL_MME_MACRO(200):
    case NV902D_CALL_MME_MACRO(201):
    case NV902D_CALL_MME_MACRO(202):
    case NV902D_CALL_MME_MACRO(203):
    case NV902D_CALL_MME_MACRO(204):
    case NV902D_CALL_MME_MACRO(205):
    case NV902D_CALL_MME_MACRO(206):
    case NV902D_CALL_MME_MACRO(207):
    case NV902D_CALL_MME_MACRO(208):
    case NV902D_CALL_MME_MACRO(209):
    case NV902D_CALL_MME_MACRO(210):
    case NV902D_CALL_MME_MACRO(211):
    case NV902D_CALL_MME_MACRO(212):
    case NV902D_CALL_MME_MACRO(213):
    case NV902D_CALL_MME_MACRO(214):
    case NV902D_CALL_MME_MACRO(215):
    case NV902D_CALL_MME_MACRO(216):
    case NV902D_CALL_MME_MACRO(217):
    case NV902D_CALL_MME_MACRO(218):
    case NV902D_CALL_MME_MACRO(219):
    case NV902D_CALL_MME_MACRO(220):
    case NV902D_CALL_MME_MACRO(221):
    case NV902D_CALL_MME_MACRO(222):
    case NV902D_CALL_MME_MACRO(223):
    case NV902D_CALL_MME_MACRO(224):
    case NV902D_CALL_MME_MACRO(225):
    case NV902D_CALL_MME_MACRO(226):
    case NV902D_CALL_MME_MACRO(227):
    case NV902D_CALL_MME_MACRO(228):
    case NV902D_CALL_MME_MACRO(229):
    case NV902D_CALL_MME_MACRO(230):
    case NV902D_CALL_MME_MACRO(231):
    case NV902D_CALL_MME_MACRO(232):
    case NV902D_CALL_MME_MACRO(233):
    case NV902D_CALL_MME_MACRO(234):
    case NV902D_CALL_MME_MACRO(235):
    case NV902D_CALL_MME_MACRO(236):
    case NV902D_CALL_MME_MACRO(237):
    case NV902D_CALL_MME_MACRO(238):
    case NV902D_CALL_MME_MACRO(239):
    case NV902D_CALL_MME_MACRO(240):
    case NV902D_CALL_MME_MACRO(241):
    case NV902D_CALL_MME_MACRO(242):
    case NV902D_CALL_MME_MACRO(243):
    case NV902D_CALL_MME_MACRO(244):
    case NV902D_CALL_MME_MACRO(245):
    case NV902D_CALL_MME_MACRO(246):
    case NV902D_CALL_MME_MACRO(247):
    case NV902D_CALL_MME_MACRO(248):
    case NV902D_CALL_MME_MACRO(249):
    case NV902D_CALL_MME_MACRO(250):
    case NV902D_CALL_MME_MACRO(251):
    case NV902D_CALL_MME_MACRO(252):
    case NV902D_CALL_MME_MACRO(253):
    case NV902D_CALL_MME_MACRO(254):
    case NV902D_CALL_MME_MACRO(255):

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
  
    case NV902D_CALL_MME_DATA(0):
    case NV902D_CALL_MME_DATA(1):
    case NV902D_CALL_MME_DATA(2):
    case NV902D_CALL_MME_DATA(3):
    case NV902D_CALL_MME_DATA(4):
    case NV902D_CALL_MME_DATA(5):
    case NV902D_CALL_MME_DATA(6):
    case NV902D_CALL_MME_DATA(7):
    case NV902D_CALL_MME_DATA(8):
    case NV902D_CALL_MME_DATA(9):
    case NV902D_CALL_MME_DATA(10):
    case NV902D_CALL_MME_DATA(11):
    case NV902D_CALL_MME_DATA(12):
    case NV902D_CALL_MME_DATA(13):
    case NV902D_CALL_MME_DATA(14):
    case NV902D_CALL_MME_DATA(15):
    case NV902D_CALL_MME_DATA(16):
    case NV902D_CALL_MME_DATA(17):
    case NV902D_CALL_MME_DATA(18):
    case NV902D_CALL_MME_DATA(19):
    case NV902D_CALL_MME_DATA(20):
    case NV902D_CALL_MME_DATA(21):
    case NV902D_CALL_MME_DATA(22):
    case NV902D_CALL_MME_DATA(23):
    case NV902D_CALL_MME_DATA(24):
    case NV902D_CALL_MME_DATA(25):
    case NV902D_CALL_MME_DATA(26):
    case NV902D_CALL_MME_DATA(27):
    case NV902D_CALL_MME_DATA(28):
    case NV902D_CALL_MME_DATA(29):
    case NV902D_CALL_MME_DATA(30):
    case NV902D_CALL_MME_DATA(31):
    case NV902D_CALL_MME_DATA(32):
    case NV902D_CALL_MME_DATA(33):
    case NV902D_CALL_MME_DATA(34):
    case NV902D_CALL_MME_DATA(35):
    case NV902D_CALL_MME_DATA(36):
    case NV902D_CALL_MME_DATA(37):
    case NV902D_CALL_MME_DATA(38):
    case NV902D_CALL_MME_DATA(39):
    case NV902D_CALL_MME_DATA(40):
    case NV902D_CALL_MME_DATA(41):
    case NV902D_CALL_MME_DATA(42):
    case NV902D_CALL_MME_DATA(43):
    case NV902D_CALL_MME_DATA(44):
    case NV902D_CALL_MME_DATA(45):
    case NV902D_CALL_MME_DATA(46):
    case NV902D_CALL_MME_DATA(47):
    case NV902D_CALL_MME_DATA(48):
    case NV902D_CALL_MME_DATA(49):
    case NV902D_CALL_MME_DATA(50):
    case NV902D_CALL_MME_DATA(51):
    case NV902D_CALL_MME_DATA(52):
    case NV902D_CALL_MME_DATA(53):
    case NV902D_CALL_MME_DATA(54):
    case NV902D_CALL_MME_DATA(55):
    case NV902D_CALL_MME_DATA(56):
    case NV902D_CALL_MME_DATA(57):
    case NV902D_CALL_MME_DATA(58):
    case NV902D_CALL_MME_DATA(59):
    case NV902D_CALL_MME_DATA(60):
    case NV902D_CALL_MME_DATA(61):
    case NV902D_CALL_MME_DATA(62):
    case NV902D_CALL_MME_DATA(63):
    case NV902D_CALL_MME_DATA(64):
    case NV902D_CALL_MME_DATA(65):
    case NV902D_CALL_MME_DATA(66):
    case NV902D_CALL_MME_DATA(67):
    case NV902D_CALL_MME_DATA(68):
    case NV902D_CALL_MME_DATA(69):
    case NV902D_CALL_MME_DATA(70):
    case NV902D_CALL_MME_DATA(71):
    case NV902D_CALL_MME_DATA(72):
    case NV902D_CALL_MME_DATA(73):
    case NV902D_CALL_MME_DATA(74):
    case NV902D_CALL_MME_DATA(75):
    case NV902D_CALL_MME_DATA(76):
    case NV902D_CALL_MME_DATA(77):
    case NV902D_CALL_MME_DATA(78):
    case NV902D_CALL_MME_DATA(79):
    case NV902D_CALL_MME_DATA(80):
    case NV902D_CALL_MME_DATA(81):
    case NV902D_CALL_MME_DATA(82):
    case NV902D_CALL_MME_DATA(83):
    case NV902D_CALL_MME_DATA(84):
    case NV902D_CALL_MME_DATA(85):
    case NV902D_CALL_MME_DATA(86):
    case NV902D_CALL_MME_DATA(87):
    case NV902D_CALL_MME_DATA(88):
    case NV902D_CALL_MME_DATA(89):
    case NV902D_CALL_MME_DATA(90):
    case NV902D_CALL_MME_DATA(91):
    case NV902D_CALL_MME_DATA(92):
    case NV902D_CALL_MME_DATA(93):
    case NV902D_CALL_MME_DATA(94):
    case NV902D_CALL_MME_DATA(95):
    case NV902D_CALL_MME_DATA(96):
    case NV902D_CALL_MME_DATA(97):
    case NV902D_CALL_MME_DATA(98):
    case NV902D_CALL_MME_DATA(99):
    case NV902D_CALL_MME_DATA(100):
    case NV902D_CALL_MME_DATA(101):
    case NV902D_CALL_MME_DATA(102):
    case NV902D_CALL_MME_DATA(103):
    case NV902D_CALL_MME_DATA(104):
    case NV902D_CALL_MME_DATA(105):
    case NV902D_CALL_MME_DATA(106):
    case NV902D_CALL_MME_DATA(107):
    case NV902D_CALL_MME_DATA(108):
    case NV902D_CALL_MME_DATA(109):
    case NV902D_CALL_MME_DATA(110):
    case NV902D_CALL_MME_DATA(111):
    case NV902D_CALL_MME_DATA(112):
    case NV902D_CALL_MME_DATA(113):
    case NV902D_CALL_MME_DATA(114):
    case NV902D_CALL_MME_DATA(115):
    case NV902D_CALL_MME_DATA(116):
    case NV902D_CALL_MME_DATA(117):
    case NV902D_CALL_MME_DATA(118):
    case NV902D_CALL_MME_DATA(119):
    case NV902D_CALL_MME_DATA(120):
    case NV902D_CALL_MME_DATA(121):
    case NV902D_CALL_MME_DATA(122):
    case NV902D_CALL_MME_DATA(123):
    case NV902D_CALL_MME_DATA(124):
    case NV902D_CALL_MME_DATA(125):
    case NV902D_CALL_MME_DATA(126):
    case NV902D_CALL_MME_DATA(127):
    case NV902D_CALL_MME_DATA(128):
    case NV902D_CALL_MME_DATA(129):
    case NV902D_CALL_MME_DATA(130):
    case NV902D_CALL_MME_DATA(131):
    case NV902D_CALL_MME_DATA(132):
    case NV902D_CALL_MME_DATA(133):
    case NV902D_CALL_MME_DATA(134):
    case NV902D_CALL_MME_DATA(135):
    case NV902D_CALL_MME_DATA(136):
    case NV902D_CALL_MME_DATA(137):
    case NV902D_CALL_MME_DATA(138):
    case NV902D_CALL_MME_DATA(139):
    case NV902D_CALL_MME_DATA(140):
    case NV902D_CALL_MME_DATA(141):
    case NV902D_CALL_MME_DATA(142):
    case NV902D_CALL_MME_DATA(143):
    case NV902D_CALL_MME_DATA(144):
    case NV902D_CALL_MME_DATA(145):
    case NV902D_CALL_MME_DATA(146):
    case NV902D_CALL_MME_DATA(147):
    case NV902D_CALL_MME_DATA(148):
    case NV902D_CALL_MME_DATA(149):
    case NV902D_CALL_MME_DATA(150):
    case NV902D_CALL_MME_DATA(151):
    case NV902D_CALL_MME_DATA(152):
    case NV902D_CALL_MME_DATA(153):
    case NV902D_CALL_MME_DATA(154):
    case NV902D_CALL_MME_DATA(155):
    case NV902D_CALL_MME_DATA(156):
    case NV902D_CALL_MME_DATA(157):
    case NV902D_CALL_MME_DATA(158):
    case NV902D_CALL_MME_DATA(159):
    case NV902D_CALL_MME_DATA(160):
    case NV902D_CALL_MME_DATA(161):
    case NV902D_CALL_MME_DATA(162):
    case NV902D_CALL_MME_DATA(163):
    case NV902D_CALL_MME_DATA(164):
    case NV902D_CALL_MME_DATA(165):
    case NV902D_CALL_MME_DATA(166):
    case NV902D_CALL_MME_DATA(167):
    case NV902D_CALL_MME_DATA(168):
    case NV902D_CALL_MME_DATA(169):
    case NV902D_CALL_MME_DATA(170):
    case NV902D_CALL_MME_DATA(171):
    case NV902D_CALL_MME_DATA(172):
    case NV902D_CALL_MME_DATA(173):
    case NV902D_CALL_MME_DATA(174):
    case NV902D_CALL_MME_DATA(175):
    case NV902D_CALL_MME_DATA(176):
    case NV902D_CALL_MME_DATA(177):
    case NV902D_CALL_MME_DATA(178):
    case NV902D_CALL_MME_DATA(179):
    case NV902D_CALL_MME_DATA(180):
    case NV902D_CALL_MME_DATA(181):
    case NV902D_CALL_MME_DATA(182):
    case NV902D_CALL_MME_DATA(183):
    case NV902D_CALL_MME_DATA(184):
    case NV902D_CALL_MME_DATA(185):
    case NV902D_CALL_MME_DATA(186):
    case NV902D_CALL_MME_DATA(187):
    case NV902D_CALL_MME_DATA(188):
    case NV902D_CALL_MME_DATA(189):
    case NV902D_CALL_MME_DATA(190):
    case NV902D_CALL_MME_DATA(191):
    case NV902D_CALL_MME_DATA(192):
    case NV902D_CALL_MME_DATA(193):
    case NV902D_CALL_MME_DATA(194):
    case NV902D_CALL_MME_DATA(195):
    case NV902D_CALL_MME_DATA(196):
    case NV902D_CALL_MME_DATA(197):
    case NV902D_CALL_MME_DATA(198):
    case NV902D_CALL_MME_DATA(199):
    case NV902D_CALL_MME_DATA(200):
    case NV902D_CALL_MME_DATA(201):
    case NV902D_CALL_MME_DATA(202):
    case NV902D_CALL_MME_DATA(203):
    case NV902D_CALL_MME_DATA(204):
    case NV902D_CALL_MME_DATA(205):
    case NV902D_CALL_MME_DATA(206):
    case NV902D_CALL_MME_DATA(207):
    case NV902D_CALL_MME_DATA(208):
    case NV902D_CALL_MME_DATA(209):
    case NV902D_CALL_MME_DATA(210):
    case NV902D_CALL_MME_DATA(211):
    case NV902D_CALL_MME_DATA(212):
    case NV902D_CALL_MME_DATA(213):
    case NV902D_CALL_MME_DATA(214):
    case NV902D_CALL_MME_DATA(215):
    case NV902D_CALL_MME_DATA(216):
    case NV902D_CALL_MME_DATA(217):
    case NV902D_CALL_MME_DATA(218):
    case NV902D_CALL_MME_DATA(219):
    case NV902D_CALL_MME_DATA(220):
    case NV902D_CALL_MME_DATA(221):
    case NV902D_CALL_MME_DATA(222):
    case NV902D_CALL_MME_DATA(223):
    case NV902D_CALL_MME_DATA(224):
    case NV902D_CALL_MME_DATA(225):
    case NV902D_CALL_MME_DATA(226):
    case NV902D_CALL_MME_DATA(227):
    case NV902D_CALL_MME_DATA(228):
    case NV902D_CALL_MME_DATA(229):
    case NV902D_CALL_MME_DATA(230):
    case NV902D_CALL_MME_DATA(231):
    case NV902D_CALL_MME_DATA(232):
    case NV902D_CALL_MME_DATA(233):
    case NV902D_CALL_MME_DATA(234):
    case NV902D_CALL_MME_DATA(235):
    case NV902D_CALL_MME_DATA(236):
    case NV902D_CALL_MME_DATA(237):
    case NV902D_CALL_MME_DATA(238):
    case NV902D_CALL_MME_DATA(239):
    case NV902D_CALL_MME_DATA(240):
    case NV902D_CALL_MME_DATA(241):
    case NV902D_CALL_MME_DATA(242):
    case NV902D_CALL_MME_DATA(243):
    case NV902D_CALL_MME_DATA(244):
    case NV902D_CALL_MME_DATA(245):
    case NV902D_CALL_MME_DATA(246):
    case NV902D_CALL_MME_DATA(247):
    case NV902D_CALL_MME_DATA(248):
    case NV902D_CALL_MME_DATA(249):
    case NV902D_CALL_MME_DATA(250):
    case NV902D_CALL_MME_DATA(251):
    case NV902D_CALL_MME_DATA(252):
    case NV902D_CALL_MME_DATA(253):
    case NV902D_CALL_MME_DATA(254):
    case NV902D_CALL_MME_DATA(255):

    
        parsed = data;
        fprintf(fp, "%s.V = ", prefix);
        fprintf(fp, "(0x%x)\n", parsed);
        break;
    default:
        fprintf(fp, "%s.VALUE = 0x%x\n", prefix, data);
        break;
    }
}
